searchData={"items":[{"type":"module","title":"Cldr","doc":"Cldr provides the core functions to retrieve and manage\nthe CLDR data that supports formatting and localisation.\n\nThis module provides the core functions to access formatted\nCLDR data, set and retrieve a current locale and validate\ncertain core data types such as locales, currencies and\nterritories.\n\n> #### `use Cldr` {: .info}\n>\n> When you `use Cldr`, a number of functions are generated\n> that encapsulate CLDR data. A moodule that invokes `use Cldr`\n> is referred to as a Cldr backend module.\n>\n> The functions in a Cldr backend module form the primary\n> recommended API for `ex_cldr`.\n>\n> In additional, a number of additional modules\n> may be generated with names that are prefixed by the name of\n> the module in which `use Cldr` is invoked. The number and names\n> of these additional modules is determined by the modules\n> configured under the `:providers` option to `use Cldr`.\n>\n> It is not recommended that a module that invoke `use Cldr`\n> define any other functions.\n>\n> See [the configuration guide](https://hexdocs.pm/ex_cldr/readme.html#configuration)\n> for details on how to configure.\n\n`Cldr` functionality is packaged into a several\nlibraries that each depend on this one.  These additional\nlibraries are:\n\n* Plugs for setting the locale from an HTTP request: [ex_cldr_plugs](https://hex.pm/packages/ex_cldr_plugs)\n* Number formatting: [ex_cldr_numbers](https://hex.pm/packages/ex_cldr_numbers)\n* List formatting: [ex_cldr_lists](https://hex.pm/packages/ex_cldr_lists)\n* Unit formatting: [ex_cldr_units](https://hex.pm/packages/ex_cldr_units)\n* Date/Time/DateTime formatting: [ex_cldr_dates_times](https://hex.pm/packages/ex_cldr_dates_times)\n* Route localization for Phoenix: [ex_cldr_routes](https://hex.pm/packages/ex_cldr_routes)\n* Locale name localisation: [ex_cldr_locale_display](https://hex.pm/packages/ex_cldr_locale_display)\n* HTML select helpers: [ex_cldr_html](https://hex.pm/packages/cldr_html)\n* Calendars: [ex_cldr_calendars](https://hex.pm/packages/ex_cldr_calendars)\n* Calendar formatting: [ex_cldr_calendars_format](https://hex.pm/packages/ex_cldr_calendars_format)\n* Printf-like formatting: [ex_cldr_print](https://hex.pm/packages/ex_cldr_print)\n* Collation: [ex_cldr_collation](https://hex.pm/packages/ex_cldr_collation)\n* ICU Message formatting: [ex_cldr_messages](https://hex.pm/packages/ex_cldr_messages)\n* Territories localization and information: [ex_cldr_territories](https://hex.pm/packages/ex_cldr_territories) by @Schultzer\n* Languages localization: [ex_cldr_languages](https://hex.pm/packages/ex_cldr_languages) by @lostkobrakai","ref":"Cldr.html"},{"type":"function","title":"Cldr.all_locale_names/0","doc":"Returns a list of all the locale names defined in\nthe CLDR repository.\n\nNote that not necessarily all of these locales are\navailable since functions are only generated for configured\nlocales which is most cases will be a subset of locales\ndefined in CLDR.\n\nSee also: `requested_locales/1` and `known_locales/1`","ref":"Cldr.html#all_locale_names/0"},{"type":"function","title":"Cldr.available_locale_name?/1","doc":"Returns a boolean indicating if the specified locale\nis available in CLDR.\n\nThe return value depends on whether the locale is\ndefined in the CLDR repository.  It does not necessarily\nmean the locale is configured for `Cldr`.  See also\n`Cldr.known_locale_name?/2`.","ref":"Cldr.html#available_locale_name?/1"},{"type":"function","title":"Arguments - Cldr.available_locale_name?/1","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`","ref":"Cldr.html#available_locale_name?/1-arguments"},{"type":"function","title":"Examples - Cldr.available_locale_name?/1","doc":"iex> Cldr.available_locale_name?(:\"en-AU\")\n    true\n\n    iex> Cldr.available_locale_name?(:\"en-SA\")\n    false","ref":"Cldr.html#available_locale_name?/1-examples"},{"type":"type","title":"Cldr.backend/0","doc":"","ref":"Cldr.html#t:backend/0"},{"type":"function","title":"Cldr.default_backend/0","doc":"","ref":"Cldr.html#default_backend/0"},{"type":"function","title":"Cldr.default_backend!/0","doc":"Returns the configured default backend module.\n\nThe default backend can be set with\n`Cldr.put_default_backend/1`.\n\nAlternatively the default backend may be configured in\n`config.exs` under the `ex_cldr` key as follows:\n\n    config :ex_cldr,\n      default_backend:","ref":"Cldr.html#default_backend!/0"},{"type":"function","title":"Important Note - Cldr.default_backend!/0","doc":"If this function is called and no default backend\nis configured an exception will be raised.","ref":"Cldr.html#default_backend!/0-important-note"},{"type":"function","title":"Cldr.default_locale/0","doc":"Returns the configured global default `locale`.\n\nThe default locale can be set with\n`Cldr.put_default_locale/1`.\n\nAlternatively the default locale may be configured in\n`config.exs` under the `ex_cldr` key as follows:\n\n    config :ex_cldr,\n      default_locale:","ref":"Cldr.html#default_locale/0"},{"type":"function","title":"Returns - Cldr.default_locale/0","doc":"* The default locale or\n\n* Raises an exception if no default\n  backend is configured","ref":"Cldr.html#default_locale/0-returns"},{"type":"function","title":"Notes - Cldr.default_locale/0","doc":"`Cldr.default_locale/0` returns the system-wide\ndefault locale.","ref":"Cldr.html#default_locale/0-notes"},{"type":"function","title":"Example - Cldr.default_locale/0","doc":"iex> Cldr.default_locale()\n    %Cldr.LanguageTag{\n      backend: TestBackend.Cldr,\n      canonical_locale_name: \"en-001\",\n      cldr_locale_name: :\"en-001\",\n      language_subtags: [],\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en-001\",\n      script: :Latn,\n      territory: :\"001\",\n      transform: %{},\n      language_variants: []\n    }","ref":"Cldr.html#default_locale/0-example"},{"type":"function","title":"Cldr.default_locale/1","doc":"Returns the global default `locale` for a\ngiven backend.","ref":"Cldr.html#default_locale/1"},{"type":"function","title":"Arguments - Cldr.default_locale/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.","ref":"Cldr.html#default_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.default_locale/1","doc":"* The default locale for the backend.","ref":"Cldr.html#default_locale/1-returns"},{"type":"function","title":"Example - Cldr.default_locale/1","doc":"iex> Cldr.default_locale(TestBackend.Cldr)\n    %Cldr.LanguageTag{\n      backend: TestBackend.Cldr,\n      canonical_locale_name: \"en-001\",\n      cldr_locale_name: :\"en-001\",\n      language_subtags: [],\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en-001\",\n      script: :Latn,\n      territory: :\"001\",\n      transform: %{},\n      language_variants: []\n    }","ref":"Cldr.html#default_locale/1-example"},{"type":"function","title":"Cldr.default_script/0","doc":"Returns the default script.","ref":"Cldr.html#default_script/0"},{"type":"function","title":"Returns - Cldr.default_script/0","doc":"* The default script which is `Latn`.","ref":"Cldr.html#default_script/0-returns"},{"type":"function","title":"Cldr.default_territory/1","doc":"Returns the default territory when a locale\ndoes not specify one and none can be inferred.","ref":"Cldr.html#default_territory/1"},{"type":"function","title":"Arguments - Cldr.default_territory/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend/0`","ref":"Cldr.html#default_territory/1-arguments"},{"type":"function","title":"Returns - Cldr.default_territory/1","doc":"* The default territory or\n\n* Raises if no argument is supplied and there is no\n  default backend configured","ref":"Cldr.html#default_territory/1-returns"},{"type":"function","title":"Example - Cldr.default_territory/1","doc":"iex> Cldr.default_territory(TestBackend.Cldr)\n    :\"001\"","ref":"Cldr.html#default_territory/1-example"},{"type":"function","title":"Cldr.display_name/2","doc":"Return a localised string suitable for\npresentation purposes for structs that\nimplement the `Cldr.LanguageTag.DisplayName`\nprotocol.\n\nThe `Cldr.LanguageTag.DisplayName` protocol is\nimplemented in this library for\n`t:Cldr.LanguageTag.t`.\n\nOther CLDR-related libraries implement\nthe protocol for the types they support\nsuch as `t:Cldr.Unit` and `t:Cldr.Currency`.","ref":"Cldr.html#display_name/2"},{"type":"function","title":"Cldr.ellipsis/3","doc":"Add locale-specific ellipsis to a string.","ref":"Cldr.html#ellipsis/3"},{"type":"function","title":"Arguments - Cldr.ellipsis/3","doc":"* `string` is any `String.t` or a 2-element list\n  of `String.t` between which the ellipsis is inserted.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend/0`.\n  Note that `Cldr.default_backend/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.\n\n* `options` is a keyword list of options.","ref":"Cldr.html#ellipsis/3-arguments"},{"type":"function","title":"Options - Cldr.ellipsis/3","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/0`\n\n* `:location` determines where to place the ellipsis. The options are\n  `:after` (the default for a single string argument), `:between` (the default\n  and only valid location for an argument that is a list of two strings) and `:before`\n\n* `:format` formats based upon whether the ellipsis\n  is inserted between words or sentences. The valid options are\n  `:word` or `:sentence`. The default is `:sentence`.","ref":"Cldr.html#ellipsis/3-options"},{"type":"function","title":"Examples - Cldr.ellipsis/3","doc":"iex> Cldr.ellipsis \"And furthermore\"\n    \"And furthermore…\"\n\n    iex> Cldr.ellipsis [\"And furthermore\", \"there is much to be done\"], locale: \"ja\"\n    \"And furthermore…there is much to be done\"\n\n    iex> Cldr.ellipsis \"And furthermore\", format: :word\n    \"And furthermore …\"\n\n    iex> Cldr.ellipsis [\"And furthermore\", \"there is much to be done\"], locale: \"ja\", format: :word\n    \"And furthermore … there is much to be done\"","ref":"Cldr.html#ellipsis/3-examples"},{"type":"function","title":"Cldr.flag/1","doc":"Returns a unicode string representing a flag for a territory.","ref":"Cldr.html#flag/1"},{"type":"function","title":"Options - Cldr.flag/1","doc":"* `territory` is any valid territory code returned\n  by `Cldr.known_territories/0` or a `Cldr.LanguageTag.t`","ref":"Cldr.html#flag/1-options"},{"type":"function","title":"Returns - Cldr.flag/1","doc":"* A string representing a flag or\n\n* An empty string if the territory is valid but no\n  unicode grapheme is defined. This is true for territories\n  that are aggregate areas such as \"the world\" which is\n  `:001`\n\n* `{:error, {Cldr.UnknownTerritoryError, message}}`","ref":"Cldr.html#flag/1-returns"},{"type":"function","title":"Notes - Cldr.flag/1","doc":"* If a `Cldr.LanguageTag.t` is provided, the territory is determined\n  by `Cldr.Locale.territory_from_locale/1`","ref":"Cldr.html#flag/1-notes"},{"type":"function","title":"Examples - Cldr.flag/1","doc":"iex> Cldr.flag :AU\n    \"🇦🇺\"\n\n    iex> Cldr.flag :US\n    \"🇺🇸\"\n\n    iex> Cldr.flag \"UN\"\n    \"🇺🇳\"\n\n    iex> Cldr.flag(:UK)\n    \"🇬🇧\"\n\n    iex> Cldr.flag(:GB)\n    \"🇬🇧\"\n\n    iex> Cldr.flag(:UX)\n    {:error, {Cldr.UnknownTerritoryError, \"The territory :UX is unknown\"}}","ref":"Cldr.html#flag/1-examples"},{"type":"function","title":"Cldr.get_locale/1","doc":"Return the `Cldr` locale for the\ncurrent process.\n\nNote that the locale is set per-process. If the locale\nis not set for the given process then:\n\n* Return the global default locale\n  which is defined under the `:ex_cldr` key in\n  `config.exs`\n\n* Or the system-wide default locale which is\n  \"en-001\"\n\nNote that if there is no locale set for the current\nprocess then an error is not returned - a default locale\nwill be returned per the rules above.","ref":"Cldr.html#get_locale/1"},{"type":"function","title":"Example - Cldr.get_locale/1","doc":"iex> Cldr.put_locale(TestBackend.Cldr.Locale.new!(\"pl\"))\n    iex> Cldr.get_locale()\n    %Cldr.LanguageTag{\n       backend: TestBackend.Cldr,\n       canonical_locale_name: \"pl\",\n       cldr_locale_name: :pl,\n       extensions: %{},\n       language: \"pl\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :pl,\n       territory: :PL,\n       requested_locale_name: \"pl\",\n       script: :Latn,\n       transform: %{},\n       language_variants: []\n     }","ref":"Cldr.html#get_locale/1-example"},{"type":"macro","title":"Cldr.is_locale_name/1","doc":"","ref":"Cldr.html#is_locale_name/1"},{"type":"function","title":"Cldr.known_calendars/0","doc":"Returns a list of strings representing the calendars known to `Cldr`.","ref":"Cldr.html#known_calendars/0"},{"type":"function","title":"Example - Cldr.known_calendars/0","doc":"iex> Cldr.known_calendars()\n    [:buddhist, :chinese, :coptic, :dangi, :ethiopic, :ethiopic_amete_alem,\n     :gregorian, :hebrew, :indian, :islamic, :islamic_civil, :islamic_rgsa,\n     :islamic_tbla, :islamic_umalqura, :japanese, :persian, :roc]","ref":"Cldr.html#known_calendars/0-example"},{"type":"function","title":"Cldr.known_currencies/0","doc":"Returns a list of strings representing the currencies known to `Cldr`.","ref":"Cldr.html#known_currencies/0"},{"type":"function","title":"Example - Cldr.known_currencies/0","doc":"iex> Cldr.known_currencies()\n    [:ADP, :AED, :AFA, :AFN, :ALK, :ALL, :AMD, :ANG, :AOA, :AOK, :AON, :AOR, :ARA,\n     :ARL, :ARM, :ARP, :ARS, :ATS, :AUD, :AWG, :AZM, :AZN, :BAD, :BAM, :BAN, :BBD,\n     :BDT, :BEC, :BEF, :BEL, :BGL, :BGM, :BGN, :BGO, :BHD, :BIF, :BMD, :BND, :BOB,\n     :BOL, :BOP, :BOV, :BRB, :BRC, :BRE, :BRL, :BRN, :BRR, :BRZ, :BSD, :BTN, :BUK,\n     :BWP, :BYB, :BYN, :BYR, :BZD, :CAD, :CDF, :CHE, :CHF, :CHW, :CLE, :CLF, :CLP,\n     :CNH, :CNX, :CNY, :COP, :COU, :CRC, :CSD, :CSK, :CUC, :CUP, :CVE, :CYP, :CZK,\n     :DDM, :DEM, :DJF, :DKK, :DOP, :DZD, :ECS, :ECV, :EEK, :EGP, :ERN, :ESA, :ESB,\n     :ESP, :ETB, :EUR, :FIM, :FJD, :FKP, :FRF, :GBP, :GEK, :GEL, :GHC, :GHS, :GIP,\n     :GMD, :GNF, :GNS, :GQE, :GRD, :GTQ, :GWE, :GWP, :GYD, :HKD, :HNL, :HRD, :HRK,\n     :HTG, :HUF, :IDR, :IEP, :ILP, :ILR, :ILS, :INR, :IQD, :IRR, :ISJ, :ISK, :ITL,\n     :JMD, :JOD, :JPY, :KES, :KGS, :KHR, :KMF, :KPW, :KRH, :KRO, :KRW, :KWD, :KYD,\n     :KZT, :LAK, :LBP, :LKR, :LRD, :LSL, :LTL, :LTT, :LUC, :LUF, :LUL, :LVL, :LVR,\n     :LYD, :MAD, :MAF, :MCF, :MDC, :MDL, :MGA, :MGF, :MKD, :MKN, :MLF, :MMK, :MNT,\n     :MOP, :MRO, :MRU, :MTL, :MTP, :MUR, :MVP, :MVR, :MWK, :MXN, :MXP, :MXV, :MYR,\n     :MZE, :MZM, :MZN, :NAD, :NGN, :NIC, :NIO, :NLG, :NOK, :NPR, :NZD, :OMR, :PAB,\n     :PEI, :PEN, :PES, :PGK, :PHP, :PKR, :PLN, :PLZ, :PTE, :PYG, :QAR, :RHD, :ROL,\n     :RON, :RSD, :RUB, :RUR, :RWF, :SAR, :SBD, :SCR, :SDD, :SDG, :SDP, :SEK, :SGD,\n     :SHP, :SIT, :SKK, :SLE, :SLL, :SOS, :SRD, :SRG, :SSP, :STD, :STN, :SUR, :SVC,\n     :SYP, :SZL, :THB, :TJR, :TJS, :TMM, :TMT, :TND, :TOP, :TPE, :TRL, :TRY, :TTD,\n     :TWD, :TZS, :UAH, :UAK, :UGS, :UGX, :USD, :USN, :USS, :UYI, :UYP, :UYU, :UYW,\n     :UZS, :VEB, :VED, :VEF, :VES, :VND, :VNN, :VUV, :WST, :XAF, :XAG, :XAU, :XBA,\n     :XBB, :XBC, :XBD, :XCD, :XCG, :XDR, :XEU, :XFO, :XFU, :XOF, :XPD, :XPF, :XPT,\n     :XRE, :XSU, :XTS, :XUA, :XXX, :YDD, :YER, :YUD, :YUM, :YUN, :YUR, :ZAL, :ZAR,\n     :ZMK, :ZMW, :ZRN, :ZRZ, :ZWD, :ZWG, :ZWL, :ZWR]","ref":"Cldr.html#known_currencies/0-example"},{"type":"function","title":"Cldr.known_gettext_locale_name/2","doc":"Returns either the Gettext `locale_name` in Cldr format or\n`false` based upon whether the locale name is configured in\n`Gettext`.","ref":"Cldr.html#known_gettext_locale_name/2"},{"type":"function","title":"Arguments - Cldr.known_gettext_locale_name/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#known_gettext_locale_name/2-arguments"},{"type":"function","title":"Examples - Cldr.known_gettext_locale_name/2","doc":"iex> Cldr.known_gettext_locale_name(\"en\", TestBackend.Cldr)\n    \"en\"\n\n    iex> Cldr.known_gettext_locale_name(\"en-SA\", TestBackend.Cldr)\n    false","ref":"Cldr.html#known_gettext_locale_name/2-examples"},{"type":"function","title":"Cldr.known_gettext_locale_name?/2","doc":"Returns a boolean indicating if the specified locale\nname is configured and available in Gettext.","ref":"Cldr.html#known_gettext_locale_name?/2"},{"type":"function","title":"Arguments - Cldr.known_gettext_locale_name?/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#known_gettext_locale_name?/2-arguments"},{"type":"function","title":"Examples - Cldr.known_gettext_locale_name?/2","doc":"iex> Cldr.known_gettext_locale_name?(\"en\", TestBackend.Cldr)\n    true\n\n    iex> Cldr.known_gettext_locale_name?(\"!!\", TestBackend.Cldr)\n    false","ref":"Cldr.html#known_gettext_locale_name?/2-examples"},{"type":"function","title":"Cldr.known_gettext_locale_names/1","doc":"Returns a list of Gettext locale names but in CLDR format with\nunderscore replaced by hyphen in order to facilitate comparisons\nwith Cldr locale names.","ref":"Cldr.html#known_gettext_locale_names/1"},{"type":"function","title":"Arguments - Cldr.known_gettext_locale_names/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#known_gettext_locale_names/1-arguments"},{"type":"function","title":"Cldr.known_locale_name/2","doc":"Returns either the `locale_name` or `false` based upon\nwhether the locale name is configured in `Cldr`.\n\nThis is helpful when building a list of `or` expressions\nto return the first known locale name from a list.","ref":"Cldr.html#known_locale_name/2"},{"type":"function","title":"Arguments - Cldr.known_locale_name/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#known_locale_name/2-arguments"},{"type":"function","title":"Examples - Cldr.known_locale_name/2","doc":"iex> Cldr.known_locale_name(:\"en-AU\", TestBackend.Cldr)\n    :\"en-AU\"\n\n    iex> Cldr.known_locale_name(:\"en-SA\", TestBackend.Cldr)\n    nil","ref":"Cldr.html#known_locale_name/2-examples"},{"type":"function","title":"Cldr.known_locale_name?/2","doc":"Returns a boolean indicating if the specified locale\nname is configured and available in Cldr.","ref":"Cldr.html#known_locale_name?/2"},{"type":"function","title":"Arguments - Cldr.known_locale_name?/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#known_locale_name?/2-arguments"},{"type":"function","title":"Examples - Cldr.known_locale_name?/2","doc":"iex> Cldr.known_locale_name?(:en, TestBackend.Cldr)\n    true\n\n    iex> Cldr.known_locale_name?(:\"!!\", TestBackend.Cldr)\n    false","ref":"Cldr.html#known_locale_name?/2-examples"},{"type":"function","title":"Cldr.known_locale_names/1","doc":"Returns a list of the known locale names.","ref":"Cldr.html#known_locale_names/1"},{"type":"function","title":"Arguments - Cldr.known_locale_names/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.\n\nKnown locales are those locales which\nare the subset of all CLDR locales that\nhave been configured for use either\ndirectly in the `config.exs` file or\nin `Gettext`.","ref":"Cldr.html#known_locale_names/1-arguments"},{"type":"function","title":"Cldr.known_number_system_types/1","doc":"Returns a list of atoms representing the number systems types known to `Cldr`.","ref":"Cldr.html#known_number_system_types/1"},{"type":"function","title":"Arguments - Cldr.known_number_system_types/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend/0`.\n  Note that `Cldr.default_backend/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#known_number_system_types/1-arguments"},{"type":"function","title":"Example - Cldr.known_number_system_types/1","doc":"iex> Cldr.known_number_system_types(TestBackend.Cldr)\n    [:default, :finance, :native, :traditional]","ref":"Cldr.html#known_number_system_types/1-example"},{"type":"function","title":"Cldr.known_number_systems/0","doc":"Returns a list of atoms representing the number systems known to `Cldr`.","ref":"Cldr.html#known_number_systems/0"},{"type":"function","title":"Example - Cldr.known_number_systems/0","doc":"iex> Cldr.known_number_systems()\n    [:adlm, :ahom, :arab, :arabext, :armn, :armnlow, :bali, :beng, :bhks, :brah,\n     :cakm, :cham, :cyrl, :deva, :diak, :ethi, :fullwide, :gara, :geor, :gong,\n     :gonm, :grek, :greklow, :gujr, :gukh, :guru, :hanidays, :hanidec, :hans,\n     :hansfin, :hant, :hantfin, :hebr, :hmng, :hmnp, :java, :jpan, :jpanfin,\n     :jpanyear, :kali, :kawi, :khmr, :knda, :krai, :lana, :lanatham, :laoo, :latn,\n     :lepc, :limb, :mathbold, :mathdbl, :mathmono, :mathsanb, :mathsans, :mlym,\n     :modi, :mong, :mroo, :mtei, :mymr, :mymrepka, :mymrpao, :mymrshan, :mymrtlng,\n     :nagm, :newa, :nkoo, :olck, :onao, :orya, :osma, :outlined, :rohg, :roman,\n     :romanlow, :saur, :segment, :shrd, :sind, :sinh, :sora, :sund, :sunu, :takr,\n     :talu, :taml, :tamldec, :telu, :thai, :tibt, :tirh, :tnsa, :vaii, :wara, :wcho]","ref":"Cldr.html#known_number_systems/0-example"},{"type":"function","title":"Cldr.known_rbnf_locale_name/2","doc":"Returns either the RBNF `locale_name` or `false` based upon\nwhether the locale name is configured in `Cldr`\nand has RBNF rules defined.","ref":"Cldr.html#known_rbnf_locale_name/2"},{"type":"function","title":"Arguments - Cldr.known_rbnf_locale_name/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#known_rbnf_locale_name/2-arguments"},{"type":"function","title":"Examples - Cldr.known_rbnf_locale_name/2","doc":"iex> Cldr.known_rbnf_locale_name(:en, TestBackend.Cldr)\n    :en\n\n    iex> Cldr.known_rbnf_locale_name(:\"en-SA\", TestBackend.Cldr)\n    false","ref":"Cldr.html#known_rbnf_locale_name/2-examples"},{"type":"function","title":"Cldr.known_rbnf_locale_name?/2","doc":"Returns a boolean indicating if the specified locale\nname is configured and available in Cldr and supports\nrules based number formats (RBNF).","ref":"Cldr.html#known_rbnf_locale_name?/2"},{"type":"function","title":"Arguments - Cldr.known_rbnf_locale_name?/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#known_rbnf_locale_name?/2-arguments"},{"type":"function","title":"Examples - Cldr.known_rbnf_locale_name?/2","doc":"iex> Cldr.known_rbnf_locale_name?(:en, TestBackend.Cldr)\n    true\n\n    iex> Cldr.known_rbnf_locale_name?(:\"!!\", TestBackend.Cldr)\n    false","ref":"Cldr.html#known_rbnf_locale_name?/2-examples"},{"type":"function","title":"Cldr.known_rbnf_locale_names/1","doc":"Returns a list of locale names which have rules based number\nformats (RBNF).","ref":"Cldr.html#known_rbnf_locale_names/1"},{"type":"function","title":"Arguments - Cldr.known_rbnf_locale_names/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.html#known_rbnf_locale_names/1-arguments"},{"type":"function","title":"Cldr.known_territories/0","doc":"Returns a list of the territories known to `Cldr`.\n\nThe territories codes are defined in [UN M.49](https://en.wikipedia.org/wiki/UN_M.49)\nwhich defines both individual territories and enclosing territories. These enclosing\nterritories are defined for statistical purposes and do not relate to political\nalignment.\n\nFor example, the territory `:\"001\"` is defined as \"the world\".","ref":"Cldr.html#known_territories/0"},{"type":"function","title":"Example - Cldr.known_territories/0","doc":"iex> Cldr.known_territories()\n    [:\"001\", :\"002\", :\"003\", :\"005\", :\"009\", :\"011\", :\"013\", :\"014\", :\"015\", :\"017\",\n     :\"018\", :\"019\", :\"021\", :\"029\", :\"030\", :\"034\", :\"035\", :\"039\", :\"053\", :\"054\",\n     :\"057\", :\"061\", :\"142\", :\"143\", :\"145\", :\"150\", :\"151\", :\"154\", :\"155\", :\"202\",\n     :\"419\", :AC, :AD, :AE, :AF, :AG, :AI, :AL, :AM, :AO, :AQ, :AR, :AS, :AT, :AU,\n     :AW, :AX, :AZ, :BA, :BB, :BD, :BE, :BF, :BG, :BH, :BI, :BJ, :BL, :BM, :BN, :BO,\n     :BQ, :BR, :BS, :BT, :BV, :BW, :BY, :BZ, :CA, :CC, :CD, :CF, :CG, :CH, :CI, :CK,\n     :CL, :CM, :CN, :CO, :CP, :CQ, :CR, :CU, :CV, :CW, :CX, :CY, :CZ, :DE, :DG, :DJ,\n     :DK, :DM, :DO, :DZ, :EA, :EC, :EE, :EG, :EH, :ER, :ES, :ET, :EU, :EZ, :FI, :FJ,\n     :FK, :FM, :FO, :FR, :GA, :GB, :GD, :GE, :GF, :GG, :GH, :GI, :GL, :GM, :GN, :GP,\n     :GQ, :GR, :GS, :GT, :GU, :GW, :GY, :HK, :HM, :HN, :HR, :HT, :HU, :IC, :ID, :IE,\n     :IL, :IM, :IN, :IO, :IQ, :IR, :IS, :IT, :JE, :JM, :JO, :JP, :KE, :KG, :KH, :KI,\n     :KM, :KN, :KP, :KR, :KW, :KY, :KZ, :LA, :LB, :LC, :LI, :LK, :LR, :LS, :LT, :LU,\n     :LV, :LY, :MA, :MC, :MD, :ME, :MF, :MG, :MH, :MK, :ML, :MM, :MN, :MO, :MP, :MQ,\n     :MR, :MS, :MT, :MU, :MV, :MW, :MX, :MY, :MZ, :NA, :NC, :NE, :NF, :NG, :NI, :NL,\n     :NO, :NP, :NR, :NU, :NZ, :OM, :PA, :PE, :PF, :PG, :PH, :PK, :PL, :PM, :PN, :PR,\n     :PS, :PT, :PW, :PY, :QA, :QO, :RE, :RO, :RS, :RU, :RW, :SA, :SB, :SC, :SD, :SE,\n     :SG, :SH, :SI, :SJ, :SK, :SL, :SM, :SN, :SO, :SR, :SS, :ST, :SV, :SX, :SY, :SZ,\n     :TA, :TC, :TD, :TF, :TG, :TH, :TJ, :TK, :TL, :TM, :TN, :TO, :TR, :TT, :TV, :TW,\n     :TZ, :UA, :UG, :UM, :UN, :US, :UY, :UZ, :VA, :VC, :VE, :VG, :VI, :VN, :VU, :WF,\n     :WS, :XK, :YE, :YT, :ZA, :ZM, :ZW]","ref":"Cldr.html#known_territories/0-example"},{"type":"function","title":"Cldr.known_territory_subdivision_containment/0","doc":"Returns a map of territory subdivisions sith a list of\ntheir parent subdivisions and region.\n\nFor a description of territory subdivisions see\n`Cldr.known_territory_subdivisions/0`","ref":"Cldr.html#known_territory_subdivision_containment/0"},{"type":"function","title":"Cldr.known_territory_subdivisions/0","doc":"Returns the map of territories and subdivisions and their\nchild subdivsions.\n\nThe subdivision codes designate a subdivision of a country\nor region. They are called various names, such as a\nstate in the United States, or a province in Canada.\n\nThe codes in CLDR are based on ISO 3166-2 subdivision codes.\nThe ISO codes have a region code followed by a hyphen, then a\nsuffix consisting of 1..3 ASCII letters or digits.\n\nThe CLDR codes are designed to work in a unicode_locale_id\n(BCP47), and are thus all lowercase, with no hyphen. For\nexample, the following are valid, and mean “English as\nused in California, USA”.\n\n    en-u-sd-usca\n    en-US-u-sd-usca\n\nCLDR has additional subdivision codes. These may start with\na 3-digit region code or use a suffix of 4 ASCII letters or\ndigits, so they will not collide with the ISO codes. Subdivision\ncodes for unknown values are the region code plus \"zzzz\", such as\n\"uszzzz\" for an unknown subdivision of the US. Other codes may be\nadded for stability.","ref":"Cldr.html#known_territory_subdivisions/0"},{"type":"function","title":"Cldr.put_default_backend/1","doc":"Set the default system-wide backend module.","ref":"Cldr.html#put_default_backend/1"},{"type":"function","title":"Arguments - Cldr.put_default_backend/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.","ref":"Cldr.html#put_default_backend/1-arguments"},{"type":"function","title":"Returns - Cldr.put_default_backend/1","doc":"* `{:ok, backend}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.html#put_default_backend/1-returns"},{"type":"function","title":"Cldr.put_default_locale/1","doc":"Set's the system default locale.\n\nThe locale set here is the base level\nsystem default equivalent to setting the\n`:default_locale` key in `config.exs`.","ref":"Cldr.html#put_default_locale/1"},{"type":"function","title":"Arguments - Cldr.put_default_locale/1","doc":"* `locale` is a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n  with a non-nil `:cldr_locale_name`.","ref":"Cldr.html#put_default_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.put_default_locale/1","doc":"* `{:ok, locale}`","ref":"Cldr.html#put_default_locale/1-returns"},{"type":"function","title":"Cldr.put_default_locale/2","doc":"Sets the system default locale.\n\nThe locale set here is the base level\nsystem default equivalent to setting the\n`:default_locale` key in `config.exs`.","ref":"Cldr.html#put_default_locale/2"},{"type":"function","title":"Arguments - Cldr.put_default_locale/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.","ref":"Cldr.html#put_default_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.put_default_locale/2","doc":"* `{:ok, locale}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.html#put_default_locale/2-returns"},{"type":"function","title":"Cldr.put_gettext_locale/1","doc":"Set the current process's Gettext locale from a\n`t:Cldr.LanguageTag`.","ref":"Cldr.html#put_gettext_locale/1"},{"type":"function","title":"Arguments - Cldr.put_gettext_locale/1","doc":"* `locale` is a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`.","ref":"Cldr.html#put_gettext_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.put_gettext_locale/1","doc":"* `{:ok, gettext_locale_name}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.html#put_gettext_locale/1-returns"},{"type":"function","title":"Behaviour - Cldr.put_gettext_locale/1","doc":"1. If the `locale.gettext_locale_name` is `nil` then an error\n   is returned.\n\n2. The `gettext` locale for the `gettext_backend` configured for the\n   CLDR backend defined by the `t:Cldr.LanguageTag` is set.","ref":"Cldr.html#put_gettext_locale/1-behaviour"},{"type":"function","title":"Examples - Cldr.put_gettext_locale/1","doc":"iex> import Cldr.LanguageTag.Sigil\n    iex> Cldr.put_gettext_locale(~l\"en\")\n    {:ok, \"en\"}\n\n    iex> import Cldr.LanguageTag.Sigil\n    iex> Cldr.put_gettext_locale(~l\"de\")\n    {\n      :error,\n      {\n        Cldr.UnknownLocaleError,\n        \"Locale TestBackend.Cldr.Locale.new!(\\\"de-DE\\\") does not map to a known gettext locale name\"\n      }\n    }","ref":"Cldr.html#put_gettext_locale/1-examples"},{"type":"function","title":"Cldr.put_locale/2","doc":"Set the current process's locale for a specified backend or\nfor all backends.","ref":"Cldr.html#put_locale/2"},{"type":"function","title":"Arguments - Cldr.put_locale/2","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is to set the locale\n  for all backends.\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`. It may\n  also be a map that contains the keys `\"cldr_locale\"` and `\"cldr_backend\"`\n  which is the shape of a `Phoenix` and `Plug` session making it easy to\n  set the locale from a session.","ref":"Cldr.html#put_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.put_locale/2","doc":"* `{:ok, locale}`","ref":"Cldr.html#put_locale/2-returns"},{"type":"function","title":"Behaviour - Cldr.put_locale/2","doc":"1. If no backend is provided and the locale is a `Cldr.LanguageTag.t`\nthen the the locale is set as the default for the current process","ref":"Cldr.html#put_locale/2-behaviour"},{"type":"function","title":"Notes - Cldr.put_locale/2","doc":"See [rfc5646](https://tools.ietf.org/html/rfc5646) for the specification\nof a language tag","ref":"Cldr.html#put_locale/2-notes"},{"type":"function","title":"Examples - Cldr.put_locale/2","doc":"iex> Cldr.put_locale(TestBackend.Cldr, \"en\")\n    {:ok,\n     %Cldr.LanguageTag{\n       backend: TestBackend.Cldr,\n       canonical_locale_name: \"en\",\n       cldr_locale_name: :en,\n       language_subtags: [],\n       extensions: %{},\n       gettext_locale_name: \"en\",\n       language: \"en\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :en,\n       requested_locale_name: \"en\",\n       script: :Latn,\n       territory: :US,\n       transform: %{},\n       language_variants: []\n     }}\n\n    iex> Cldr.put_locale(TestBackend.Cldr, \"invalid-locale!\")\n    {:error, {Cldr.LanguageTag.ParseError,\n      \"Expected a BCP47 language tag. Could not parse the remaining \\\"!\\\" starting at position 15\"}}","ref":"Cldr.html#put_locale/2-examples"},{"type":"function","title":"Cldr.quote/3","doc":"Add locale-specific quotation marks around a string.","ref":"Cldr.html#quote/3"},{"type":"function","title":"Arguments - Cldr.quote/3","doc":"* `string` is any valid Elixir string\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.\n\n* `options` is a keyword list of options","ref":"Cldr.html#quote/3-arguments"},{"type":"function","title":"Options - Cldr.quote/3","doc":"* `:locale` is any valid locale name returned by `Cldr.known_locale_names/1`.\n  The default is `Cldr.get_locale/0`\n\n* `:prefer` is one of `:default` or `:variant` with a default of `:default`.\n  Some locales have alternative opening and closing quote marks and `:prefer`\n  allows selecting a variant should one exist.","ref":"Cldr.html#quote/3-options"},{"type":"function","title":"Examples - Cldr.quote/3","doc":"iex> Cldr.quote(\"Quoted String\", MyApp.Cldr)\n    \"“Quoted String”\"\n\n    iex> Cldr.quote(\"Quoted String\", MyApp.Cldr, prefer: :variant)\n    \"‘Quoted String’\"\n\n    iex> Cldr.quote(\"Quoted String\", MyApp.Cldr, locale: \"ja\")\n    \"「Quoted String」\"","ref":"Cldr.html#quote/3-examples"},{"type":"function","title":"Cldr.requested_locale_names/1","doc":"Returns a list of all requested locale names.","ref":"Cldr.html#requested_locale_names/1"},{"type":"function","title":"Arguments - Cldr.requested_locale_names/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.\n\nThe list is the combination of configured locales,\n`Gettext` locales and the default locale.\n\nSee also `known_locales/1` and `all_locales/0`.","ref":"Cldr.html#requested_locale_names/1-arguments"},{"type":"function","title":"Cldr.territory_chain/1","doc":"Return the territory fallback chain based upon\na locales territory (including `u` extension) and\nterritory containment definitions.\n\nWhile CLDR also includes subdivisions in the\nterritory chain, this implementation does not\nconsider them.","ref":"Cldr.html#territory_chain/1"},{"type":"function","title":"Arguments - Cldr.territory_chain/1","doc":"* `territory` is either a binary or atom territory code\n  or a `t:Cldr.LanguageTag`","ref":"Cldr.html#territory_chain/1-arguments"},{"type":"function","title":"Returns - Cldr.territory_chain/1","doc":"* `{:ok, list}` where `list` is a list of territories\n  in decreasing order of containment (ie larger enclosing\n  areas) or\n\n* `{:error, {exception, reason}}` indicating an error","ref":"Cldr.html#territory_chain/1-returns"},{"type":"function","title":"Examples - Cldr.territory_chain/1","doc":"iex> Cldr.territory_chain \"US\"\n    {:ok, [:US, :\"021\", :\"019\", :\"001\"]}\n\n    iex> Cldr.territory_chain :AU\n    {:ok, [:AU, :\"053\", :\"009\", :\"001\"]}\n\n    iex> {:ok, locale} = Cldr.validate_locale(\"en-US-u-rg-CAzzzz\", MyApp.Cldr)\n    iex> Cldr.territory_chain locale\n    {:ok, [:CA, :\"021\", :\"019\", :\"001\"]}\n\n    iex> Cldr.territory_chain :\"001\"\n    {:ok, [:\"001\"]}","ref":"Cldr.html#territory_chain/1-examples"},{"type":"function","title":"Cldr.territory_chain/2","doc":"Return the territory fallback chain based upon\na locales territory (including `u` extension) and\nterritory containment definitions.\n\nWhile CLDR also includes subdivisions in the\nterritory chain, this implementation does not\nconsider them.","ref":"Cldr.html#territory_chain/2"},{"type":"function","title":"Arguments - Cldr.territory_chain/2","doc":"* `locale` is a binary locale name\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.","ref":"Cldr.html#territory_chain/2-arguments"},{"type":"function","title":"Returns - Cldr.territory_chain/2","doc":"* `{:ok, list}` where `list` is a list of territories\n  in decreasing order of containment (ie larger enclosing\n  areas) or\n\n* `{:error, {exception, reason}}` indicating an error","ref":"Cldr.html#territory_chain/2-returns"},{"type":"function","title":"Examples - Cldr.territory_chain/2","doc":"iex> Cldr.territory_chain \"en-US-u-rg-CAzzzz\", MyApp.Cldr\n    {:ok, [:CA, :\"021\", :\"019\", :\"001\"]}","ref":"Cldr.html#territory_chain/2-examples"},{"type":"function","title":"Cldr.territory_containment/0","doc":"Returns a map of territories and the territories\nwithin which they are contained.","ref":"Cldr.html#territory_containment/0"},{"type":"function","title":"Cldr.the_world/0","doc":"Returns the territory for the world\n\nThis is the outermost containment of\nterritories in CLDR.\n\nCLDR does not yet consider non-terrestrial\nterritories.","ref":"Cldr.html#the_world/0"},{"type":"function","title":"Cldr.to_string/1","doc":"Return a localsed string for types\nthat implement the `Cldr.Chars` protocol.\n\nThe `Cldr.Chars` protocol is implemented in this\nlibrary for `t:Cldr.LanguageTag.t()`.\n\nOther CLDR-related libraries implement\nthe protocol for the types they support\nsuch as `Float`, `Integer`, `Decimal`,\n`Money`, `Unit` and `List`.","ref":"Cldr.html#to_string/1"},{"type":"function","title":"Cldr.unknown_calendar_error/1","doc":"Returns an error tuple for an invalid calendar.","ref":"Cldr.html#unknown_calendar_error/1"},{"type":"function","title":"Arguments - Cldr.unknown_calendar_error/1","doc":"* `calendar` is any calendar name **not** returned by `Cldr.known_calendars/0`","ref":"Cldr.html#unknown_calendar_error/1-arguments"},{"type":"function","title":"Returns - Cldr.unknown_calendar_error/1","doc":"* `{:error, {Cldr.UnknownCalendarError, message}}`","ref":"Cldr.html#unknown_calendar_error/1-returns"},{"type":"function","title":"Examples - Cldr.unknown_calendar_error/1","doc":"iex> Cldr.unknown_calendar_error(\"invalid\")\n    {Cldr.UnknownCalendarError, \"The calendar name \\\"invalid\\\" is invalid\"}","ref":"Cldr.html#unknown_calendar_error/1-examples"},{"type":"function","title":"Cldr.unknown_currency_error/1","doc":"Returns an error tuple for an invalid currency.","ref":"Cldr.html#unknown_currency_error/1"},{"type":"function","title":"Arguments - Cldr.unknown_currency_error/1","doc":"* `currency` is any currency code **not** returned by `Cldr.known_currencies/0`","ref":"Cldr.html#unknown_currency_error/1-arguments"},{"type":"function","title":"Returns - Cldr.unknown_currency_error/1","doc":"* `{:error, {Cldr.UnknownCurrencyError, message}}`","ref":"Cldr.html#unknown_currency_error/1-returns"},{"type":"function","title":"Examples - Cldr.unknown_currency_error/1","doc":"iex> Cldr.unknown_currency_error(\"invalid\")\n    {Cldr.UnknownCurrencyError, \"The currency \\\"invalid\\\" is invalid\"}","ref":"Cldr.html#unknown_currency_error/1-examples"},{"type":"function","title":"Cldr.unknown_locale_names/1","doc":"Returns a list of the locales names that are configured,\nbut not known in CLDR.","ref":"Cldr.html#unknown_locale_names/1"},{"type":"function","title":"Arguments - Cldr.unknown_locale_names/1","doc":"* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.\n\nSince there is a compile-time exception raise if there are\nany unknown locales this function should always\nreturn an empty list.","ref":"Cldr.html#unknown_locale_names/1-arguments"},{"type":"function","title":"Cldr.unknown_number_system_error/1","doc":"Returns an error tuple for an unknown number system.","ref":"Cldr.html#unknown_number_system_error/1"},{"type":"function","title":"Arguments - Cldr.unknown_number_system_error/1","doc":"* `number_system` is any number system name **not** returned by `Cldr.known_number_systems/0`","ref":"Cldr.html#unknown_number_system_error/1-arguments"},{"type":"function","title":"Returns - Cldr.unknown_number_system_error/1","doc":"* `{:error, {Cldr.UnknownNumberSystemError, message}}`","ref":"Cldr.html#unknown_number_system_error/1-returns"},{"type":"function","title":"Examples - Cldr.unknown_number_system_error/1","doc":"iex> Cldr.unknown_number_system_error \"invalid\"\n    {Cldr.UnknownNumberSystemError, \"The number system \\\"invalid\\\" is invalid\"}\n\n    iex> Cldr.unknown_number_system_error :invalid\n    {Cldr.UnknownNumberSystemError, \"The number system :invalid is unknown\"}","ref":"Cldr.html#unknown_number_system_error/1-examples"},{"type":"function","title":"Cldr.unknown_number_system_type_error/1","doc":"Returns an error tuple for an unknown number system type.","ref":"Cldr.html#unknown_number_system_type_error/1"},{"type":"function","title":"Options - Cldr.unknown_number_system_type_error/1","doc":"* `number_system_type` is any number system type name **not** returned\n  by `Cldr.known_number_system_types/1`","ref":"Cldr.html#unknown_number_system_type_error/1-options"},{"type":"function","title":"Returns - Cldr.unknown_number_system_type_error/1","doc":"* `{:error, {Cldr.UnknownNumberSystemTypeError, message}}`","ref":"Cldr.html#unknown_number_system_type_error/1-returns"},{"type":"function","title":"Examples - Cldr.unknown_number_system_type_error/1","doc":"iex> Cldr.unknown_number_system_type_error(\"invalid\")\n    {Cldr.UnknownNumberSystemTypeError, \"The number system type \\\"invalid\\\" is invalid\"}\n\n    iex> Cldr.unknown_number_system_type_error(:invalid)\n    {Cldr.UnknownNumberSystemTypeError, \"The number system type :invalid is unknown\"}","ref":"Cldr.html#unknown_number_system_type_error/1-examples"},{"type":"function","title":"Cldr.unknown_plural_type_error/1","doc":"Returns an error tuple for an unknown plural type.","ref":"Cldr.html#unknown_plural_type_error/1"},{"type":"function","title":"Options - Cldr.unknown_plural_type_error/1","doc":"* `plural_type` is any unknown number system type","ref":"Cldr.html#unknown_plural_type_error/1-options"},{"type":"function","title":"Returns - Cldr.unknown_plural_type_error/1","doc":"* `{:error, {Cldr.UnknownPluralTypeError, message}}`","ref":"Cldr.html#unknown_plural_type_error/1-returns"},{"type":"function","title":"Examples - Cldr.unknown_plural_type_error/1","doc":"iex> Cldr.unknown_plural_type_error(\"invalid\")\n    {Cldr.UnknownPluralTypeError, \"The plural type \\\"invalid\\\" is invalid\"}\n\n    iex> Cldr.unknown_plural_type_error(:invalid)\n    {Cldr.UnknownPluralTypeError, \"The plural type :invalid is unknown\"}","ref":"Cldr.html#unknown_plural_type_error/1-examples"},{"type":"function","title":"Cldr.unknown_script_error/1","doc":"Returns an error tuple for an invalid script.","ref":"Cldr.html#unknown_script_error/1"},{"type":"function","title":"Arguments - Cldr.unknown_script_error/1","doc":"* `script` is any script as a string or an atom","ref":"Cldr.html#unknown_script_error/1-arguments"},{"type":"function","title":"Returns - Cldr.unknown_script_error/1","doc":"* `{:error, {Cldr.InvalidScriptError, message}}`","ref":"Cldr.html#unknown_script_error/1-returns"},{"type":"function","title":"Examples - Cldr.unknown_script_error/1","doc":"iex> Cldr.unknown_script_error \"invalid\"\n    {Cldr.InvalidScriptError, \"The script \\\"invalid\\\" is invalid\"}\n\n    iex> Cldr.unknown_script_error :invalid\n    {Cldr.InvalidScriptError, \"The script :invalid is invalid\"}","ref":"Cldr.html#unknown_script_error/1-examples"},{"type":"function","title":"Cldr.unknown_territory_error/1","doc":"Returns an error tuple for an unknown territory.","ref":"Cldr.html#unknown_territory_error/1"},{"type":"function","title":"Arguments - Cldr.unknown_territory_error/1","doc":"* `territory` is any territory code **not** returned by `Cldr.known_territories/0`","ref":"Cldr.html#unknown_territory_error/1-arguments"},{"type":"function","title":"Returns - Cldr.unknown_territory_error/1","doc":"* `{:error, {Cldr.UnknownTerritoryError, message}}`","ref":"Cldr.html#unknown_territory_error/1-returns"},{"type":"function","title":"Examples - Cldr.unknown_territory_error/1","doc":"iex> Cldr.unknown_territory_error(\"invalid\")\n    {Cldr.UnknownTerritoryError, \"The territory \\\"invalid\\\" is unknown\"}","ref":"Cldr.html#unknown_territory_error/1-examples"},{"type":"function","title":"Cldr.validate_backend/1","doc":"Validates that a module is a CLDR backend module.","ref":"Cldr.html#validate_backend/1"},{"type":"function","title":"Arguments - Cldr.validate_backend/1","doc":"* `backend` is any module name that may be a\n  `Cldr` backend module.","ref":"Cldr.html#validate_backend/1-arguments"},{"type":"function","title":"Returns - Cldr.validate_backend/1","doc":"* `{:ok, backend}` is the module if a CLDR backend module or\n\n* `{:error, {exception, reason}}` if the module is unknown or if\n  the module is not a backend module.","ref":"Cldr.html#validate_backend/1-returns"},{"type":"function","title":"Examples - Cldr.validate_backend/1","doc":"iex> Cldr.validate_backend MyApp.Cldr\n    {:ok, MyApp.Cldr}\n\n    iex> Cldr.validate_backend :something_else\n    {:error,\n     {Cldr.UnknownBackendError,\n      \"The backend :something_else is not known or not a backend module.\"}}","ref":"Cldr.html#validate_backend/1-examples"},{"type":"function","title":"Cldr.validate_calendar/1","doc":"Normalise and validate a calendar name.","ref":"Cldr.html#validate_calendar/1"},{"type":"function","title":"Arguments - Cldr.validate_calendar/1","doc":"* `calendar` is any calendar name returned by `Cldr.known_calendars/0`","ref":"Cldr.html#validate_calendar/1-arguments"},{"type":"function","title":"Returns - Cldr.validate_calendar/1","doc":"* `{:ok, normalized_calendar_name}` or\n\n* `{:error, {Cldr.UnknownCalendarError, message}}`","ref":"Cldr.html#validate_calendar/1-returns"},{"type":"function","title":"Examples - Cldr.validate_calendar/1","doc":"iex> Cldr.validate_calendar(:gregorian)\n    {:ok, :gregorian}\n\n    iex> Cldr.validate_calendar(:invalid)\n    {:error, {Cldr.UnknownCalendarError, \"The calendar name :invalid is invalid\"}}","ref":"Cldr.html#validate_calendar/1-examples"},{"type":"function","title":"Cldr.validate_currency/1","doc":"Normalize and validate a currency code.","ref":"Cldr.html#validate_currency/1"},{"type":"function","title":"Arguments - Cldr.validate_currency/1","doc":"* `currency` is any ISO 4217 currency code as returned by `Cldr.known_currencies/0`\n  or any valid private use ISO4217 code which is a three-letter alphabetic code that\n  starts with \"X\".","ref":"Cldr.html#validate_currency/1-arguments"},{"type":"function","title":"Returns - Cldr.validate_currency/1","doc":"* `{:ok, normalized_currency_code}` or\n\n* `{:error, {Cldr.UnknownCurrencyError, message}}`","ref":"Cldr.html#validate_currency/1-returns"},{"type":"function","title":"Examples - Cldr.validate_currency/1","doc":"iex> Cldr.validate_currency(:USD)\n    {:ok, :USD}\n\n    iex> Cldr.validate_currency(\"USD\")\n    {:ok, :USD}\n\n    iex> Cldr.validate_currency(:XTC)\n    {:ok, :XTC}\n\n    iex> Cldr.validate_currency(\"xtc\")\n    {:ok, :XTC}\n\n    iex> Cldr.validate_currency(\"invalid\")\n    {:error, {Cldr.UnknownCurrencyError, \"The currency \\\"invalid\\\" is invalid\"}}\n\n    iex> Cldr.validate_currency(:invalid)\n    {:error, {Cldr.UnknownCurrencyError, \"The currency :invalid is invalid\"}}","ref":"Cldr.html#validate_currency/1-examples"},{"type":"function","title":"Cldr.validate_gettext_locale/2","doc":"Normalise and validate a gettext locale name.","ref":"Cldr.html#validate_gettext_locale/2"},{"type":"function","title":"Arguments - Cldr.validate_gettext_locale/2","doc":"* `locale_name` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend/0`.\n  Note that `Cldr.default_backend/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#validate_gettext_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.validate_gettext_locale/2","doc":"* `{:ok, language_tag}`\n\n* `{:error, reason}`","ref":"Cldr.html#validate_gettext_locale/2-returns"},{"type":"function","title":"Examples - Cldr.validate_gettext_locale/2","doc":"","ref":"Cldr.html#validate_gettext_locale/2-examples"},{"type":"function","title":"Cldr.validate_locale/2","doc":"Normalise and validate a locale name.","ref":"Cldr.html#validate_locale/2"},{"type":"function","title":"Arguments - Cldr.validate_locale/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#validate_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.validate_locale/2","doc":"* `{:ok, language_tag}`\n\n* `{:error, reason}`","ref":"Cldr.html#validate_locale/2-returns"},{"type":"function","title":"Examples - Cldr.validate_locale/2","doc":"iex> Cldr.validate_locale(:en, TestBackend.Cldr)\n    {:ok,\n    %Cldr.LanguageTag{\n      backend: TestBackend.Cldr,\n      canonical_locale_name: \"en\",\n      cldr_locale_name: :en,\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en\",\n      script: :Latn,\n      territory: :US,\n      transform: %{},\n      language_variants: []\n    }}\n\n    iex> Cldr.validate_locale(:af, TestBackend.Cldr)\n    {:ok,\n    %Cldr.LanguageTag{\n      backend: TestBackend.Cldr,\n      canonical_locale_name: \"af\",\n      cldr_locale_name: :af,\n      extensions: %{},\n      gettext_locale_name: nil,\n      language: \"af\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :af,\n      requested_locale_name: \"af\",\n      script: :Latn,\n      territory: :ZA,\n      transform: %{},\n      language_variants: []\n    }}\n\n    iex> Cldr.validate_locale(\"zzz\", TestBackend.Cldr)\n    {:error, {Cldr.InvalidLanguageError, \"The language \\\"zzz\\\" is invalid\"}}","ref":"Cldr.html#validate_locale/2-examples"},{"type":"function","title":"Cldr.validate_locale!/2","doc":"Normalise and validate a locale name or raises\nan exception.","ref":"Cldr.html#validate_locale!/2"},{"type":"function","title":"Arguments - Cldr.validate_locale!/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n  Note that `Cldr.default_backend!/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#validate_locale!/2-arguments"},{"type":"function","title":"Returns - Cldr.validate_locale!/2","doc":"* `language_tag` or\n\n* raises an exception","ref":"Cldr.html#validate_locale!/2-returns"},{"type":"function","title":"Examples - Cldr.validate_locale!/2","doc":"iex> Cldr.validate_locale!(:en, TestBackend.Cldr)\n    %Cldr.LanguageTag{\n      backend: TestBackend.Cldr,\n      canonical_locale_name: \"en\",\n      cldr_locale_name: :en,\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en\",\n      script: :Latn,\n      territory: :US,\n      transform: %{},\n      language_variants: []\n    }\n\n    iex> Cldr.validate_locale!(:af, TestBackend.Cldr)\n    %Cldr.LanguageTag{\n      backend: TestBackend.Cldr,\n      canonical_locale_name: \"af\",\n      cldr_locale_name: :af,\n      extensions: %{},\n      gettext_locale_name: nil,\n      language: \"af\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :af,\n      requested_locale_name: \"af\",\n      script: :Latn,\n      territory: :ZA,\n      transform: %{},\n      language_variants: []\n    }\n\n    iex> Cldr.validate_locale!(\"zzz\", TestBackend.Cldr)\n    ** (Cldr.InvalidLanguageError) The language \"zzz\" is invalid","ref":"Cldr.html#validate_locale!/2-examples"},{"type":"function","title":"Cldr.validate_measurement_system/1","doc":"Normalise and validate a measurement system type.","ref":"Cldr.html#validate_measurement_system/1"},{"type":"function","title":"Arguments - Cldr.validate_measurement_system/1","doc":"* `measurement_system` is a known\n  measurement system.","ref":"Cldr.html#validate_measurement_system/1-arguments"},{"type":"function","title":"Returns - Cldr.validate_measurement_system/1","doc":"* `{:ok, normalized_measurement_system}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.html#validate_measurement_system/1-returns"},{"type":"function","title":"Examples - Cldr.validate_measurement_system/1","doc":"iex> Cldr.validate_measurement_system :metric\n    {:ok, :metric}\n\n    iex> Cldr.validate_measurement_system \"ussystem\"\n    {:ok, :ussystem}\n\n    iex> Cldr.validate_measurement_system \"uksystem\"\n    {:ok, :uksystem}\n\n    iex> Cldr.validate_measurement_system \"something\"\n    {:error, {Cldr.UnknownMeasurementSystemError,\n     \"The measurement system \\\"something\\\" is invalid\"}}","ref":"Cldr.html#validate_measurement_system/1-examples"},{"type":"function","title":"Cldr.validate_number_system/1","doc":"Normalize and validate a number system name.","ref":"Cldr.html#validate_number_system/1"},{"type":"function","title":"Arguments - Cldr.validate_number_system/1","doc":"* `number_system` is any number system name returned by\n  `Cldr.known_number_systems/0`","ref":"Cldr.html#validate_number_system/1-arguments"},{"type":"function","title":"Returns - Cldr.validate_number_system/1","doc":"* `{:ok, normalized_number_system_name}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.html#validate_number_system/1-returns"},{"type":"function","title":"Examples - Cldr.validate_number_system/1","doc":"iex> Cldr.validate_number_system :latn\n    {:ok, :latn}\n\n    iex> Cldr.validate_number_system :arab\n    {:ok, :arab}\n\n    iex> Cldr.validate_number_system \"invalid\"\n    {\n      :error,\n      {Cldr.UnknownNumberSystemError, \"The number system :invalid is unknown\"}\n    }","ref":"Cldr.html#validate_number_system/1-examples"},{"type":"function","title":"Cldr.validate_number_system_type/2","doc":"Normalise and validate a number system type.","ref":"Cldr.html#validate_number_system_type/2"},{"type":"function","title":"Arguments - Cldr.validate_number_system_type/2","doc":"* `number_system_type` is any number system type returned by\n  `Cldr.known_number_system_types/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend/0`.\n  Note that `Cldr.default_backend/0` will raise an exception if\n  no `:default_backend` is configured under the `:ex_cldr` key in\n  `config.exs`.","ref":"Cldr.html#validate_number_system_type/2-arguments"},{"type":"function","title":"Returns - Cldr.validate_number_system_type/2","doc":"* `{:ok, normalized_number_system_type}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.html#validate_number_system_type/2-returns"},{"type":"function","title":"Examples - Cldr.validate_number_system_type/2","doc":"iex> Cldr.validate_number_system_type(:default, TestBackend.Cldr)\n    {:ok, :default}\n\n    iex> Cldr.validate_number_system_type(:traditional, TestBackend.Cldr)\n    {:ok, :traditional}\n\n    iex> Cldr.validate_number_system_type(:latn, TestBackend.Cldr)\n    {\n      :error,\n      {Cldr.UnknownNumberSystemTypeError, \"The number system type :latn is unknown\"}\n    }","ref":"Cldr.html#validate_number_system_type/2-examples"},{"type":"function","title":"Cldr.validate_plural_type/1","doc":"Normalize and validate a plural type.","ref":"Cldr.html#validate_plural_type/1"},{"type":"function","title":"Arguments - Cldr.validate_plural_type/1","doc":"* `plural_type` is any plural type returned by\n  `Cldr.Number.PluralRule.known_plural_types/0`","ref":"Cldr.html#validate_plural_type/1-arguments"},{"type":"function","title":"Returns - Cldr.validate_plural_type/1","doc":"* `{:ok, normalized_plural_type}` or\n\n* `{:error, {exception, message}}`","ref":"Cldr.html#validate_plural_type/1-returns"},{"type":"function","title":"Examples - Cldr.validate_plural_type/1","doc":"iex> Cldr.validate_plural_type :few\n    {:ok, :few}\n\n    iex> Cldr.validate_plural_type \"one\"\n    {:ok, :one}\n\n    iex> Cldr.validate_plural_type \"invalid\"\n    {\n      :error,\n      {Cldr.UnknownPluralTypeError, \"The plural type :invalid is unknown\"}\n    }","ref":"Cldr.html#validate_plural_type/1-examples"},{"type":"function","title":"Cldr.validate_script/1","doc":"Normalise and validate a script code.","ref":"Cldr.html#validate_script/1"},{"type":"function","title":"Arguments - Cldr.validate_script/1","doc":"* `script` is any script code as a binary\n  or atom","ref":"Cldr.html#validate_script/1-arguments"},{"type":"function","title":"Returns: - Cldr.validate_script/1","doc":"* `{:ok, normalized_script_code}` or\n\n* `{:error, {Cldr.UnknownscriptError, message}}`","ref":"Cldr.html#validate_script/1-returns"},{"type":"function","title":"Examples - Cldr.validate_script/1","doc":"iex> Cldr.validate_script(\"thai\")\n    {:ok, :Thai}\n\n    iex> Cldr.validate_script(\"qaai\")\n    {:ok, :Zinh}\n\n    iex> Cldr.validate_script(Cldr.Locale.new!(\"en\", TestBackend.Cldr))\n    {:ok, :Latn}\n\n    iex> Cldr.validate_script(\"aaaa\")\n    {:error, {Cldr.InvalidScriptError, \"The script \\\"aaaa\\\" is invalid\"}}\n\n    iex> Cldr.validate_script(%{})\n    {:error, {Cldr.InvalidScriptError, \"The script %{} is invalid\"}}","ref":"Cldr.html#validate_script/1-examples"},{"type":"function","title":"Cldr.validate_territory/1","doc":"Normalise and validate a territory code.","ref":"Cldr.html#validate_territory/1"},{"type":"function","title":"Arguments - Cldr.validate_territory/1","doc":"* `territory` is any territory code returned by `Cldr.known_territories/0`","ref":"Cldr.html#validate_territory/1-arguments"},{"type":"function","title":"Returns: - Cldr.validate_territory/1","doc":"* `{:ok, normalized_territory_code}` or\n\n* `{:error, {Cldr.UnknownTerritoryError, message}}`","ref":"Cldr.html#validate_territory/1-returns"},{"type":"function","title":"Examples - Cldr.validate_territory/1","doc":"iex> Cldr.validate_territory(\"en\")\n    {:error, {Cldr.UnknownTerritoryError, \"The territory \\\"en\\\" is unknown\"}}\n\n    iex> Cldr.validate_territory(\"gb\")\n    {:ok, :GB}\n\n    iex> Cldr.validate_territory(\"001\")\n    {:ok, :\"001\"}\n\n    iex> Cldr.validate_territory(Cldr.Locale.new!(\"en\", TestBackend.Cldr))\n    {:ok, :US}\n\n    iex> Cldr.validate_territory(%{})\n    {:error, {Cldr.UnknownTerritoryError, \"The territory %{} is unknown\"}}","ref":"Cldr.html#validate_territory/1-examples"},{"type":"function","title":"Cldr.validate_territory_subdivision/1","doc":"Normalise and validate a territory subdivision code.","ref":"Cldr.html#validate_territory_subdivision/1"},{"type":"function","title":"Arguments - Cldr.validate_territory_subdivision/1","doc":"* `subdivision` is any territory code returned by `Cldr.known_territory_subdivisions/0`","ref":"Cldr.html#validate_territory_subdivision/1-arguments"},{"type":"function","title":"Returns: - Cldr.validate_territory_subdivision/1","doc":"* `{:ok, normalized_subdivision_code}` or\n\n* `{:error, {Cldr.UnknownTerritoryError, message}}`","ref":"Cldr.html#validate_territory_subdivision/1-returns"},{"type":"function","title":"Examples - Cldr.validate_territory_subdivision/1","doc":"","ref":"Cldr.html#validate_territory_subdivision/1-examples"},{"type":"function","title":"Cldr.version/0","doc":"Returns the version of the CLDR repository.","ref":"Cldr.html#version/0"},{"type":"function","title":"Example - Cldr.version/0","doc":"iex> Cldr.version()\n    Version.parse!(\"47.0.0\")","ref":"Cldr.html#version/0-example"},{"type":"function","title":"Cldr.with_locale/2","doc":"Execute a function with a locale ensuring that the\ncurrent locale is restored after the function.","ref":"Cldr.html#with_locale/2"},{"type":"function","title":"Arguments - Cldr.with_locale/2","doc":"* `locale` is any `t:Cldr.LanguageTag.t/0`, tyically returned\n  by `Cldr.validate_locale/2`.\n\n* `fun` is any 0-arity function or function capture.","ref":"Cldr.html#with_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.with_locale/2","doc":"* The value returned by the function `fun/0` or\n\n* raises an exception if the current locale cannot be\n  identified.","ref":"Cldr.html#with_locale/2-returns"},{"type":"function","title":"Cldr.with_locale/3","doc":"Execute a function with a locale ensuring that the\ncurrent locale is restored after the function.","ref":"Cldr.html#with_locale/3"},{"type":"function","title":"Arguments - Cldr.with_locale/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a string locale name.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is `Cldr.default_backend!/0`.\n\n* `fun` is any 0-arity function or function capture.","ref":"Cldr.html#with_locale/3-arguments"},{"type":"function","title":"Returns - Cldr.with_locale/3","doc":"* The value returned by the function `fun/0` or\n\n* `{:error, {exception, reason}}` if the locale is invalid or\n\n* raises an exception if the current locale cannot be\n  identified.","ref":"Cldr.html#with_locale/3-returns"},{"type":"module","title":"Cldr.AcceptLanguage","doc":"Tokenizer and parser for HTTP `Accept-Language` header values as defined in\n[rfc2616](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4).\n\nThe Accept-Language request-header field is similar to Accept, but restricts\nthe set of natural languages that are preferred as a response to the request.\nLanguage tags function are provided in `Cldr.LanguageTag`.\n\nThe format of an `Accept-Language` header is as follows in `ABNF` format:\n\n       Accept-Language = \"Accept-Language\" \":\"\n                         1#( language-range [ \";\" \"q\" \"=\" qvalue ] )\n       language-range  = ( ( 1*8ALPHA *( \"-\" 1*8ALPHA ) ) | \"*\" )\n\nEach language-range MAY be given an associated quality value which represents an\nestimate of the user's preference for the languages specified by that range. The\nquality value defaults to \"q=1\". For example,\n\n       Accept-Language: da, en-gb;q=0.8, en;q=0.7\n\nwould mean: \"I prefer Danish, but will accept British English and other types of English.\"","ref":"Cldr.AcceptLanguage.html"},{"type":"function","title":"Cldr.AcceptLanguage.best_match/2","doc":"Parse an `Accept-Language` string and return the best match for\na configured `Cldr` locale.\n\n* `accept_language` is a string representing an accept language header\n\nReturns:\n\n* `{:ok, language_tag}` or\n\n* `{:error, reason}`","ref":"Cldr.AcceptLanguage.html#best_match/2"},{"type":"function","title":"Examples - Cldr.AcceptLanguage.best_match/2","doc":"iex> Cldr.AcceptLanguage.best_match(\"da;q=0.1,zh-TW;q=0.3\", TestBackend.Cldr)\n    {:ok,\n     %Cldr.LanguageTag{\n       backend: TestBackend.Cldr,\n       canonical_locale_name: \"zh-TW\",\n       cldr_locale_name: :\"zh-Hant\",\n       language_subtags: [],\n       extensions: %{},\n       gettext_locale_name: nil,\n       language: \"zh\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :\"zh-Hant\",\n       requested_locale_name: \"zh-TW\",\n       script: :Hant,\n       territory: :TW,\n       transform: %{},\n       language_variants: []\n     }}\n\n    iex> Cldr.AcceptLanguage.best_match(\"da;q=0.1,zh-TW;q=0.3\", TestBackend.Cldr)\n    {:ok,\n     %Cldr.LanguageTag{\n       backend: TestBackend.Cldr,\n       canonical_locale_name: \"zh-TW\",\n       cldr_locale_name: :\"zh-Hant\",\n       language_subtags: [],\n       extensions: %{},\n       gettext_locale_name: nil,\n       language: \"zh\",\n       locale: %{},\n       private_use: [],\n       rbnf_locale_name: :\"zh-Hant\",\n       requested_locale_name: \"zh-TW\",\n       script: :Hant,\n       territory: :TW,\n       transform: %{},\n       language_variants: []\n     }}\n\n    iex> Cldr.AcceptLanguage.best_match(\"xx,yy;q=0.3\", TestBackend.Cldr)\n    {:error,\n     {Cldr.NoMatchingLocale,\n      \"No configured locale could be matched to \\\"xx,yy;q=0.3\\\"\"}}\n\n    iex> Cldr.AcceptLanguage.best_match(\"invalid_tag\", TestBackend.Cldr)\n    {:error, {Cldr.LanguageTag.ParseError,\n      \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}","ref":"Cldr.AcceptLanguage.html#best_match/2-examples"},{"type":"function","title":"Cldr.AcceptLanguage.errors/1","doc":"Filters the returned results of `parse/1` to return\nonly the error tuples.","ref":"Cldr.AcceptLanguage.html#errors/1"},{"type":"function","title":"Example - Cldr.AcceptLanguage.errors/1","doc":"iex> Cldr.AcceptLanguage.parse!(\"da,zh-TW;q=0.3,invalid_tag\", TestBackend.Cldr)\n    ...> |> Cldr.AcceptLanguage.errors\n    [\n      error: {Cldr.LanguageTag.ParseError,\n      \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}\n    ]","ref":"Cldr.AcceptLanguage.html#errors/1-example"},{"type":"function","title":"Cldr.AcceptLanguage.parse/2","doc":"Parses an `Accept-Language` header value in its string\nor tokenized form to return a tuple of the form\n`{:ok, [{quality, %Cldr.LanguageTag{}}, ...]}` sorted by quality.","ref":"Cldr.AcceptLanguage.html#parse/2"},{"type":"function","title":"Arguments - Cldr.AcceptLanguage.parse/2","doc":"* `accept-language` is any string in the format defined by\n  [rfc2616](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4)\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.AcceptLanguage.html#parse/2-arguments"},{"type":"function","title":"Returns - Cldr.AcceptLanguage.parse/2","doc":"* `{:ok, [{quality, language_tag}, ...]}` or\n\n* `{:error, {Cldr.AcceptLanguageError, String.t}}`\n\nIf at least one valid language tag is found but errors are also\ndetected on one more more tags, an `{ok, list}` tuple is returned\nwith an error tuple for each invalid tag added at the end of the list.","ref":"Cldr.AcceptLanguage.html#parse/2-returns"},{"type":"function","title":"Example - Cldr.AcceptLanguage.parse/2","doc":"iex> Cldr.AcceptLanguage.parse(\"da,zh-TW;q=0.3\", TestBackend.Cldr)\n    {:ok,\n     [\n       {1.0,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"da\",\n          cldr_locale_name: :da,\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"da\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :da,\n          requested_locale_name: \"da\",\n          script: :Latn,\n          territory: :DK,\n          transform: %{},\n          language_variants: []\n        }},\n       {0.3,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"zh-TW\",\n          cldr_locale_name: :\"zh-Hant\",\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"zh\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :\"zh-Hant\",\n          requested_locale_name: \"zh-TW\",\n          script: :Hant,\n          territory: :TW,\n          transform: %{},\n          language_variants: []\n        }}\n     ]}\n\n    iex> Cldr.AcceptLanguage.parse(\"invalid_tag\", TestBackend.Cldr)\n    {:error,\n     {Cldr.LanguageTag.ParseError,\n      \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}\n\n    iex> Cldr.AcceptLanguage.parse(\"da,zh-TW;q=0.3,invalid_tag\", TestBackend.Cldr)\n    {:ok,\n     [\n       {1.0,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"da\",\n          cldr_locale_name: :da,\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"da\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :da,\n          requested_locale_name: \"da\",\n          script: :Latn,\n          territory: :DK,\n          transform: %{},\n          language_variants: []\n        }},\n       {0.3,\n        %Cldr.LanguageTag{\n          backend: TestBackend.Cldr,\n          canonical_locale_name: \"zh-TW\",\n          cldr_locale_name: :\"zh-Hant\",\n          language_subtags: [],\n          extensions: %{},\n          gettext_locale_name: nil,\n          language: \"zh\",\n          locale: %{},\n          private_use: [],\n          rbnf_locale_name: :\"zh-Hant\",\n          requested_locale_name: \"zh-TW\",\n          script: :Hant,\n          territory: :TW,\n          transform: %{},\n          language_variants: []\n        }},\n       {:error,\n        {Cldr.LanguageTag.ParseError,\n         \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}\n     ]}","ref":"Cldr.AcceptLanguage.html#parse/2-example"},{"type":"function","title":"Cldr.AcceptLanguage.parse!/2","doc":"Parses an `Accept-Language` header value in its string\nor tokenized form to produce a list of tuples of the form\n`[{quality, %Cldr.LanguageTag{}}, ...]` sorted by quality\nin descending order.\n\n* `accept-language` is any string in the format defined by [rfc2616](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4)\n\nReturns:\n\n* `{:ok, [{quality, language_tag}, ...]}` or\n\n* raises a `Cldr.AcceptLanguageError` exception\n\nIf at least one valid language tag is found but errors are also\ndetected on one more more tags, an `{ok, list}` tuple is returned\nwith an error tuple for each invalid tag added at the end of the list.","ref":"Cldr.AcceptLanguage.html#parse!/2"},{"type":"function","title":"Example - Cldr.AcceptLanguage.parse!/2","doc":"iex> Cldr.AcceptLanguage.parse!(\"da,zh-TW;q=0.3\", TestBackend.Cldr)\n    [\n      {1.0,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"da\",\n         cldr_locale_name: :da,\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"da\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :da,\n         requested_locale_name: \"da\",\n         script: :Latn,\n         territory: :DK,\n         transform: %{},\n         language_variants: []\n       }},\n      {0.3,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"zh-TW\",\n         cldr_locale_name: :\"zh-Hant\",\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"zh\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :\"zh-Hant\",\n         requested_locale_name: \"zh-TW\",\n         script: :Hant,\n         territory: :TW,\n         transform: %{},\n         language_variants: []\n       }}\n    ]\n\n    Cldr.AcceptLanguage.parse! \"invalid_tag\"\n    ** (Cldr.AcceptLanguageError) \"Expected a BCP47 language tag. Could not parse the remaining \"g\" starting at position 11\n        (ex_cldr) lib/cldr/accept_language.ex:304: Cldr.AcceptLanguage.parse!/1\n\n    iex> Cldr.AcceptLanguage.parse!(\"da,zh-TW;q=0.3,invalid_tag\", TestBackend.Cldr)\n    [\n      {1.0,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"da\",\n         cldr_locale_name: :da,\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"da\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :da,\n         requested_locale_name: \"da\",\n         script: :Latn,\n         territory: :DK,\n         transform: %{},\n         language_variants: []\n       }},\n      {0.3,\n       %Cldr.LanguageTag{\n         backend: TestBackend.Cldr,\n         canonical_locale_name: \"zh-TW\",\n         cldr_locale_name: :\"zh-Hant\",\n         language_subtags: [],\n         extensions: %{},\n         gettext_locale_name: nil,\n         language: \"zh\",\n         locale: %{},\n         private_use: [],\n         rbnf_locale_name: :\"zh-Hant\",\n         requested_locale_name: \"zh-TW\",\n         script: :Hant,\n         territory: :TW,\n         transform: %{},\n         language_variants: []\n       }},\n      {:error,\n       {Cldr.LanguageTag.ParseError,\n        \"Expected a BCP47 language tag. Could not parse the remaining \\\"g\\\" starting at position 11\"}}\n    ]","ref":"Cldr.AcceptLanguage.html#parse!/2-example"},{"type":"function","title":"Cldr.AcceptLanguage.sort_by_quality/1","doc":"","ref":"Cldr.AcceptLanguage.html#sort_by_quality/1"},{"type":"function","title":"Cldr.AcceptLanguage.tokenize/1","doc":"Splits the language ranges for an `Accept-Language` header\nvalue into tuples `{quality, language}`.\n\n* `accept-language` is any string in the format defined by [rfc2616](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4)","ref":"Cldr.AcceptLanguage.html#tokenize/1"},{"type":"function","title":"Example - Cldr.AcceptLanguage.tokenize/1","doc":"iex> Cldr.AcceptLanguage.tokenize \"da,zh-TW;q=0.3\"\n    [{1.0, \"da\"}, {0.3, \"zh-tw\"}]","ref":"Cldr.AcceptLanguage.html#tokenize/1-example"},{"type":"module","title":"Cldr.Locale","doc":"Functions to parse and normalize locale names into a structure\nlocale represented by a `Cldr.LanguageTag`.\n\nCLDR represents localisation data organized into locales, with\neach locale being identified by a locale name that is formatted\naccording to [RFC5646](https://tools.ietf.org/html/rfc5646).\n\nIn practise, the CLDR data utilizes a simple subset of locale name\nformats being:\n\n* a Language code such as `en` or `fr`\n\n* a Language code and Territory code such as `en-GB`\n\n* a Language code and Script such as `zh-Hant`\n\n* and in only two cases a Language code, Territory code and Variant\n  such as `ca-ES-valencia` and `en-US-posix`.\n\nThe RFC defines a language tag as:\n\n> A language tag is composed from a sequence of one or more \"subtags\",\n  each of which refines or narrows the range of language identified by\n  the overall tag.  Subtags, in turn, are a sequence of alphanumeric\n  characters (letters and digits), distinguished and separated from\n  other subtags in a tag by a hyphen (\"-\", [Unicode] U+002D)\n\nTherefore `Cldr` uses the hyphen (\"-\", [Unicode] U+002D) as the subtag\nseparator.  On certain platforms, including POSIX platforms, the\nsubtag separator is a \"_\" (underscore) rather than a \"-\" (hyphen). Where\nappropriate, `Cldr` will transliterate any underscore into a hyphen before\nparsing or processing.","ref":"Cldr.Locale.html"},{"type":"module","title":"Locale name validity - Cldr.Locale","doc":"When validating a locale name, `Cldr` will attempt to match the requested\nlocale name to a configured locale. Therefore `Cldr.Locale.new/2` may\nreturn an `{:ok, language_tag}` tuple even when the locale returned does\nnot exactly match the requested locale name.  For example, the following\nattempts to create a locale matching the non-existent \"english as spoken\nin Japan\" local name.  Here `Cldr` will match to the nearest configured\nlocale, which in this case will be \"en\".\n\n    iex> Cldr.Locale.new(\"en-JP\", TestBackend.Cldr)\n    {:ok, %Cldr.LanguageTag{\n      backend: TestBackend.Cldr,\n      canonical_locale_name: \"en-JP\",\n      cldr_locale_name: :en,\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en-JP\",\n      script: :Latn,\n      territory: :JP,\n      transform: %{},\n      language_variants: []\n    }}","ref":"Cldr.Locale.html#module-locale-name-validity"},{"type":"module","title":"Matching locales to requested locale names - Cldr.Locale","doc":"When attempting to match the requested locale name to a configured\nlocale, `Cldr` attempt to match against a set of reductions in the\nfollowing order and will return the first match:\n\n* language, script, territory, [variants]\n* language, territory, [variants]\n* language, script, [variants]\n* language, [variants]\n* language, script, territory\n* language, territory\n* language, script\n* language\n* requested locale name\n* nil\n\nTherefore matching is tolerant of a request for unknown scripts,\nterritories and variants.  Only the requested language is a\nrequirement to be matched to a configured locale.","ref":"Cldr.Locale.html#module-matching-locales-to-requested-locale-names"},{"type":"module","title":"Substitutions for Obsolete and Deprecated locale names - Cldr.Locale","doc":"CLDR provides data to help manage the transition from obsolete\nor deprecated locale names to current names.  For example, the\nfollowing requests the locale name \"mo\" which is the deprecated\ncode for \"Moldovian\".  The replacement code is \"ro\" (Romanian).\n\n    iex> Cldr.Locale.new(\"mo\", TestBackend.Cldr)\n    {:ok, %Cldr.LanguageTag{\n      backend: TestBackend.Cldr,\n      extensions: %{},\n      gettext_locale_name: nil,\n      language: \"ro\",\n      language_subtags: [],\n      language_variants: [],\n      locale: %{}, private_use: [],\n      rbnf_locale_name: :ro,\n      requested_locale_name: \"mo\",\n      script: :Latn,\n      transform: %{},\n      canonical_locale_name: \"ro\",\n      cldr_locale_name: :ro,\n      territory: :RO\n    }}","ref":"Cldr.Locale.html#module-substitutions-for-obsolete-and-deprecated-locale-names"},{"type":"module","title":"Likely subtags - Cldr.Locale","doc":"CLDR also provides data to indetify the most likely subtags for a\nrequested locale name. This data is based on the default content data,\nthe population data, and the suppress-script data in [BCP47]. It is\nheuristically derived, and may change over time. For example, when\nrequesting the locale \"en\", the following is returned:\n\n    iex> Cldr.Locale.new(\"en\", TestBackend.Cldr)\n    {:ok, %Cldr.LanguageTag{\n      backend: TestBackend.Cldr,\n      canonical_locale_name: \"en\",\n      cldr_locale_name: :en,\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en\",\n      script: :Latn,\n      territory: :US,\n      transform: %{},\n      language_variants: []\n    }}\n\nWhich shows that a the likely subtag for the script is :Latn and the likely\nterritory is \"US\".\n\nUsing the example for Substitutions above, we can see the\nresult of combining substitutions and likely subtags for locale name \"mo\"\nreturns the current language code of \"ro\" as well as the likely\nterritory code of \"MD\" (Moldova).","ref":"Cldr.Locale.html#module-likely-subtags"},{"type":"module","title":"Unknown territory codes - Cldr.Locale","doc":"Whilst `Cldr` is tolerant of invalid territory codes. Therefore validity is\nnot checked by `Cldr.Locale.new/2` but it is checked by `Cldr.validate_locale/2`\nwhich is the recommended api for forming language tags.\n\n    iex> Cldr.Locale.new(\"en-XX\", TestBackend.Cldr)\n    {:ok, %Cldr.LanguageTag{\n      backend: TestBackend.Cldr,\n      canonical_locale_name: \"en-XX\",\n      cldr_locale_name: :en,\n      extensions: %{},\n      gettext_locale_name: \"en\",\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: :en,\n      requested_locale_name: \"en-XX\",\n      script: :Latn,\n      territory: :XX,\n      transform: %{},\n      language_variants: []\n    }}","ref":"Cldr.Locale.html#module-unknown-territory-codes"},{"type":"module","title":"Locale extensions - Cldr.Locale","doc":"Unicode defines the [U extension](https://unicode.org/reports/tr35/#Locale_Extension_Key_and_Type_Data)\nwhich support defining the requested treatment of CLDR data formats. For example, a locale name\ncan configure the requested:\n\n* calendar to be used for dates\n* collation\n* currency\n* currency format\n* number system\n* first day of the week\n* 12-hour or 24-hour time\n* time zone\n* and many other items\n\nFor example, the following locale name will request the use of the timezone `Australia/Sydney`,\nand request the use of `accounting` format when formatting currencies:\n\n    iex> MyApp.Cldr.validate_locale \"en-AU-u-tz-ausyd-cf-account\"\n    {\n      :ok,\n      %Cldr.LanguageTag{\n        backend: MyApp.Cldr,\n        canonical_locale_name: \"en-AU-u-cf-account-tz-ausyd\",\n        cldr_locale_name: :\"en-AU\",\n        extensions: %{},\n        gettext_locale_name: \"en\",\n        language: \"en\",\n        language_subtags: [],\n        language_variants: [],\n        locale: %Cldr.LanguageTag.U{\n          calendar: nil,\n          cf: :account,\n          col_alternate: nil,\n          col_backwards: nil,\n          col_case_first: nil,\n          col_case_level: nil,\n          col_normalization: nil,\n          col_numeric: nil,\n          col_reorder: nil,\n          col_strength: nil,\n          collation: nil,\n          currency: nil,\n          dx: nil,\n          em: nil,\n          fw: nil,\n          hc: nil,\n          lb: nil,\n          lw: nil,\n          ms: nil,\n          numbers: nil,\n          rg: nil,\n          sd: nil,\n          ss: nil,\n          timezone: \"Australia/Sydney\",\n          va: nil,\n          vt: nil\n        },\n        private_use: [],\n        rbnf_locale_name: :en,\n        requested_locale_name: \"en-AU\",\n        script: :Latn,\n        territory: :AU,\n        transform: %{}\n      }\n    }","ref":"Cldr.Locale.html#module-locale-extensions"},{"type":"function","title":"Cldr.Locale.aliases/0","doc":"Return a map of the known aliases for Language, Script and Territory","ref":"Cldr.Locale.html#aliases/0"},{"type":"function","title":"Cldr.Locale.aliases/2","doc":"Return a map of the aliases for a given alias key and type","ref":"Cldr.Locale.html#aliases/2"},{"type":"function","title":"Options - Cldr.Locale.aliases/2","doc":"* `type` is one of `[:language, :region, :script, :variant, :zone]`\n\n* `key` is the substitution key (a language, region, script, variant or zone)","ref":"Cldr.Locale.html#aliases/2-options"},{"type":"function","title":"Cldr.Locale.canonical_language_tag/3","doc":"Parses a locale name and returns a `Cldr.LanguageTag` struct\nthat represents a locale.","ref":"Cldr.Locale.html#canonical_language_tag/3"},{"type":"function","title":"Arguments - Cldr.Locale.canonical_language_tag/3","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`\n  or any `locale_name` returned by `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module\n\n* `options` is a keyword list of options","ref":"Cldr.Locale.html#canonical_language_tag/3-arguments"},{"type":"function","title":"Options - Cldr.Locale.canonical_language_tag/3","doc":"* `:add_likely_subtags` is a `boolean` that determines\n  if subtags that are likely to be applicable to this\n  language tag are added to the language tag. The default\n  is `true`.","ref":"Cldr.Locale.html#canonical_language_tag/3-options"},{"type":"function","title":"Returns - Cldr.Locale.canonical_language_tag/3","doc":"* `{:ok, language_tag}` or\n\n* `{:error, reason}`","ref":"Cldr.Locale.html#canonical_language_tag/3-returns"},{"type":"function","title":"Method - Cldr.Locale.canonical_language_tag/3","doc":"1. The language tag is parsed in accordance with [RFC5646](https://tools.ietf.org/html/rfc5646)\n\n2. Any language, script or region aliases are replaced. This\n   will replace any obsolete elements with current versions.\n\n3. If a territory, script or language variant is not specified,\n   then a default is provided using the CLDR information returned by\n   `Cldr.Locale.likely_subtags/1` if the option `:add_likely_subtags`\n   is `true` (the default).\n\n4. A `Cldr` locale name is selected that is the nearest fit to the\n   requested locale.","ref":"Cldr.Locale.html#canonical_language_tag/3-method"},{"type":"function","title":"Example - Cldr.Locale.canonical_language_tag/3","doc":"iex> Cldr.Locale.canonical_language_tag(\"en\", TestBackend.Cldr)\n    {\n      :ok,\n      %Cldr.LanguageTag{\n        backend: TestBackend.Cldr,\n        canonical_locale_name: \"en\",\n        cldr_locale_name: :en,\n        extensions: %{},\n        gettext_locale_name: \"en\",\n        language: \"en\",\n        locale: %{},\n        private_use: [],\n        rbnf_locale_name: :en,\n        requested_locale_name: \"en\",\n        script: :Latn,\n        territory: :US,\n        transform: %{},\n        language_variants: []\n      }\n    }","ref":"Cldr.Locale.html#canonical_language_tag/3-example"},{"type":"function","title":"Cldr.Locale.canonical_language_tag!/3","doc":"Parses a locale name and returns a `Cldr.LanguageTag` struct\nthat represents a locale or raises on error.","ref":"Cldr.Locale.html#canonical_language_tag!/3"},{"type":"function","title":"Arguments - Cldr.Locale.canonical_language_tag!/3","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`\n  or any `locale_name` returned by `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module\n\nSee `Cldr.Locale.canonical_language_tag/3` for more information.","ref":"Cldr.Locale.html#canonical_language_tag!/3-arguments"},{"type":"function","title":"Cldr.Locale.consider_as_tlds/0","doc":"Returns a list of territory top-level domains that are\nconsidered to be generic top level domains.\n\nSee https://developers.google.com/search/docs/advanced/crawling/managing-multi-regional-sites\nfor an explanation of why some valid territory suffixxes\nare considered as TLDs.","ref":"Cldr.Locale.html#consider_as_tlds/0"},{"type":"function","title":"Example - Cldr.Locale.consider_as_tlds/0","doc":"iex> Cldr.Locale.consider_as_tlds()\n    [:AD, :AS, :BZ, :CC, :CD, :CO, :DJ, :FM, :IO, :LA, :ME, :MS, :NU, :SC, :SR, :SU, :TV, :TK, :WS]","ref":"Cldr.Locale.html#consider_as_tlds/0-example"},{"type":"function","title":"Cldr.Locale.fallback_locale_names/1","doc":"Returns the list of fallback locale names, starting with\nthe provided locale.\n\nFallbacks are a list of locate names which can\nbe used to resolve translation or other localization\ndata if such localised data does not exist for\nthis specific locale.","ref":"Cldr.Locale.html#fallback_locale_names/1"},{"type":"function","title":"Arguments - Cldr.Locale.fallback_locale_names/1","doc":"* `locale` is any `LanguageTag.t`","ref":"Cldr.Locale.html#fallback_locale_names/1-arguments"},{"type":"function","title":"Returns - Cldr.Locale.fallback_locale_names/1","doc":"* `{:ok, list_of_locale_names}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Locale.html#fallback_locale_names/1-returns"},{"type":"function","title":"Examples - Cldr.Locale.fallback_locale_names/1","doc":"In these examples the default locale is `:\"en-001\"`.\n\n    iex> Cldr.Locale.fallback_locale_names(Cldr.Locale.new!(\"fr-CA\", MyApp.Cldr))\n    {:ok, [:\"fr-CA\", :fr, :und]}\n\n    # Fallbacks are typically formed by progressively\n    # stripping variant, territory and script from the\n    # given locale name. But not always - there are\n    # certain fallbacks that take a different path.\n\n    iex> Cldr.Locale.fallback_locale_names(Cldr.Locale.new!(\"nb\", MyApp.Cldr))\n    {:ok, [:nb, :no, :und]}","ref":"Cldr.Locale.html#fallback_locale_names/1-examples"},{"type":"function","title":"Cldr.Locale.fallback_locale_names/2","doc":"Returns the list of fallback locale names, starting the\nthe provided locale name.\n\nFallbacks are a list of locate names which can\nbe used to resolve translation or other localization\ndata if such localised data does not exist for\nthis specific locale.","ref":"Cldr.Locale.html#fallback_locale_names/2"},{"type":"function","title":"Arguments - Cldr.Locale.fallback_locale_names/2","doc":"* `locale_name` is any locale name returned by\n  `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is\n  `Cldr.default_locale/0`.","ref":"Cldr.Locale.html#fallback_locale_names/2-arguments"},{"type":"function","title":"Returns - Cldr.Locale.fallback_locale_names/2","doc":"* `{:ok, list_of_locale_names}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Locale.html#fallback_locale_names/2-returns"},{"type":"function","title":"Examples - Cldr.Locale.fallback_locale_names/2","doc":"In these examples the default locale is `:\"en-001\"`.\n\n    iex> Cldr.Locale.fallback_locale_names(:\"fr-CA\")\n    {:ok, [:\"fr-CA\", :fr, :und]}\n\n    # Fallbacks are typically formed by progressively\n    # stripping variant, territory and script from the\n    # given locale name. But not always - there are\n    # certain fallbacks that take a different path.\n\n    iex> Cldr.Locale.fallback_locale_names(:nb)\n    {:ok, [:nb, :no, :und]}","ref":"Cldr.Locale.html#fallback_locale_names/2-examples"},{"type":"function","title":"Cldr.Locale.fallback_locale_names!/1","doc":"Returns the list of fallback locale names, starting with\nthe provided locale.\n\nFallbacks are a list of locate names which can\nbe used to resolve translation or other localization\ndata if such localised data does not exist for\nthis specific locale.","ref":"Cldr.Locale.html#fallback_locale_names!/1"},{"type":"function","title":"Arguments - Cldr.Locale.fallback_locale_names!/1","doc":"* `locale` is any `LanguageTag.t`","ref":"Cldr.Locale.html#fallback_locale_names!/1-arguments"},{"type":"function","title":"Returns - Cldr.Locale.fallback_locale_names!/1","doc":"* `list_of_locale_names` or\n\n* raises an exception","ref":"Cldr.Locale.html#fallback_locale_names!/1-returns"},{"type":"function","title":"Examples - Cldr.Locale.fallback_locale_names!/1","doc":"In these examples the default locale is `:\"en-001\"`.\n\n    iex> Cldr.Locale.fallback_locale_names!(Cldr.Locale.new!(\"fr-CA\", MyApp.Cldr))\n    [:\"fr-CA\", :fr, :und]\n\n    # Fallbacks are typically formed by progressively\n    # stripping variant, territory and script from the\n    # given locale name. But not always - there are\n    # certain fallbacks that take a different path.\n\n    iex> Cldr.Locale.fallback_locale_names!(Cldr.Locale.new!(\"nb\", MyApp.Cldr))\n    [:nb, :no, :und]","ref":"Cldr.Locale.html#fallback_locale_names!/1-examples"},{"type":"function","title":"Cldr.Locale.fallback_locales/1","doc":"Returns the list of fallback locales, starting the\nthe provided locale.\n\nFallbacks are a list of locate names which can\nbe used to resolve translation or other localization\ndata if such localised data does not exist for\nthis specific locale.","ref":"Cldr.Locale.html#fallback_locales/1"},{"type":"function","title":"Arguments - Cldr.Locale.fallback_locales/1","doc":"* `locale` is any `LanguageTag.t`","ref":"Cldr.Locale.html#fallback_locales/1-arguments"},{"type":"function","title":"Returns - Cldr.Locale.fallback_locales/1","doc":"* `{:ok, list_of_locales}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Locale.html#fallback_locales/1-returns"},{"type":"function","title":"Examples - Cldr.Locale.fallback_locales/1","doc":"Cldr.Locale.fallback_locales(Cldr.Locale.new!(\"fr-CA\", MyApp.Cldr))\n    => {:ok,\n     [#Cldr.LanguageTag , #Cldr.LanguageTag ,\n      #Cldr.LanguageTag ]}\n\n    # Fallbacks are typically formed by progressively\n    # stripping variant, territory and script from the\n    # given locale name. But not always - there are\n    # certain fallbacks that take a different path.\n\n    Cldr.Locale.fallback_locales(Cldr.Locale.new!(\"nb\", MyApp.Cldr))\n    => {:ok,\n     [#Cldr.LanguageTag , #Cldr.LanguageTag ,\n      #Cldr.LanguageTag ]}","ref":"Cldr.Locale.html#fallback_locales/1-examples"},{"type":"function","title":"Cldr.Locale.fallback_locales/2","doc":"Returns the list of fallback locales, starting the\nthe provided locale.\n\nFallbacks are a list of locate names which can\nbe used to resolve translation or other localization\ndata if such localised data does not exist for\nthis specific locale.","ref":"Cldr.Locale.html#fallback_locales/2"},{"type":"function","title":"Arguments - Cldr.Locale.fallback_locales/2","doc":"* `locale_name` is any locale name returned by\n  `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module. The default is\n  `Cldr.default_locale/0`.","ref":"Cldr.Locale.html#fallback_locales/2-arguments"},{"type":"function","title":"Returns - Cldr.Locale.fallback_locales/2","doc":"* `{:ok, list_of_locales}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Locale.html#fallback_locales/2-returns"},{"type":"function","title":"Examples - Cldr.Locale.fallback_locales/2","doc":"Cldr.Locale.fallback_locales(:\"fr-CA\")\n    => {:ok,\n         [#Cldr.LanguageTag , #Cldr.LanguageTag ,\n          #Cldr.LanguageTag ]}\n\n    # Fallbacks are typically formed by progressively\n    # stripping variant, territory and script from the\n    # given locale name. But not always - there are\n    # certain fallbacks that take a different path.\n\n    Cldr.Locale.fallback_locales(:nb)\n    => {:ok,\n         [#Cldr.LanguageTag , #Cldr.LanguageTag ,\n          #Cldr.LanguageTag ]}","ref":"Cldr.Locale.html#fallback_locales/2-examples"},{"type":"function","title":"Cldr.Locale.first_match/3","doc":"Execute a function for a locale returning\nthe first match on language, script, territory,\nand variant combination.\n\nA match is determined when the `fun/1` returns\na `truthy` value.","ref":"Cldr.Locale.html#first_match/3"},{"type":"function","title":"Arguments - Cldr.Locale.first_match/3","doc":"* `language_tag` is any language tag returned by\n  `Cldr.Locale.new/2`.\n\n* `fun/2` is 2-arity function that takes a string\n  locale name and subtags. The locale name is a built from the language,\n  script, territory and variant combinations of `language_tag`.\n\n* `omit_singular_script?` is a boolean indicating if\n  a match should fail if the language tag script is the only\n  (default) script for the language. The default is `false`.","ref":"Cldr.Locale.html#first_match/3-arguments"},{"type":"function","title":"Returns - Cldr.Locale.first_match/3","doc":"* The first `truthy` value returned by `fun/2` or `nil` if no\n  match is made.","ref":"Cldr.Locale.html#first_match/3-returns"},{"type":"macro","title":"Cldr.Locale.is_locale_name/1","doc":"","ref":"Cldr.Locale.html#is_locale_name/1"},{"type":"type","title":"Cldr.Locale.language/0","doc":"The name of a language","ref":"Cldr.Locale.html#t:language/0"},{"type":"function","title":"Cldr.Locale.language_data/0","doc":"Mapping of language data to known\nscripts and territories","ref":"Cldr.Locale.html#language_data/0"},{"type":"function","title":"Cldr.Locale.languages_for_territories/0","doc":"Returns a map of a territory code to its\nmost-spoken language.","ref":"Cldr.Locale.html#languages_for_territories/0"},{"type":"function","title":"Example - Cldr.Locale.languages_for_territories/0","doc":"Cldr.Locale.languages_for_territories()\n      => %{\n        AQ: \"und\",\n        PE: \"es\",\n        SR: \"nl\",\n        NU: \"en\",\n        ...\n      }","ref":"Cldr.Locale.html#languages_for_territories/0-example"},{"type":"function","title":"Cldr.Locale.likely_subtags/0","doc":"Returns the map of likely subtags.\n\nNote that not all locales are guaranteed\nto have likely subtags.","ref":"Cldr.Locale.html#likely_subtags/0"},{"type":"function","title":"Example - Cldr.Locale.likely_subtags/0","doc":"Cldr.Locale.likely_subtags\n    => %{\n      bez; %Cldr.LanguageTag{\n        backend: TestBackend.Cldr,\n        canonical_locale_name: nil,\n        cldr_locale_name: nil,\n        extensions: %{},\n        language: \"bez\",\n        locale: %{},\n        private_use: [],\n        rbnf_locale_name: nil,\n        requested_locale_name: nil,\n        script: :Latn,\n        territory: :TZ,\n        transform: %{},\n        language_variants: []\n      },\n      fuf: %Cldr.LanguageTag{\n        canonical_locale_name: nil,\n        cldr_locale_name: nil,\n        extensions: %{},\n        language: \"fuf\",\n        locale: %{},\n        private_use: [],\n        rbnf_locale_name: nil,\n        requested_locale_name: nil,\n        script: :Latn,\n        territory: :GN,\n        transform: %{},\n        language_variants: []\n      },\n      ...","ref":"Cldr.Locale.html#likely_subtags/0-example"},{"type":"function","title":"Cldr.Locale.likely_subtags/1","doc":"Returns the likely substags, as a `Cldr.LanguageTag`,\nfor a given locale name.","ref":"Cldr.Locale.html#likely_subtags/1"},{"type":"function","title":"Options - Cldr.Locale.likely_subtags/1","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct","ref":"Cldr.Locale.html#likely_subtags/1-options"},{"type":"function","title":"Examples - Cldr.Locale.likely_subtags/1","doc":"iex> Cldr.Locale.likely_subtags :en\n    %Cldr.LanguageTag{\n      backend: nil,\n      canonical_locale_name: nil,\n      cldr_locale_name: nil,\n      extensions: %{},\n      gettext_locale_name: nil,\n      language: \"en\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: nil,\n      requested_locale_name: \"en-Latn-US\",\n      script: :Latn,\n      territory: :US,\n      transform: %{},\n      language_variants: []\n    }","ref":"Cldr.Locale.html#likely_subtags/1-examples"},{"type":"function","title":"Cldr.Locale.locale_for_territory/2","doc":"Returns the \"best fit\" locale for a given territory.\n\nUsing the population percentage data from CLDR, the\nlanguage most commonly spoken in the given territory\nis used to form a locale name which is then validated\nagainst the given backend.\n\nFirst a territory-specific locale is validated and if\nthat fails, the base language only is validate.\n\nFor example, if the territory is `AU` then then the\nlanguage most spoken is \"en\". First, the locale \"en-AU\"\nis validated and if that fails, \"en\" is validated.","ref":"Cldr.Locale.html#locale_for_territory/2"},{"type":"function","title":"Arguments - Cldr.Locale.locale_for_territory/2","doc":"* `territory` is any ISO 3166 Alpha-2 territory\n  code that can be validated by `Cldr.validate_territory/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.","ref":"Cldr.Locale.html#locale_for_territory/2-arguments"},{"type":"function","title":"Returns - Cldr.Locale.locale_for_territory/2","doc":"* `{:ok, language_tag}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Locale.html#locale_for_territory/2-returns"},{"type":"function","title":"Examples - Cldr.Locale.locale_for_territory/2","doc":"iex> Cldr.Locale.locale_for_territory(:AU, TestBackend.Cldr)\n  Cldr.validate_locale(:\"en-AU\", TestBackend.Cldr)\n\n  iex> Cldr.Locale.locale_for_territory(:US, TestBackend.Cldr)\n  Cldr.validate_locale(:\"en-US\", TestBackend.Cldr)\n\n  iex> Cldr.Locale.locale_for_territory(:ZZ)\n  {:error, {Cldr.UnknownTerritoryError, \"The territory :ZZ is unknown\"}}","ref":"Cldr.Locale.html#locale_for_territory/2-examples"},{"type":"function","title":"Cldr.Locale.locale_from_host/3","doc":"Returns a \"best fit\" locale for a host name.","ref":"Cldr.Locale.html#locale_from_host/3"},{"type":"function","title":"Arguments - Cldr.Locale.locale_from_host/3","doc":"* `host` is any valid host name\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.\n\n* `options` is a keyword list of options. The default\n  is `[tlds: Cldr.Locale.consider_as_tlds()]`.","ref":"Cldr.Locale.html#locale_from_host/3-arguments"},{"type":"function","title":"Options - Cldr.Locale.locale_from_host/3","doc":"* `:tlds` is a list of territory codes as upper-cased\n  atoms that are to be considered as top-level domains.\n  The default list is `consider_as_tlds/0`.","ref":"Cldr.Locale.html#locale_from_host/3-options"},{"type":"function","title":"Returns - Cldr.Locale.locale_from_host/3","doc":"* `{:ok, language_tag}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Locale.html#locale_from_host/3-returns"},{"type":"function","title":"Notes - Cldr.Locale.locale_from_host/3","doc":"Certain top-level domains have become associated with content\nunderlated to the territory for who the domain is registered.\nTherefore Google (and perhaps others) do not associate these\nTLDs as belonging to the territory but rather are considered\ngeneric top-level domain names.","ref":"Cldr.Locale.html#locale_from_host/3-notes"},{"type":"function","title":"Examples - Cldr.Locale.locale_from_host/3","doc":"iex> Cldr.Locale.locale_from_host \"a.b.com.au\", TestBackend.Cldr\n    Cldr.validate_locale(:\"en-AU\", TestBackend.Cldr)\n\n    iex> Cldr.Locale.locale_from_host \"a.b.com.tv\", TestBackend.Cldr\n    {:error,\n     {Cldr.UnknownLocaleError, \"No locale was identified for territory \\\"tv\\\"\"}}\n\n    iex> Cldr.Locale.locale_from_host \"a.b.com\", TestBackend.Cldr\n    {:error,\n     {Cldr.UnknownLocaleError, \"No locale was identified for territory \\\"com\\\"\"}}","ref":"Cldr.Locale.html#locale_from_host/3-examples"},{"type":"type","title":"Cldr.Locale.locale_name/0","doc":"The name of a locale","ref":"Cldr.Locale.html#t:locale_name/0"},{"type":"function","title":"Cldr.Locale.locale_name_from/2","doc":"Return a locale name from a `Cldr.LanguageTag`","ref":"Cldr.Locale.html#locale_name_from/2"},{"type":"function","title":"Options - Cldr.Locale.locale_name_from/2","doc":"* `locale_name` is any `Cldr.LanguageTag` struct returned by\n  `Cldr.Locale.new!/2`","ref":"Cldr.Locale.html#locale_name_from/2-options"},{"type":"function","title":"Example - Cldr.Locale.locale_name_from/2","doc":"iex> Cldr.Locale.locale_name_from Cldr.Locale.new!(\"en\", TestBackend.Cldr)\n    \"en\"","ref":"Cldr.Locale.html#locale_name_from/2-example"},{"type":"function","title":"Cldr.Locale.locale_name_from/5","doc":"Return a locale name by combining language, script, territory and variant\nparameters","ref":"Cldr.Locale.html#locale_name_from/5"},{"type":"function","title":"Arguments - Cldr.Locale.locale_name_from/5","doc":"* `language` is a string representing\n  a valid language code\n\n* `script` is an atom that is a valid\n  script code.\n\n* `territory` is an atom that is a valid\n  territory code.\n\n* `variants` is a list of language variants as lower\n  case string or `[]`.","ref":"Cldr.Locale.html#locale_name_from/5-arguments"},{"type":"function","title":"Returns - Cldr.Locale.locale_name_from/5","doc":"* The atom locale name constructed from the non-nil arguments joined\n  by a \"-\".","ref":"Cldr.Locale.html#locale_name_from/5-returns"},{"type":"function","title":"Example - Cldr.Locale.locale_name_from/5","doc":"iex> Cldr.Locale.locale_name_from(\"en\", :Latn, \"001\", [])\n    \"en-Latn-001\"\n\n    iex> Cldr.Locale.locale_name_from(\"en\", :Latn, :\"001\", [])\n    \"en-Latn-001\"","ref":"Cldr.Locale.html#locale_name_from/5-example"},{"type":"function","title":"Cldr.Locale.locale_name_from_posix/1","doc":"","ref":"Cldr.Locale.html#locale_name_from_posix/1"},{"type":"function","title":"Cldr.Locale.locale_name_to_posix/1","doc":"","ref":"Cldr.Locale.html#locale_name_to_posix/1"},{"type":"type","title":"Cldr.Locale.locale_reference/0","doc":"A reference to a locale","ref":"Cldr.Locale.html#t:locale_reference/0"},{"type":"function","title":"Cldr.Locale.new/2","doc":"","ref":"Cldr.Locale.html#new/2"},{"type":"function","title":"Cldr.Locale.new!/2","doc":"","ref":"Cldr.Locale.html#new!/2"},{"type":"function","title":"Cldr.Locale.omit_likely_subtags/4","doc":"","ref":"Cldr.Locale.html#omit_likely_subtags/4"},{"type":"function","title":"Cldr.Locale.parent/1","doc":"Returns the parent for a given locale.\n\nThe function implements locale inheritance\nin accordance with [CLDR's inheritance rules](https://unicode.org/reports/tr35/#Locale_Inheritance).\n\nOnly locales that are configured are returned.\nThat is, there may be a different parent locale in CLDR\nbut unless those locales are configured they are not\ncandidates to be parents in this context. The contract\nis to return either a known locale or an error.","ref":"Cldr.Locale.html#parent/1"},{"type":"function","title":"Inheritance - Cldr.Locale.parent/1","doc":"* Inheritance starts by looking for a parent locale via\n `Cldr.Config.parent_locales/0`.\n\n* If not found, strip in turn the variant, script and territory\n  while checking to see if a base locale for the given language\n  exists.\n\n* If no parent language exists then move to the default\n  locale and its inheritance chain.","ref":"Cldr.Locale.html#parent/1-inheritance"},{"type":"function","title":"Cldr.Locale.parent/2","doc":"","ref":"Cldr.Locale.html#parent/2"},{"type":"function","title":"Cldr.Locale.parent_locale_map/0","doc":"Returns mappings between a locale\nand its parent.\n\nThe mappings exist only where normal\ninheritance rules are not applied.","ref":"Cldr.Locale.html#parent_locale_map/0"},{"type":"function","title":"Cldr.Locale.parents/2","doc":"Returns a list of all the parent locales\nfor a given locale.","ref":"Cldr.Locale.html#parents/2"},{"type":"function","title":"Examples - Cldr.Locale.parents/2","doc":"Cldr.Locale.parents \"fr-ca\"\n      => {:ok, [#Cldr.LanguageTag , #Cldr.LanguageTag ]}","ref":"Cldr.Locale.html#parents/2-examples"},{"type":"function","title":"Cldr.Locale.put_gettext_locale_name/2","doc":"","ref":"Cldr.Locale.html#put_gettext_locale_name/2"},{"type":"function","title":"Cldr.Locale.put_likely_subtags/1","doc":"Replace empty subtags within a `t:Cldr.LanguageTag.t/0` with the most likely\nsubtag.","ref":"Cldr.Locale.html#put_likely_subtags/1"},{"type":"function","title":"Arguments - Cldr.Locale.put_likely_subtags/1","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`\n\n* `options` is a keyword list of options","ref":"Cldr.Locale.html#put_likely_subtags/1-arguments"},{"type":"function","title":"Options - Cldr.Locale.put_likely_subtags/1","doc":"* `:add_likely` is a boolean indicating whether to add\n  likely subtags. The default is `true`.","ref":"Cldr.Locale.html#put_likely_subtags/1-options"},{"type":"function","title":"Notes - Cldr.Locale.put_likely_subtags/1","doc":"A subtag is called empty if it has a missing script or territory subtag, or it is\na base language subtag with the value `und`. In the description below,\na subscript on a subtag x indicates which tag it is from: x s  is in the\nsource, x m  is in a match, and x r  is in the final result.","ref":"Cldr.Locale.html#put_likely_subtags/1-notes"},{"type":"function","title":"Lookup - Cldr.Locale.put_likely_subtags/1","doc":"Lookup each of the following in order, and stops on the first match:\n\n* language s -script s -region s \n* language s -region s \n* language s -script s \n* language s \n* und-script s","ref":"Cldr.Locale.html#put_likely_subtags/1-lookup"},{"type":"function","title":"Returns - Cldr.Locale.put_likely_subtags/1","doc":"* If there is no match,either return\n  * an error value, or\n  * the match for `und`\n\n* Otherwise there is a match = language m -script m -region m \n\n* Let x r  = x s  if x s  is not empty, and x m  otherwise.\n\n* Return the language tag composed of language r -script r -region r  + variants + extensions .","ref":"Cldr.Locale.html#put_likely_subtags/1-returns"},{"type":"function","title":"Example - Cldr.Locale.put_likely_subtags/1","doc":"iex> Cldr.Locale.put_likely_subtags Cldr.LanguageTag.parse!(\"zh-SG\")\n    %Cldr.LanguageTag{\n      backend: nil,\n      canonical_locale_name: nil,\n      cldr_locale_name: nil,\n      language_subtags: [],\n      extensions: %{},\n      gettext_locale_name: nil,\n      language: \"zh\",\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: nil,\n      requested_locale_name: \"zh-SG\",\n      script: :Hans,\n      territory: \"SG\",\n      transform: %{},\n      language_variants: []\n    }","ref":"Cldr.Locale.html#put_likely_subtags/1-example"},{"type":"function","title":"Cldr.Locale.root_language/0","doc":"Returns the root language for CLDR.","ref":"Cldr.Locale.html#root_language/0"},{"type":"type","title":"Cldr.Locale.script/0","doc":"The name of a script","ref":"Cldr.Locale.html#t:script/0"},{"type":"type","title":"Cldr.Locale.script_direction/0","doc":"The direction in which a script is rendered","ref":"Cldr.Locale.html#t:script_direction/0"},{"type":"function","title":"Cldr.Locale.script_direction_from_locale/1","doc":"Returns the script direction for a locale.","ref":"Cldr.Locale.html#script_direction_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Locale.script_direction_from_locale/1","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`\n  or any `locale_name` returned by `Cldr.known_locale_names/1`. If\n  the parameter is a `locale_name` then a default backend must be\n  configured in `config.exs` or an exception will be raised.","ref":"Cldr.Locale.html#script_direction_from_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Locale.script_direction_from_locale/1","doc":"* The script direction which is either `:ltr` (for left-to-right\n  scripts) or `:rtl` (for right-to-left scripts).","ref":"Cldr.Locale.html#script_direction_from_locale/1-returns"},{"type":"function","title":"Examples - Cldr.Locale.script_direction_from_locale/1","doc":"iex> Cldr.Locale.script_direction_from_locale \"en-US\"\n    :ltr\n\n    iex> Cldr.Locale.script_direction_from_locale \"ar\"\n    :rtl","ref":"Cldr.Locale.html#script_direction_from_locale/1-examples"},{"type":"function","title":"Cldr.Locale.script_direction_from_locale/2","doc":"Returns the script direction for a locale.","ref":"Cldr.Locale.html#script_direction_from_locale/2"},{"type":"function","title":"Arguments - Cldr.Locale.script_direction_from_locale/2","doc":"* `locale_name` is any locale name returned by\n  `Cldr.known_locale_names/1`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.","ref":"Cldr.Locale.html#script_direction_from_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.Locale.script_direction_from_locale/2","doc":"* The script direction which is either `:ltr` (for left-to-right\n  scripts) or `:rtl` (for right-to-left scripts).","ref":"Cldr.Locale.html#script_direction_from_locale/2-returns"},{"type":"function","title":"Examples - Cldr.Locale.script_direction_from_locale/2","doc":"iex> Cldr.Locale.script_direction_from_locale :\"en-US\", TestBackend.Cldr\n    :ltr\n\n    iex> Cldr.Locale.script_direction_from_locale :he, TestBackend.Cldr\n    :rtl","ref":"Cldr.Locale.html#script_direction_from_locale/2-examples"},{"type":"function","title":"Cldr.Locale.script_from_locale/1","doc":"Returns the script for a locale.","ref":"Cldr.Locale.html#script_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Locale.script_from_locale/1","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`\n  or any `locale_name` returned by `Cldr.known_locale_names/1`. If\n  the parameter is a `locale_name` then a default backend must be\n  configured in `config.exs` or an exception will be raised.","ref":"Cldr.Locale.html#script_from_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Locale.script_from_locale/1","doc":"* The script to be used for localization purposes.","ref":"Cldr.Locale.html#script_from_locale/1-returns"},{"type":"function","title":"Examples - Cldr.Locale.script_from_locale/1","doc":"iex> Cldr.Locale.script_from_locale \"en-US\"\n    :Latn\n\n    iex> Cldr.Locale.script_from_locale \"th\"\n    :Thai","ref":"Cldr.Locale.html#script_from_locale/1-examples"},{"type":"function","title":"Cldr.Locale.script_from_locale/2","doc":"Returns the script for a locale.","ref":"Cldr.Locale.html#script_from_locale/2"},{"type":"function","title":"Arguments - Cldr.Locale.script_from_locale/2","doc":"* `locale_name` is any locale name returned by\n  `Cldr.known_locale_names/1`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.","ref":"Cldr.Locale.html#script_from_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.Locale.script_from_locale/2","doc":"* The script to be used for localization purposes.","ref":"Cldr.Locale.html#script_from_locale/2-returns"},{"type":"function","title":"Examples - Cldr.Locale.script_from_locale/2","doc":"iex> Cldr.Locale.script_from_locale \"en-US\", TestBackend.Cldr\n    :Latn\n\n    iex> Cldr.Locale.script_from_locale \"th\", TestBackend.Cldr\n    :Thai","ref":"Cldr.Locale.html#script_from_locale/2-examples"},{"type":"type","title":"Cldr.Locale.subdivision_code/0","doc":"A territory subdiviiosn code as a string","ref":"Cldr.Locale.html#t:subdivision_code/0"},{"type":"function","title":"Cldr.Locale.substitute_aliases/1","doc":"Substitute deprecated subtags with a `Cldr.LanguageTag` with their\nnon-deprecated alternatives.","ref":"Cldr.Locale.html#substitute_aliases/1"},{"type":"function","title":"Arguments - Cldr.Locale.substitute_aliases/1","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`","ref":"Cldr.Locale.html#substitute_aliases/1-arguments"},{"type":"function","title":"Method - Cldr.Locale.substitute_aliases/1","doc":"* Replace any deprecated subtags with their canonical values using the alias\n  data. Use the first value in the replacement list, if\n  it exists. Language tag replacements may have multiple parts, such as\n  `sh` ➞ `sr_Latn` or `mo` ➞ `ro_MD`. In such a case, the original script and/or\n  region/territory are retained if there is one. Thus `sh_Arab_AQ` ➞ `sr_Arab_AQ`, not\n  `sr_Latn_AQ`.\n\n* Remove the script code 'Zzzz' and the territory code 'ZZ' if they occur.\n\n* Get the components of the cleaned-up source tag (languages, scripts, and\n  regions/territories), plus any variants and extensions.","ref":"Cldr.Locale.html#substitute_aliases/1-method"},{"type":"function","title":"Example - Cldr.Locale.substitute_aliases/1","doc":"iex> Cldr.Locale.substitute_aliases Cldr.LanguageTag.Parser.parse!(\"mo\")\n    %Cldr.LanguageTag{\n      backend: nil,\n      canonical_locale_name: nil,\n      cldr_locale_name: nil,\n      extensions: %{},\n      gettext_locale_name: nil,\n      language: \"ro\",\n      language_subtags: [],\n      language_variants: [],\n      locale: %{},\n      private_use: [],\n      rbnf_locale_name: nil,\n      requested_locale_name: \"mo\",\n      script: nil,\n      territory: nil,\n      transform: %{}\n    }","ref":"Cldr.Locale.html#substitute_aliases/1-example"},{"type":"type","title":"Cldr.Locale.subtags/0","doc":"The list of language subtags as strings","ref":"Cldr.Locale.html#t:subtags/0"},{"type":"type","title":"Cldr.Locale.territory_code/0","doc":"A territory code as an ISO3166 Alpha-2 in atom form","ref":"Cldr.Locale.html#t:territory_code/0"},{"type":"function","title":"Cldr.Locale.territory_from_host/1","doc":"Returns the last segment of a host that might\nbe a territory.","ref":"Cldr.Locale.html#territory_from_host/1"},{"type":"function","title":"Arguments - Cldr.Locale.territory_from_host/1","doc":"* `host` is any valid host name","ref":"Cldr.Locale.html#territory_from_host/1-arguments"},{"type":"function","title":"Returns - Cldr.Locale.territory_from_host/1","doc":"* `{:ok, territory}` or\n\n* `{:error, {exception, reason}}`","ref":"Cldr.Locale.html#territory_from_host/1-returns"},{"type":"function","title":"Examples - Cldr.Locale.territory_from_host/1","doc":"iex> Cldr.Locale.territory_from_host(\"a.b.com.au\")\n    {:ok, :AU}\n\n    iex> Cldr.Locale.territory_from_host(\"a.b.com\")\n    {:error,\n     {Cldr.UnknownLocaleError, \"No locale was identified for territory \\\"com\\\"\"}}","ref":"Cldr.Locale.html#territory_from_host/1-examples"},{"type":"function","title":"Cldr.Locale.territory_from_locale/1","doc":"Returns the effective territory for a locale.","ref":"Cldr.Locale.html#territory_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Locale.territory_from_locale/1","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`\n  or any `locale_name` returned by `Cldr.known_locale_names/1`. If\n  the parameter is a `locale_name` then a default backend must be\n  configured in `config.exs` or an exception will be raised.","ref":"Cldr.Locale.html#territory_from_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Locale.territory_from_locale/1","doc":"* The territory to be used for localization purposes.","ref":"Cldr.Locale.html#territory_from_locale/1-returns"},{"type":"function","title":"Examples - Cldr.Locale.territory_from_locale/1","doc":"iex> Cldr.Locale.territory_from_locale \"en-US\"\n    :US\n\n    iex> Cldr.Locale.territory_from_locale \"en-US-u-rg-cazzzz\"\n    :CA\n\n    iex> Cldr.Locale.territory_from_locale \"en-US-u-rg-xxxxx\"\n    {:error, {Cldr.LanguageTag.ParseError, \"The value \\\"xxxxx\\\" is not valid for the key \\\"rg\\\"\"}}","ref":"Cldr.Locale.html#territory_from_locale/1-examples"},{"type":"function","title":"Notes - Cldr.Locale.territory_from_locale/1","doc":"A locale can reflect the desired territory to be used\nwhen determining region-specific defaults for items such\nas:\n\n* default currency,\n* default calendar and week data,\n* default time cycle, and\n* default measurement system and unit preferences\n\nTerritory information is stored in the locale in up to three\ndifferent places:\n\n1. The `:territory` extracted from the locale name or\n   defined by default for a given language. This is the typical\n   use case when locale names such as `en-US` or `es-AR` are\n   used.\n\n2. In some cases it might be desirable to override the territory\n   derived from the locale name. For example, the default\n   territory for the language \"en\" is \"US\" but it may be desired\n   to apply the defaults for the territory \"AU\" instead, without\n   otherwise changing the localization intent. In this case\n   the [U extension](https://unicode.org/reports/tr35/#u_Extension) is\n   used to define a\n   [regional override](https://unicode.org/reports/tr35/#RegionOverride).\n\n3. Similarly, the [regional subdivision identifier]\n   (https://unicode.org/reports/tr35/#UnicodeSubdivisionIdentifier)\n   can be used to influence localization decisions. This identifier\n   is not currently used in `ex_cldr` and dependent libraries\n   however it is correctly parsed to support future use.","ref":"Cldr.Locale.html#territory_from_locale/1-notes"},{"type":"function","title":"Cldr.Locale.territory_from_locale/2","doc":"Returns the effective territory for a locale.","ref":"Cldr.Locale.html#territory_from_locale/2"},{"type":"function","title":"Arguments - Cldr.Locale.territory_from_locale/2","doc":"* `locale_name` is any locale name returned by\n  `Cldr.known_locale_names/1`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.","ref":"Cldr.Locale.html#territory_from_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.Locale.territory_from_locale/2","doc":"* The territory to be used for localization purposes or\n  `{:error, {exception, reason}}`.","ref":"Cldr.Locale.html#territory_from_locale/2-returns"},{"type":"function","title":"Examples - Cldr.Locale.territory_from_locale/2","doc":"iex> Cldr.Locale.territory_from_locale \"en-US\", TestBackend.Cldr\n    :US\n\n    iex> Cldr.Locale.territory_from_locale \"en-US-u-rg-cazzzz\", TestBackend.Cldr\n    :CA\n\n    iex> Cldr.Locale.territory_from_locale \"en-US-u-rg-xxxxx\", TestBackend.Cldr\n    {:error, {Cldr.LanguageTag.ParseError, \"The value \\\"xxxxx\\\" is not valid for the key \\\"rg\\\"\"}}","ref":"Cldr.Locale.html#territory_from_locale/2-examples"},{"type":"function","title":"Notes - Cldr.Locale.territory_from_locale/2","doc":"A locale can reflect the desired territory to be used\nwhen determining region-specific defaults for items such\nas:\n\n* default currency,\n* default calendar and week data,\n* default time cycle, and\n* default measurement system and unit preferences\n\nTerritory information is stored in the locale in up to three\ndifferent places:\n\n1. The `:territory` extracted from the locale name or\n   defined by default for a given language. This is the typical\n   use case when locale names such as `en-US` or `es-AR` are\n   used.\n\n2. In some cases it might be desirable to override the territory\n   derived from the locale name. For example, the default\n   territory for the language \"en\" is \"US\" but it may be desired\n   to apply the defaults for the territory \"AU\" instead, without\n   otherwise changing the localization intent. In this case\n   the [U extension](https://unicode.org/reports/tr35/#u_Extension) is\n   used to define a\n   [regional override](https://unicode.org/reports/tr35/#RegionOverride).\n\n3. Similarly, the [regional subdivision identifier]\n   (https://unicode.org/reports/tr35/#UnicodeSubdivisionIdentifier)\n   can be used to influence localization decisions. This identifier\n   is not currently used in `ex_cldr` and dependent libraries\n   however it is correctly parsed to support future use.","ref":"Cldr.Locale.html#territory_from_locale/2-notes"},{"type":"type","title":"Cldr.Locale.territory_reference/0","doc":"The name of a territory","ref":"Cldr.Locale.html#t:territory_reference/0"},{"type":"function","title":"Cldr.Locale.timezone_from_locale/1","doc":"Returns the effective time zone for a locale.","ref":"Cldr.Locale.html#timezone_from_locale/1"},{"type":"function","title":"Arguments - Cldr.Locale.timezone_from_locale/1","doc":"* `language_tag` is any language tag returned by `Cldr.Locale.new/2`\n  or any `locale_name` returned by `Cldr.known_locale_names/1`. If\n  the parameter is a `locale_name` then a default backend must be\n  configured in `config.exs` or an exception will be raised.","ref":"Cldr.Locale.html#timezone_from_locale/1-arguments"},{"type":"function","title":"Returns - Cldr.Locale.timezone_from_locale/1","doc":"* The time zone ID as a `String.t` or `{:error, {exception, reason}}`","ref":"Cldr.Locale.html#timezone_from_locale/1-returns"},{"type":"function","title":"Examples - Cldr.Locale.timezone_from_locale/1","doc":"iex> Cldr.Locale.timezone_from_locale \"en-US-u-tz-ausyd\"\n    \"Australia/Sydney\"\n\n    iex> Cldr.Locale.timezone_from_locale \"en-AU\"\n    {:error,\n     {Cldr.AmbiguousTimezoneError,\n      \"Cannot determine the timezone since the territory :AU has 24 timezone IDs\"}}","ref":"Cldr.Locale.html#timezone_from_locale/1-examples"},{"type":"function","title":"Cldr.Locale.timezone_from_locale/2","doc":"Returns the effective time zone for a locale.","ref":"Cldr.Locale.html#timezone_from_locale/2"},{"type":"function","title":"Arguments - Cldr.Locale.timezone_from_locale/2","doc":"* `locale_name` is any name returned by `Cldr.known_locale_names/1`\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module","ref":"Cldr.Locale.html#timezone_from_locale/2-arguments"},{"type":"function","title":"Returns - Cldr.Locale.timezone_from_locale/2","doc":"* The time zone ID as a `String.t` or `{:error, {exception, reason}}`","ref":"Cldr.Locale.html#timezone_from_locale/2-returns"},{"type":"function","title":"Examples - Cldr.Locale.timezone_from_locale/2","doc":"iex> Cldr.Locale.timezone_from_locale \"en-US-u-tz-ausyd\", TestBackend.Cldr\n    \"Australia/Sydney\"\n\n    iex> Cldr.Locale.timezone_from_locale :\"en-AU\", TestBackend.Cldr\n    {:error,\n     {Cldr.AmbiguousTimezoneError,\n      \"Cannot determine the timezone since the territory :AU has 24 timezone IDs\"}}","ref":"Cldr.Locale.html#timezone_from_locale/2-examples"},{"type":"type","title":"Cldr.Locale.variants/0","doc":"The list of language variants as strings","ref":"Cldr.Locale.html#t:variants/0"},{"type":"module","title":"Cldr.Rfc5646.Parser","doc":"Implements parsing for [RFC5646](https://datatracker.ietf.org/doc/html/rfc5646) language\ntags with [BCP47](https://tools.ietf.org/search/bcp47) extensions.\n\nThe primary interface to this module is the function\n`Cldr.LanguageTag.parse/1`.","ref":"Cldr.Rfc5646.Parser.html"},{"type":"function","title":"Cldr.Rfc5646.Parser.error_on_remaining/4","doc":"","ref":"Cldr.Rfc5646.Parser.html#error_on_remaining/4"},{"type":"function","title":"Cldr.Rfc5646.Parser.language_tag/2","doc":"Parses the given `binary` as language_tag.\n\nReturns `{:ok, [token], rest, context, position, byte_offset}` or\n`{:error, reason, rest, context, line, byte_offset}` where `position`\ndescribes the location of the language_tag (start position) as `{line, column_on_line}`.","ref":"Cldr.Rfc5646.Parser.html#language_tag/2"},{"type":"function","title":"Options - Cldr.Rfc5646.Parser.language_tag/2","doc":"* `:byte_offset` - the byte offset for the whole binary, defaults to 0\n  * `:line` - the line and the byte offset into that line, defaults to `{1, byte_offset}`\n  * `:context` - the initial context value. It will be converted to a map","ref":"Cldr.Rfc5646.Parser.html#language_tag/2-options"},{"type":"function","title":"Cldr.Rfc5646.Parser.parse/2","doc":"","ref":"Cldr.Rfc5646.Parser.html#parse/2"},{"type":"module","title":"Cldr.LanguageTag","doc":"Represents a language tag as defined in [rfc5646](https://tools.ietf.org/html/rfc5646)\nwith extensions \"u\" and \"t\" as defined in [BCP 47](https://tools.ietf.org/html/bcp47).\n\nLanguage tags are used to help identify languages, whether spoken,\nwritten, signed, or otherwise signaled, for the purpose of\ncommunication.  This includes constructed and artificial languages\nbut excludes languages not intended primarily for human\ncommunication, such as programming languages.","ref":"Cldr.LanguageTag.html"},{"type":"module","title":"Syntax - Cldr.LanguageTag","doc":"A language tag is composed from a sequence of one or more \"subtags\",\neach of which refines or narrows the range of language identified by\nthe overall tag.  Subtags, in turn, are a sequence of alphanumeric\ncharacters (letters and digits), distinguished and separated from\nother subtags in a tag by a hyphen (\"-\", [Unicode] U+002D).\n\nThere are different types of subtag, each of which is distinguished\nby length, position in the tag, and content: each subtag's type can\nbe recognized solely by these features.  This makes it possible to\nextract and assign some semantic information to the subtags, even if\nthe specific subtag values are not recognized.  Thus, a language tag\nprocessor need not have a list of valid tags or subtags (that is, a\ncopy of some version of the IANA Language Subtag Registry) in order\nto perform common searching and matching operations.  The only\nexceptions to this ability to infer meaning from subtag structure are\nthe grandfathered tags listed in the productions 'regular' and\n'irregular' below.  These tags were registered under [RFC3066] and\nare a fixed list that can never change.\n\nThe syntax of the language tag in ABNF is:\n\n Language-Tag  = langtag             ; normal language tags\n               / privateuse          ; private use tag\n               / grandfathered       ; grandfathered tags\n\n langtag       = language\n                 [\"-\" script]\n                 [\"-\" region]\n                 *(\"-\" variant)\n                 *(\"-\" extension)\n                 [\"-\" privateuse]\n\n language      = 2*3ALPHA            ; shortest ISO 639 code\n                 [\"-\" extlang]       ; sometimes followed by\n                                     ; extended language subtags\n               / 4ALPHA              ; or reserved for future use\n               / 5*8ALPHA            ; or registered language subtag\n\n extlang       = 3ALPHA              ; selected ISO 639 codes\n                 *2(\"-\" 3ALPHA)      ; permanently reserved\n\n script        = 4ALPHA              ; ISO 15924 code\n\n region        = 2ALPHA              ; ISO 3166-1 code\n               / 3DIGIT              ; UN M.49 code\n\n variant       = 5*8alphanum         ; registered variants\n               / (DIGIT 3alphanum)\n\n extension     = singleton 1*(\"-\" (2*8alphanum))\n\n                                     ; Single alphanumerics\n                                     ; \"x\" reserved for private use\n singleton     = DIGIT               ; 0 - 9\n               / %x41-57             ; A - W\n               / %x59-5A             ; Y - Z\n               / %x61-77             ; a - w\n               / %x79-7A             ; y - z\n\n privateuse    = \"x\" 1*(\"-\" (1*8alphanum))\n\n grandfathered = irregular           ; non-redundant tags registered\n               / regular             ; during the RFC 3066 era\n\n irregular     = \"en-GB-oed\"         ; irregular tags do not match\n               / \"i-ami\"             ; the 'langtag' production and\n               / \"i-bnn\"             ; would not otherwise be\n               / \"i-default\"         ; considered 'well-formed'\n               / \"i-enochian\"        ; These tags are all valid,\n               / \"i-hak\"             ; but most are deprecated\n               / \"i-klingon\"         ; in favor of more modern\n               / \"i-lux\"             ; subtags or subtag\n               / \"i-mingo\"           ; combination\n               / \"i-navajo\"\n               / \"i-pwn\"\n               / \"i-tao\"\n               / \"i-tay\"\n               / \"i-tsu\"\n               / \"sgn-BE-FR\"\n               / \"sgn-BE-NL\"\n               / \"sgn-CH-DE\"\n\n regular       = \"art-lojban\"        ; these tags match the 'langtag'\n               / \"cel-gaulish\"       ; production, but their subtags\n               / \"no-bok\"            ; are not extended language\n               / \"no-nyn\"            ; or variant subtags: their meaning\n               / \"zh-guoyu\"          ; is defined by their registration\n               / \"zh-hakka\"          ; and all of these are deprecated\n               / \"zh-min\"            ; in favor of a more modern\n               / \"zh-min-nan\"        ; subtag or sequence of subtags\n               / \"zh-xiang\"\n\n alphanum      = (ALPHA / DIGIT)     ; letters and numbers\n\nAll subtags have a maximum length of eight characters.  Whitespace is\nnot permitted in a language tag.  There is a subtlety in the ABNF\nproduction 'variant': a variant starting with a digit has a minimum\nlength of four characters, while those starting with a letter have a\nminimum length of five characters.","ref":"Cldr.LanguageTag.html#module-syntax"},{"type":"module","title":"Unicode BCP 47 Extension type \"u\" - Locale - Cldr.LanguageTag","doc":"Extension | Description                      | Examples\n+-------+ | -------------------------------  | ---------\nca        | Calendar type                    | buddhist, chinese, gregory\ncf        | Currency format style            | standard, account\nco        | Collation type                   | standard, search, phonetic, pinyin\ncu        | Currency type                    | ISO4217 code like \"USD\", \"EUR\"\nfw        | First day of the week identifier | sun, mon, tue, wed, ...\nhc        | Hour cycle identifier            | h12, h23, h11, h24\nlb        | Line break style identifier      | strict, normal, loose\nlw        | Word break identifier            | normal, breakall, keepall, phrase\nms        | Measurement system identifier    | metric, ussystem, uksystem\nmu        | Measurement unit override        | celsius, fahrenhe, kelvin which overrides the ms key\nnu        | Number system identifier         | arabext, armnlow, roman, tamldec\nrg        | Region override                  | The value is a unicode_region_subtag for a regular region (not a macroregion), suffixed by \"ZZZZ\"\nsd        | Subdivision identifier           | A unicode_subdivision_id, which is a unicode_region_subtagconcatenated with a unicode_subdivision_suffix.\nss        | Break suppressions identifier    | none, standard\ntz        | Timezone identifier              | Short identifiers defined in terms of a TZ time zone database\nva        | Common variant type              | POSIX style locale variant","ref":"Cldr.LanguageTag.html#module-unicode-bcp-47-extension-type-u-locale"},{"type":"module","title":"Unicode BCP 47 Extension type \"t\" - Transforms - Cldr.LanguageTag","doc":"Extension | Description\n+-------+ | -----------------------------------------\nmo        | Transform extension mechanism: to reference an authority or rules for a type of transformation\ns0        | Transform source: for non-languages/scripts, such as fullwidth-halfwidth conversion.\nd0        | Transform sdestination: for non-languages/scripts, such as fullwidth-halfwidth conversion.\ni0        | Input Method Engine transform\nk0        | Keyboard transform\nt0        | Machine Translation: Used to indicate content that has been machine translated\nh0        | Hybrid Locale Identifiers: h0 with the value 'hybrid' indicates that the -t- value is a language that is mixed into the main language tag to form a hybrid\nx0        | Private use transform\n\nExtensions are formatted by specifying keyword pairs after an extension\nseparator. The example `de-DE-u-co-phonebk` specifies German as spoken in\nGermany with a collation of `phonebk`.  Another example, \"en-latn-AU-u-cf-account\"\nrepresents English as spoken in Australia, with the number system \"latn\" but\nformatting currencies with the \"accounting\" style.","ref":"Cldr.LanguageTag.html#module-unicode-bcp-47-extension-type-t-transforms"},{"type":"function","title":"Cldr.LanguageTag.parse/1","doc":"Parse a locale name into a `t:Cldr.LanguageTag` struct.","ref":"Cldr.LanguageTag.html#parse/1"},{"type":"function","title":"Arguments - Cldr.LanguageTag.parse/1","doc":"* `locale_name` is any [BCP 47](https://tools.ietf.org/search/bcp47)\n  string.","ref":"Cldr.LanguageTag.html#parse/1-arguments"},{"type":"function","title":"Returns - Cldr.LanguageTag.parse/1","doc":"* `{:ok, t:Cldr.LanguageTag}` or\n\n* `{:error, reason}`","ref":"Cldr.LanguageTag.html#parse/1-returns"},{"type":"function","title":"Cldr.LanguageTag.parse!/1","doc":"Parse a locale name into a `Cldr.LanguageTag` struct and raises on error","ref":"Cldr.LanguageTag.html#parse!/1"},{"type":"function","title":"Arguments - Cldr.LanguageTag.parse!/1","doc":"* `locale_name` is any [BCP 47](https://tools.ietf.org/search/bcp47)\n  string.","ref":"Cldr.LanguageTag.html#parse!/1-arguments"},{"type":"function","title":"Returns - Cldr.LanguageTag.parse!/1","doc":"* `t:Cldr.LanguageTag` or\n\n* raises an exception","ref":"Cldr.LanguageTag.html#parse!/1-returns"},{"type":"type","title":"Cldr.LanguageTag.t/0","doc":"","ref":"Cldr.LanguageTag.html#t:t/0"},{"type":"function","title":"Cldr.LanguageTag.to_string/2","doc":"Reconstitute a textual language tag from a\nLanguageTag that is suitable to pass to a collator.\n\nNote that this function will always calculate the\ncanonical locale name. `Kernel.to_string/1` will\nreturn the pre-calculated canonical locale name and\nis to be preferred.","ref":"Cldr.LanguageTag.html#to_string/2"},{"type":"function","title":"Arguments - Cldr.LanguageTag.to_string/2","doc":"* `locale` is a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n\n* `omit_singular_script?` is a boolean indicating if the\n  script name should be omitted if the landuage_tag territory has\n  only this one script. The default is `false`.","ref":"Cldr.LanguageTag.html#to_string/2-arguments"},{"type":"function","title":"Returns - Cldr.LanguageTag.to_string/2","doc":"* A formatted string representation of the language tag that is also\n  parseable back into a `Cldr.LanguageTag.t()`","ref":"Cldr.LanguageTag.html#to_string/2-returns"},{"type":"function","title":"Examples - Cldr.LanguageTag.to_string/2","doc":"iex> {:ok, locale} = Cldr.validate_locale \"en-US\", MyApp.Cldr\n    iex> Cldr.LanguageTag.to_string(locale)\n    \"en-US\"\n\n    iex> {:ok, locale} = Cldr.validate_locale \"en-US-u-co-phonebk-nu-arab\", MyApp.Cldr\n    iex> Cldr.LanguageTag.to_string(locale)\n    \"en-US-u-co-phonebk-nu-arab\"","ref":"Cldr.LanguageTag.html#to_string/2-examples"},{"type":"exception","title":"Cldr.LanguageTag.ParseError","doc":"Exception raised when a language tag cannot\nbe parsed (there is unparsed content).","ref":"Cldr.LanguageTag.ParseError.html"},{"type":"module","title":"Cldr.LanguageTag.Parser","doc":"Parses a CLDR language tag (also referred to as locale string).\n\nThe applicable specification is from [CLDR](http://unicode.org/reports/tr35/#Unicode_Language_and_Locale_Identifiers)\nwhich is similar based upon [RFC5646](https://tools.ietf.org/html/rfc5646) with some variations.","ref":"Cldr.LanguageTag.Parser.html"},{"type":"function","title":"Cldr.LanguageTag.Parser.normalize_field/1","doc":"","ref":"Cldr.LanguageTag.Parser.html#normalize_field/1"},{"type":"function","title":"Cldr.LanguageTag.Parser.parse/1","doc":"Parse a locale name into a `t:Cldr.LanguageTag`\n\n* `locale_name` is a string representation of a language tag\n  as defined by [RFC5646](https://tools.ietf.org/html/rfc5646).\n\nReturns\n\n* `{:ok, language_tag}` or\n\n* `{:error, reasons}`","ref":"Cldr.LanguageTag.Parser.html#parse/1"},{"type":"function","title":"Cldr.LanguageTag.Parser.parse!/1","doc":"Parse a locale name into a `t:Cldr.LanguageTag`\n\n* `locale_name` is a string representation of a language tag\n  as defined by [RFC5646](https://tools.ietf.org/html/rfc5646).\n\nReturns\n\n* `language_tag` or\n\n* raises an exception","ref":"Cldr.LanguageTag.Parser.html#parse!/1"},{"type":"module","title":"Cldr.LanguageTag.Sigil","doc":"Implements a `sigil_l/2` macro to\nconstructing `t:Cldr.LanguageTag` structs.","ref":"Cldr.LanguageTag.Sigil.html"},{"type":"macro","title":"Cldr.LanguageTag.Sigil.sigil_l/2","doc":"Handles sigil `~l` for language tags.","ref":"Cldr.LanguageTag.Sigil.html#sigil_l/2"},{"type":"macro","title":"Arguments - Cldr.LanguageTag.Sigil.sigil_l/2","doc":"* `locale_name` is either a [BCP 47](https://unicode-org.github.io/cldr/ldml/tr35.html#Identifiers)\nlocale name as a string or\n\n* `locale_name` | `backend` where backend is a backend module name.","ref":"Cldr.LanguageTag.Sigil.html#sigil_l/2-arguments"},{"type":"macro","title":"Options - Cldr.LanguageTag.Sigil.sigil_l/2","doc":"* `u` Will parse the locale but will not add\n  likely subtags and its not guaranteed that this\n  language tag is known to the backend module.","ref":"Cldr.LanguageTag.Sigil.html#sigil_l/2-options"},{"type":"macro","title":"Returns - Cldr.LanguageTag.Sigil.sigil_l/2","doc":"* a `t:Cldr.LanguageTag.t/0` struct or\n\n* raises an exception.","ref":"Cldr.LanguageTag.Sigil.html#sigil_l/2-returns"},{"type":"macro","title":"Examples - Cldr.LanguageTag.Sigil.sigil_l/2","doc":"iex> import Cldr.LanguageTag.Sigil\n    iex> inspect(~l(en-US-u-ca-gregory))\n    \"TestBackend.Cldr.Locale.new!(\\\"en-US-u-ca-gregory\\\")\"\n\n    iex> import Cldr.LanguageTag.Sigil\n    iex> inspect(~l(en-US-u-ca-gregory|MyApp.Cldr))\n    \"MyApp.Cldr.Locale.new!(\\\"en-US-u-ca-gregory\\\")\"\n\n    iex> import Cldr.LanguageTag.Sigil\n    iex> inspect(~l(en))\n    \"TestBackend.Cldr.Locale.new!(\\\"en-US\\\")\"\n\n    iex> import Cldr.LanguageTag.Sigil\n    iex> inspect(~l(en)u)\n    \"TestBackend.Cldr.Locale.new!(\\\"en\\\")\"","ref":"Cldr.LanguageTag.Sigil.html#sigil_l/2-examples"},{"type":"module","title":"Cldr.LanguageTag.T","doc":"Defines the struct for the BCP 47 `t`\nextension.","ref":"Cldr.LanguageTag.T.html"},{"type":"function","title":"Cldr.LanguageTag.T.display_name/2","doc":"","ref":"Cldr.LanguageTag.T.html#display_name/2"},{"type":"function","title":"Cldr.LanguageTag.T.format_key_type/2","doc":"","ref":"Cldr.LanguageTag.T.html#format_key_type/2"},{"type":"function","title":"Cldr.LanguageTag.T.join_field_values/2","doc":"","ref":"Cldr.LanguageTag.T.html#join_field_values/2"},{"type":"type","title":"Cldr.LanguageTag.T.t/0","doc":"Defines the [BCP 47 `t` extension](https://unicode-org.github.io/cldr/ldml/tr35.html#t_Extension)\nof a `t:Cldr.LanguageTag`.","ref":"Cldr.LanguageTag.T.html#t:t/0"},{"type":"module","title":"Cldr.LanguageTag.U","doc":"Defines the struct for the BCP 47 `u`\nextension.","ref":"Cldr.LanguageTag.U.html"},{"type":"function","title":"Cldr.LanguageTag.U.encode/1","doc":"","ref":"Cldr.LanguageTag.U.html#encode/1"},{"type":"type","title":"Cldr.LanguageTag.U.t/0","doc":"Defines the [BCP 47 `u` extension](https://unicode-org.github.io/cldr/ldml/tr35.html#u_Extension)\nof a `t:Cldr.LanguageTag`.","ref":"Cldr.LanguageTag.U.html#t:t/0"},{"type":"module","title":"Cldr.Number.PluralRule","doc":"Defines the plural rule implementation\nmodules. The functions in this module\ngenerate code to implement the plural\nrules of CLDR.","ref":"Cldr.Number.PluralRule.html"},{"type":"function","title":"Cldr.Number.PluralRule.known_plural_types/0","doc":"Returns a list of the possible pluralization\ntypes","ref":"Cldr.Number.PluralRule.html#known_plural_types/0"},{"type":"type","title":"Cldr.Number.PluralRule.operand/0","doc":"","ref":"Cldr.Number.PluralRule.html#t:operand/0"},{"type":"type","title":"Cldr.Number.PluralRule.plural_rule/0","doc":"Defines the structure of a plural rule before compilation.","ref":"Cldr.Number.PluralRule.html#t:plural_rule/0"},{"type":"type","title":"Cldr.Number.PluralRule.plural_type/0","doc":"Defines the plural types into which a number can be categorised.","ref":"Cldr.Number.PluralRule.html#t:plural_type/0"},{"type":"function","title":"Cldr.Number.PluralRule.plural_type/3","doc":"Returns the plural type for a given number.","ref":"Cldr.Number.PluralRule.html#plural_type/3"},{"type":"function","title":"Arguments - Cldr.Number.PluralRule.plural_type/3","doc":"* `number` is an integer, float or Decimal number.\n\n* `backend` is any module that includes `use Cldr` and therefore\n  is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n\n* `options` is a keyword list of options.","ref":"Cldr.Number.PluralRule.html#plural_type/3-arguments"},{"type":"function","title":"Options - Cldr.Number.PluralRule.plural_type/3","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`, The\n  default is `Cldr.get_locale/0`.\n\n* `backend` is any module that includes `use Cldr` and therefore\n   is a `Cldr` backend module.  The default is `Cldr.default_backend!/0`.\n   This option allows the backend to be specified as an argument or an option.\n\n* `type` is either `Cardinal` or `Ordinal`. The default is `Cardinal`.","ref":"Cldr.Number.PluralRule.html#plural_type/3-options"},{"type":"function","title":"Examples - Cldr.Number.PluralRule.plural_type/3","doc":"iex> Cldr.Number.PluralRule.plural_type(123)\n  \t:other\n\n  \tiex> Cldr.Number.PluralRule.plural_type(123, type: Ordinal)\n  \t:few\n\n  \tiex> Cldr.Number.PluralRule.plural_type(123, type: Cardinal)\n  \t:other\n\n  \tiex> Cldr.Number.PluralRule.plural_type(2, locale: \"de\")\n  \t:other","ref":"Cldr.Number.PluralRule.html#plural_type/3-examples"},{"type":"protocol","title":"Cldr.Chars","doc":"The `Cldr.Chars` protocol mirrors the\n`String.Chars` protocol but localises\n the output. It is intended to be\n drop-in replacement for `String.Chars`.","ref":"Cldr.Chars.html"},{"type":"type","title":"Cldr.Chars.t/0","doc":"All the types that implement this protocol.","ref":"Cldr.Chars.html#t:t/0"},{"type":"function","title":"Cldr.Chars.to_string/1","doc":"Converts `term` to a localised string.","ref":"Cldr.Chars.html#to_string/1"},{"type":"protocol","title":"Cldr.DisplayName","doc":"Returns the localised display name\nfor a CLDR struct (locale, unit, currency)","ref":"Cldr.DisplayName.html"},{"type":"function","title":"Cldr.DisplayName.display_name/2","doc":"","ref":"Cldr.DisplayName.html#display_name/2"},{"type":"type","title":"Cldr.DisplayName.t/0","doc":"All the types that implement this protocol.","ref":"Cldr.DisplayName.html#t:t/0"},{"type":"module","title":"Cldr.Gettext.Plural","doc":"Implements a macro to define a CLDR-based Gettext plural\nmodule\n\n[gettext](https://hexdocs.pm/gettext) allows for user-defined\n[plural forms](https://hexdocs.pm/gettext/Gettext.Plural.html#content) modules\nto be configured for a [gettext backend](https://hexdocs.pm/gettext/Gettext.Backend.html#content).\n\nTo define a plural forms module that uses [CLDR plural rules](https://cldr.unicode.org/index/cldr-spec/plural-rules)\ncreate a new module and then `use Cldr.Gettext.Plural`. For example:\n\n    defmodule MyApp.Gettext.Plural do\n      use Cldr.Gettext.Plural, cldr_backend: MyApp.Cldr\n\n    end\n\nThis module can then be used in the configuration of a `gettext` backend.\nFor example:\n\n    defmodule MyApp.Gettext do\n      use Gettext, plural_forms: MyApp.Gettext.Plural\n\n    end","ref":"Cldr.Gettext.Plural.html"},{"type":"macro","title":"Cldr.Gettext.Plural.__using__/1","doc":"Configure a module to be a [gettext plural](https://hexdocs.pm/gettext/Gettext.Plural.html#content)\nmodule.\n\nA CLDR-based `gettext` plural module is defined by including `use Cldr.Gettext.Plural`\nas in this example:\n\n    defmodule MyApp.Gettext.Plural do\n      use Cldr.Gettext.Plural, cldr_backend: MyApp.Cldr\n\n    end","ref":"Cldr.Gettext.Plural.html#__using__/1"},{"type":"macro","title":"Arguments - Cldr.Gettext.Plural.__using__/1","doc":"* `options` is a keyword list of options. The default is `[]`","ref":"Cldr.Gettext.Plural.html#__using__/1-arguments"},{"type":"macro","title":"Options - Cldr.Gettext.Plural.__using__/1","doc":"* `:cldr_backend` is any CLDR [backend](https://hexdocs.pm/ex_cldr/readme.html#backend-module-configuration)\n  module. The default is `Cldr.default_backend!/0`.","ref":"Cldr.Gettext.Plural.html#__using__/1-options"},{"type":"module","title":"Cldr.Config","doc":"Provider configuration support\nfunctions for ex_cldr.\n\nThe functions in this module should\nbe considered private use and they\nmay change at any time.","ref":"Cldr.Config.html"},{"type":"function","title":"Cldr.Config.aliases/0","doc":"Returns the map of aliases for languages,\nscripts and regions","ref":"Cldr.Config.html#aliases/0"},{"type":"function","title":"Cldr.Config.all_language_tags/0","doc":"Returns the map of language tags for all\navailable locales","ref":"Cldr.Config.html#all_language_tags/0"},{"type":"function","title":"Cldr.Config.all_language_tags?/0","doc":"Returns a boolean indicating whether the language_tags.ebin\nfile exists","ref":"Cldr.Config.html#all_language_tags?/0"},{"type":"function","title":"Cldr.Config.all_locale_names/0","doc":"Returns a list of all locales in the CLDR repository.\n\nReturns a list of the complete locales list in CLDR, irrespective\nof whether they are configured for use in the application.\n\nAny configured locales that are not present in this list will\nraise an exception at compile time.","ref":"Cldr.Config.html#all_locale_names/0"},{"type":"function","title":"Cldr.Config.app_name/0","doc":"Return the configured application name\nfor cldr\n\nNote this is probably `:ex_cldr` which is\nwhat this app is called on `hex.pm`","ref":"Cldr.Config.html#app_name/0"},{"type":"function","title":"Cldr.Config.calendar_data/0","doc":"","ref":"Cldr.Config.html#calendar_data/0"},{"type":"function","title":"Cldr.Config.calendar_preferences/0","doc":"Return the map of calendar preferences by territory","ref":"Cldr.Config.html#calendar_preferences/0"},{"type":"function","title":"Cldr.Config.calendars/0","doc":"Returns the data that defines start and end of\ncalendar eras.","ref":"Cldr.Config.html#calendars/0"},{"type":"function","title":"Example - Cldr.Config.calendars/0","doc":"iex> Cldr.Config.calendars() |> Map.get(:gregorian)\n    %{\n      calendar_system: :solar,\n      eras: [\n        [0, %{end: [0, 12, 31], aliases: [\"bc\", \"bce\"], code: :gregory_inverse}],\n        [1, %{start: [1, 1, 1], aliases: [\"ad\", \"ce\"], code: :gregory}]\n      ]\n    }","ref":"Cldr.Config.html#calendars/0-example"},{"type":"function","title":"Cldr.Config.calendars_for_locale/2","doc":"Returns the calendars available for a given locale name","ref":"Cldr.Config.html#calendars_for_locale/2"},{"type":"function","title":"Example - Cldr.Config.calendars_for_locale/2","doc":"iex> Cldr.Config.calendars_for_locale \"en\", TestBackend.Cldr\n    [:buddhist, :chinese, :coptic, :dangi, :ethiopic, :ethiopic_amete_alem,\n     :generic, :gregorian, :hebrew, :indian, :islamic, :islamic_civil,\n     :islamic_rgsa, :islamic_tbla, :islamic_umalqura, :iso8601, :japanese, :persian, :roc]","ref":"Cldr.Config.html#calendars_for_locale/2-example"},{"type":"function","title":"Cldr.Config.canonical_name/1","doc":"","ref":"Cldr.Config.html#canonical_name/1"},{"type":"function","title":"Cldr.Config.cldr_data_dir/0","doc":"Returns the path of the CLDR data directory for the ex_cldr app.\n\nThis is the directory where base CLDR data files are stored\nincluding included locale files.","ref":"Cldr.Config.html#cldr_data_dir/0"},{"type":"function","title":"Cldr.Config.cldr_home/0","doc":"Return the root path of the cldr application","ref":"Cldr.Config.html#cldr_home/0"},{"type":"function","title":"Cldr.Config.client_data_dir/1","doc":"Return the path name of the CLDR data directory for a client\napplication.\n\nThe order of priority to determine where the client data\ndirectory is located is:\n\n* A specified `:data_dir` of a backend configuration\n* The specified `:data_dir` of the backend's `:otp_app` configuration\n* The specified `:data_dir` of the global configuration\n* The `priv_dir()` of a specified `:otp_app`\n* The `priv_dir()` of `ex_cldr`\n\nNote that `config_from_opts/1` merges the global config,\nthe otp_app config and the module config together so\nthat `:data_dir` already resolves this priority in most\ncases.\n\nThe remaining cases are for when no `:data_dir` is\nspecified.","ref":"Cldr.Config.html#client_data_dir/1"},{"type":"function","title":"Cldr.Config.client_locales_dir/1","doc":"Returns the directory where downloaded ex_cldr locales files\nare located.","ref":"Cldr.Config.html#client_locales_dir/1"},{"type":"function","title":"Cldr.Config.configured_locale_names/1","doc":"Returns a list of all locales configured in a\n`Cldr.Config.t` struct.\n\nIn order of priority return either:\n\n* The list of locales configured configured in mix.exs if any\n\n* The default locale\n\nIf the configured locales is `:all` then all locales\nin CLDR are configured.\n\nThe locale \"und\" is always added to the list of configured locales since it\nis required to support some RBNF functions.\n\nThe use of `:all` is not recommended since all 571 locales take\nquite some time (minutes) to compile. It is however\nhelpful for testing Cldr.","ref":"Cldr.Config.html#configured_locale_names/1"},{"type":"function","title":"Cldr.Config.currencies_for/2","doc":"Returns the currency metadata for a locale.","ref":"Cldr.Config.html#currencies_for/2"},{"type":"function","title":"Arguments - Cldr.Config.currencies_for/2","doc":"* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n\n* `config` is a `Config.Cldr.t()` struct or a `Cldr.backend()` module","ref":"Cldr.Config.html#currencies_for/2-arguments"},{"type":"function","title":"Cldr.Config.currencies_for!/2","doc":"","ref":"Cldr.Config.html#currencies_for!/2"},{"type":"function","title":"Cldr.Config.day_period_info/0","doc":"Returns the data that defines time periods of\na day for a language.\n\nTime period rules are used to define the meaning\nof \"morning\", \"evening\", \"noon\", \"midnight\" and\npotentially other periods on a per-language basis.","ref":"Cldr.Config.html#day_period_info/0"},{"type":"function","title":"Example - Cldr.Config.day_period_info/0","doc":"iex> Cldr.Config.day_period_info() |> Map.get(\"fr\")\n    %{\"afternoon1\" => %{\"before\" => [18, 0], \"from\" => [12, 0]},\n      \"evening1\" => %{\"before\" => [24, 0], \"from\" => [18, 0]},\n      \"midnight\" => %{\"at\" => [0, 0]},\n      \"morning1\" => %{\"before\" => [12, 0], \"from\" => [4, 0]},\n      \"night1\" => %{\"before\" => [4, 0], \"from\" => [0, 0]},\n      \"noon\" => %{\"at\" => [12, 0]}}","ref":"Cldr.Config.html#day_period_info/0-example"},{"type":"function","title":"Cldr.Config.default_backend/0","doc":"Return the system-wide default backend","ref":"Cldr.Config.html#default_backend/0"},{"type":"function","title":"Cldr.Config.default_locale/0","doc":"Return the system-wide default locale.","ref":"Cldr.Config.html#default_locale/0"},{"type":"function","title":"Cldr.Config.default_locale_name/1","doc":"Return the default locale name for a given backend\nconfiguration.\n\nIn order of priority return either:\n\n* The default locale for a given backend configuration\n* The global default locale specified in `mix.exs` under\n  the `ex_cldr` key\n* The `Gettext.get_locale/1` for the current configuration\n* The system-wide default locale which is currently\n  :\"en-001\"","ref":"Cldr.Config.html#default_locale_name/1"},{"type":"function","title":"Cldr.Config.download_data_dir/0","doc":"Returns the directory where the downloaded CLDR repository files\nare stored.\n\nThese are the real CLDR data files that are used only for the\ndevelopment of ex_cldr.  They are not included in the hex\npackage.","ref":"Cldr.Config.html#download_data_dir/0"},{"type":"function","title":"Cldr.Config.expand_locale_names/1","doc":"Expands wildcards in locale names.\n\nLocales often have region variants (for example en-AU is one of 104\nvariants in CLDR).  To make it easier to configure a language and all\nits variants, a locale can be specified as a regex which will\nthen do a match against all CLDR locales.\n\nFor locale names that have a Script or Variant component the base\nlanguage is also configured since plural rules will fall back to the\nlanguage for these locale names.","ref":"Cldr.Config.html#expand_locale_names/1"},{"type":"function","title":"Examples - Cldr.Config.expand_locale_names/1","doc":"iex> Cldr.Config.expand_locale_names([\"en-A+\"])\n    [:en, :\"en-AE\", :\"en-AG\", :\"en-AI\", :\"en-AS\", :\"en-AT\", :\"en-AU\"]\n\n    iex> Cldr.Config.expand_locale_names([\"fr-*\"])\n    [\n      :fr, :\"fr-BE\", :\"fr-BF\", :\"fr-BI\", :\"fr-BJ\", :\"fr-BL\", :\"fr-CA\",\n      :\"fr-CD\", :\"fr-CF\", :\"fr-CG\", :\"fr-CH\", :\"fr-CI\", :\"fr-CM\", :\"fr-DJ\",\n      :\"fr-DZ\", :\"fr-GA\", :\"fr-GF\", :\"fr-GN\", :\"fr-GP\", :\"fr-GQ\", :\"fr-HT\",\n      :\"fr-KM\", :\"fr-LU\", :\"fr-MA\", :\"fr-MC\", :\"fr-MF\", :\"fr-MG\", :\"fr-ML\",\n      :\"fr-MQ\", :\"fr-MR\", :\"fr-MU\", :\"fr-NC\", :\"fr-NE\", :\"fr-PF\", :\"fr-PM\",\n      :\"fr-RE\", :\"fr-RW\", :\"fr-SC\", :\"fr-SN\", :\"fr-SY\", :\"fr-TD\", :\"fr-TG\",\n      :\"fr-TN\", :\"fr-VU\", :\"fr-WF\", :\"fr-YT\"\n    ]","ref":"Cldr.Config.html#expand_locale_names/1-examples"},{"type":"function","title":"Cldr.Config.fallback/1","doc":"Returns the immediate fallback locale for a\nlocale name. Follows the CLDR [TR35](https://unicode.org/reports/tr35/tr35.html#Bundle_vs_Item_Lookup)\nresource bundle lookup algorithm.\n\nThis function is only intended to\nreturn the fallback for the locales\ndefined by CLDR. It does not perform\nany alias lookup or likely subtag\nprocessing.","ref":"Cldr.Config.html#fallback/1"},{"type":"function","title":"Algorithm Summary - Cldr.Config.fallback/1","doc":"1. Decompose the locale name into language,\n   script, territory and variant. CLDR locale\n   names have no more than these four parts but\n   usually have less.\n\n2. Look for a locale in the following order:\n   * language-script-territory\n   * language-script\n   * language-territory\n   * language\n\n3. At each stage in (2) resolve\n   an alias in `parent_locales/1`","ref":"Cldr.Config.html#fallback/1-algorithm-summary"},{"type":"function","title":"Cldr.Config.fallback_chain/1","doc":"Returns the fallback chain for a\nlocale name. Follows the CLDR [TR35](https://unicode.org/reports/tr35/tr35.html#Bundle_vs_Item_Lookup)\nresource bundle lookup algorithm.\n\nThis function is only intended to\nreturn fallback chains for the locales\ndefined by CLDR. It does not perform\nany alias lookup or likely subtag\nprocessing.\n\nThe primary purpose for this function is\nto support including fallback locales\nin a backend configuration since both\nRBNF and Subdivision data follows the\nfallback chain.","ref":"Cldr.Config.html#fallback_chain/1"},{"type":"function","title":"Algorithm Summary - Cldr.Config.fallback_chain/1","doc":"1. Decompose the locale name into language,\n   script, territory and variant. CLDR locale\n   names have no more than these four parts but\n   usually have less.\n\n2. Look for a locale in the following order:\n   * language-script-territory\n   * language-script\n   * language-territory\n   * language\n\n3. At each stage in (2) resolve\n   an alias in `parent_locales/1`","ref":"Cldr.Config.html#fallback_chain/1-algorithm-summary"},{"type":"function","title":"Cldr.Config.get_precompile_number_formats/1","doc":"Get the configured number formats that should be precompiled at application\ncompilation time.","ref":"Cldr.Config.html#get_precompile_number_formats/1"},{"type":"function","title":"Cldr.Config.gettext/1","doc":"Return the configured `Gettext` module name or `nil`.","ref":"Cldr.Config.html#gettext/1"},{"type":"function","title":"Cldr.Config.gettext_configured?/1","doc":"Returns true if a `Gettext` module is configured in Cldr and\nthe `Gettext` module is available.","ref":"Cldr.Config.html#gettext_configured?/1"},{"type":"function","title":"Example - Cldr.Config.gettext_configured?/1","doc":"iex> test_config = TestBackend.Cldr.__cldr__(:config)\n    iex> Cldr.Config.gettext_configured?(test_config)\n    true","ref":"Cldr.Config.html#gettext_configured?/1-example"},{"type":"function","title":"Cldr.Config.gettext_default_locale/1","doc":"Return the default gettext locale for a CLDR\nconfig.","ref":"Cldr.Config.html#gettext_default_locale/1"},{"type":"function","title":"Cldr.Config.grammatical_features/0","doc":"Returns the CLDR grammatical features data\nwhich is used with formatting units.","ref":"Cldr.Config.html#grammatical_features/0"},{"type":"function","title":"Cldr.Config.grammatical_gender/0","doc":"Returns the CLDR grammatical gender data\nwhich is used with formatting units.","ref":"Cldr.Config.html#grammatical_gender/0"},{"type":"function","title":"Cldr.Config.include_module_docs?/1","doc":"","ref":"Cldr.Config.html#include_module_docs?/1"},{"type":"function","title":"Cldr.Config.json_library/0","doc":"Return the configured json lib","ref":"Cldr.Config.html#json_library/0"},{"type":"function","title":"Cldr.Config.known_calendars/0","doc":"Returns a list of strings representing the calendars known to `Cldr`.","ref":"Cldr.Config.html#known_calendars/0"},{"type":"function","title":"Example - Cldr.Config.known_calendars/0","doc":"iex> Cldr.Config.known_calendars()\n    [:buddhist, :chinese, :coptic, :dangi, :ethiopic, :ethiopic_amete_alem,\n     :gregorian, :hebrew, :indian, :islamic, :islamic_civil, :islamic_rgsa,\n     :islamic_tbla, :islamic_umalqura, :japanese, :persian, :roc]","ref":"Cldr.Config.html#known_calendars/0-example"},{"type":"function","title":"Cldr.Config.known_currencies/0","doc":"Returns a list of the currencies known in `Cldr` in\nupcased atom format.","ref":"Cldr.Config.html#known_currencies/0"},{"type":"function","title":"Example - Cldr.Config.known_currencies/0","doc":"iex> Cldr.Config.known_currencies()\n    [:ADP, :AED, :AFA, :AFN, :ALK, :ALL, :AMD, :ANG, :AOA, :AOK, :AON, :AOR, :ARA,\n     :ARL, :ARM, :ARP, :ARS, :ATS, :AUD, :AWG, :AZM, :AZN, :BAD, :BAM, :BAN, :BBD,\n     :BDT, :BEC, :BEF, :BEL, :BGL, :BGM, :BGN, :BGO, :BHD, :BIF, :BMD, :BND, :BOB,\n     :BOL, :BOP, :BOV, :BRB, :BRC, :BRE, :BRL, :BRN, :BRR, :BRZ, :BSD, :BTN, :BUK,\n     :BWP, :BYB, :BYN, :BYR, :BZD, :CAD, :CDF, :CHE, :CHF, :CHW, :CLE, :CLF, :CLP,\n     :CNH, :CNX, :CNY, :COP, :COU, :CRC, :CSD, :CSK, :CUC, :CUP, :CVE, :CYP, :CZK,\n     :DDM, :DEM, :DJF, :DKK, :DOP, :DZD, :ECS, :ECV, :EEK, :EGP, :ERN, :ESA, :ESB,\n     :ESP, :ETB, :EUR, :FIM, :FJD, :FKP, :FRF, :GBP, :GEK, :GEL, :GHC, :GHS, :GIP,\n     :GMD, :GNF, :GNS, :GQE, :GRD, :GTQ, :GWE, :GWP, :GYD, :HKD, :HNL, :HRD, :HRK,\n     :HTG, :HUF, :IDR, :IEP, :ILP, :ILR, :ILS, :INR, :IQD, :IRR, :ISJ, :ISK, :ITL,\n     :JMD, :JOD, :JPY, :KES, :KGS, :KHR, :KMF, :KPW, :KRH, :KRO, :KRW, :KWD, :KYD,\n     :KZT, :LAK, :LBP, :LKR, :LRD, :LSL, :LTL, :LTT, :LUC, :LUF, :LUL, :LVL, :LVR,\n     :LYD, :MAD, :MAF, :MCF, :MDC, :MDL, :MGA, :MGF, :MKD, :MKN, :MLF, :MMK, :MNT,\n     :MOP, :MRO, :MRU, :MTL, :MTP, :MUR, :MVP, :MVR, :MWK, :MXN, :MXP, :MXV, :MYR,\n     :MZE, :MZM, :MZN, :NAD, :NGN, :NIC, :NIO, :NLG, :NOK, :NPR, :NZD, :OMR, :PAB,\n     :PEI, :PEN, :PES, :PGK, :PHP, :PKR, :PLN, :PLZ, :PTE, :PYG, :QAR, :RHD, :ROL,\n     :RON, :RSD, :RUB, :RUR, :RWF, :SAR, :SBD, :SCR, :SDD, :SDG, :SDP, :SEK, :SGD,\n     :SHP, :SIT, :SKK, :SLE, :SLL, :SOS, :SRD, :SRG, :SSP, :STD, :STN, :SUR, :SVC,\n     :SYP, :SZL, :THB, :TJR, :TJS, :TMM, :TMT, :TND, :TOP, :TPE, :TRL, :TRY, :TTD,\n     :TWD, :TZS, :UAH, :UAK, :UGS, :UGX, :USD, :USN, :USS, :UYI, :UYP, :UYU, :UYW,\n     :UZS, :VEB, :VED, :VEF, :VES, :VND, :VNN, :VUV, :WST, :XAF, :XAG, :XAU, :XBA,\n     :XBB, :XBC, :XBD, :XCD, :XCG, :XDR, :XEU, :XFO, :XFU, :XOF, :XPD, :XPF, :XPT,\n     :XRE, :XSU, :XTS, :XUA, :XXX, :YDD, :YER, :YUD, :YUM, :YUN, :YUR, :ZAL, :ZAR,\n     :ZMK, :ZMW, :ZRN,:ZRZ, :ZWD, :ZWG, :ZWL, :ZWR]","ref":"Cldr.Config.html#known_currencies/0-example"},{"type":"function","title":"Cldr.Config.known_gettext_locale_names/1","doc":"Return a list of the locales defined in `Gettext`.\n\nReturn a list of locales configured in `Gettext` or\n`[]` if `Gettext` is not configured.","ref":"Cldr.Config.html#known_gettext_locale_names/1"},{"type":"function","title":"Cldr.Config.known_locale_name/2","doc":"Returns either the locale name (if its known)\nor `false` if the locale name is not known.","ref":"Cldr.Config.html#known_locale_name/2"},{"type":"function","title":"Cldr.Config.known_locale_names/1","doc":"Returns a list of all locales that are configured and available\nin the CLDR repository.","ref":"Cldr.Config.html#known_locale_names/1"},{"type":"function","title":"Cldr.Config.known_number_system_types/1","doc":"Returns the number system types that\nare known.","ref":"Cldr.Config.html#known_number_system_types/1"},{"type":"function","title":"Cldr.Config.known_number_systems/0","doc":"Returns a list of strings representing the number systems known to `Cldr`.","ref":"Cldr.Config.html#known_number_systems/0"},{"type":"function","title":"Example - Cldr.Config.known_number_systems/0","doc":"iex> Cldr.Config.known_number_systems()\n    [:adlm, :ahom, :arab, :arabext, :armn, :armnlow, :bali, :beng, :bhks, :brah,\n     :cakm, :cham, :cyrl, :deva, :diak, :ethi, :fullwide, :gara, :geor, :gong,\n     :gonm, :grek, :greklow, :gujr, :gukh, :guru, :hanidays, :hanidec, :hans,\n     :hansfin, :hant, :hantfin, :hebr, :hmng, :hmnp, :java, :jpan, :jpanfin,\n     :jpanyear, :kali, :kawi, :khmr, :knda, :krai, :lana, :lanatham, :laoo, :latn,\n     :lepc, :limb, :mathbold, :mathdbl, :mathmono, :mathsanb, :mathsans, :mlym,\n     :modi, :mong, :mroo, :mtei, :mymr, :mymrepka, :mymrpao, :mymrshan, :mymrtlng,\n     :nagm, :newa, :nkoo, :olck, :onao, :orya, :osma, :outlined, :rohg, :roman,\n     :romanlow, :saur, :segment, :shrd, :sind, :sinh, :sora, :sund, :sunu, :takr,\n     :talu, :taml, :tamldec, :telu, :thai, :tibt, :tirh, :tnsa, :vaii, :wara, :wcho]","ref":"Cldr.Config.html#known_number_systems/0-example"},{"type":"function","title":"Cldr.Config.known_number_systems_like/3","doc":"Returns locale and number systems that have the same digits and\nseparators as the supplied one.\n\nTransliterating between locale & number systems is expensive.  To avoid\nunnecessary transliteration we look for locale and number systems that have\nthe same digits and separators.  Typically we are comparing to locale \"en\"\nand number system \"latn\" since this is what the number formatting routines use\nas placeholders.\n\nThis function is intended for use at compile time only and is\nused to help optimise the generation of transliteration functions.","ref":"Cldr.Config.html#known_number_systems_like/3"},{"type":"function","title":"Cldr.Config.known_rbnf_locale_name/2","doc":"Returns either the locale name (if its known\nand has an rbnf configuration)\nor `false`.","ref":"Cldr.Config.html#known_rbnf_locale_name/2"},{"type":"function","title":"Cldr.Config.known_rbnf_locale_names/1","doc":"Returns a list of all locales that have RBNF data and that are\nconfigured and available in the CLDR repository.","ref":"Cldr.Config.html#known_rbnf_locale_names/1"},{"type":"function","title":"Cldr.Config.known_territories/0","doc":"Returns a list of atoms representing the territories known to `Cldr`.","ref":"Cldr.Config.html#known_territories/0"},{"type":"function","title":"Example - Cldr.Config.known_territories/0","doc":"iex> Cldr.Config.known_territories()\n    [:\"001\", :\"002\", :\"003\", :\"005\", :\"009\", :\"011\", :\"013\", :\"014\", :\"015\", :\"017\",\n     :\"018\", :\"019\", :\"021\", :\"029\", :\"030\", :\"034\", :\"035\", :\"039\", :\"053\", :\"054\",\n     :\"057\", :\"061\", :\"142\", :\"143\", :\"145\", :\"150\", :\"151\", :\"154\", :\"155\", :\"202\",\n     :\"419\", :AC, :AD, :AE, :AF, :AG, :AI, :AL, :AM, :AO, :AQ, :AR, :AS, :AT, :AU,\n     :AW, :AX, :AZ, :BA, :BB, :BD, :BE, :BF, :BG, :BH, :BI, :BJ, :BL, :BM, :BN, :BO,\n     :BQ, :BR, :BS, :BT, :BV, :BW, :BY, :BZ, :CA, :CC, :CD, :CF, :CG, :CH, :CI, :CK,\n     :CL, :CM, :CN, :CO, :CP, :CQ, :CR, :CU, :CV, :CW, :CX, :CY, :CZ, :DE, :DG, :DJ,\n     :DK, :DM, :DO, :DZ, :EA, :EC, :EE, :EG, :EH, :ER, :ES, :ET, :EU, :EZ, :FI, :FJ,\n     :FK, :FM, :FO, :FR, :GA, :GB, :GD, :GE, :GF, :GG, :GH, :GI, :GL, :GM, :GN, :GP,\n     :GQ, :GR, :GS, :GT, :GU, :GW, :GY, :HK, :HM, :HN, :HR, :HT, :HU, :IC, :ID, :IE,\n     :IL, :IM, :IN, :IO, :IQ, :IR, :IS, :IT, :JE, :JM, :JO, :JP, :KE, :KG, :KH, :KI,\n     :KM, :KN, :KP, :KR, :KW, :KY, :KZ, :LA, :LB, :LC, :LI, :LK, :LR, :LS, :LT, :LU,\n     :LV, :LY, :MA, :MC, :MD, :ME, :MF, :MG, :MH, :MK, :ML, :MM, :MN, :MO, :MP, :MQ,\n     :MR, :MS, :MT, :MU, :MV, :MW, :MX, :MY, :MZ, :NA, :NC, :NE, :NF, :NG, :NI, :NL,\n     :NO, :NP, :NR, :NU, :NZ, :OM, :PA, :PE, :PF, :PG, :PH, :PK, :PL, :PM, :PN, :PR,\n     :PS, :PT, :PW, :PY, :QA, :QO, :RE, :RO, :RS, :RU, :RW, :SA, :SB, :SC, :SD, :SE,\n     :SG, :SH, :SI, :SJ, :SK, :SL, :SM, :SN, :SO, :SR, :SS, :ST, :SV, :SX, :SY, :SZ,\n     :TA, :TC, :TD, :TF, :TG, :TH, :TJ, :TK, :TL, :TM, :TN, :TO, :TR, :TT, :TV, :TW,\n     :TZ, :UA, :UG, :UM, :UN, :US, :UY, :UZ, :VA, :VC, :VE, :VG, :VI, :VN, :VU, :WF,\n     :WS, :XK, :YE, :YT, :ZA, :ZM, :ZW]","ref":"Cldr.Config.html#known_territories/0-example"},{"type":"function","title":"Cldr.Config.language_data/0","doc":"Return the language data that maps\nvalid territories and scripts","ref":"Cldr.Config.html#language_data/0"},{"type":"function","title":"Cldr.Config.language_tag/1","doc":"Return the saved language tag for the\ngiven locale name.","ref":"Cldr.Config.html#language_tag/1"},{"type":"function","title":"Cldr.Config.language_tag_for_territory/0","doc":"Return the mapping from a territory to a language tag.\n\nThis is used to derive a locale from a territory.","ref":"Cldr.Config.html#language_tag_for_territory/0"},{"type":"function","title":"Cldr.Config.likely_subtags/0","doc":"Returns the likely subtags map which maps a\nlocale string to %LaguageTag{} representing\nthe likely subtags for that locale string","ref":"Cldr.Config.html#likely_subtags/0"},{"type":"function","title":"Cldr.Config.locale_filename/1","doc":"Returns the filename that contains the json representation\nof a locale.","ref":"Cldr.Config.html#locale_filename/1"},{"type":"function","title":"Cldr.Config.locale_name_from_posix/1","doc":"Transforms a locale name from the Posix format to the Cldr format","ref":"Cldr.Config.html#locale_name_from_posix/1"},{"type":"function","title":"Cldr.Config.locale_name_to_posix/1","doc":"Transforms a locale name from the CLDR format to the Posix format","ref":"Cldr.Config.html#locale_name_to_posix/1"},{"type":"function","title":"Cldr.Config.locale_path/2","doc":"Returns the location of the json data for a `locale`","ref":"Cldr.Config.html#locale_path/2"},{"type":"function","title":"Arguments - Cldr.Config.locale_path/2","doc":"* `locale` is any locale returned from `Cldr.known_locale_names/1`\n\n* `config` is any `t:Cldr.Config`","ref":"Cldr.Config.html#locale_path/2-arguments"},{"type":"function","title":"Returns - Cldr.Config.locale_path/2","doc":"* `{:ok, path}` or\n\n* `{:error, :not_found}`","ref":"Cldr.Config.html#locale_path/2-returns"},{"type":"function","title":"Cldr.Config.locale_path!/2","doc":"Returns the location of the json data for a `locale`","ref":"Cldr.Config.html#locale_path!/2"},{"type":"function","title":"Arguments - Cldr.Config.locale_path!/2","doc":"* `locale` is any locale returned from `Cldr.known_locale_names/1`\n\n* `config` is any `t:Cldr.Config`","ref":"Cldr.Config.html#locale_path!/2-arguments"},{"type":"function","title":"Returns - Cldr.Config.locale_path!/2","doc":"* `path` or\n\n* raises an exception","ref":"Cldr.Config.html#locale_path!/2-returns"},{"type":"function","title":"Cldr.Config.maybe_add_fallback_locales/1","doc":"Add the fallback locales to a list of\nconfigured locales","ref":"Cldr.Config.html#maybe_add_fallback_locales/1"},{"type":"function","title":"Cldr.Config.measurement_systems/0","doc":"Return a list of measurement systems","ref":"Cldr.Config.html#measurement_systems/0"},{"type":"function","title":"Cldr.Config.merge_locales_with_default/1","doc":"","ref":"Cldr.Config.html#merge_locales_with_default/1"},{"type":"function","title":"Cldr.Config.normalize_plural_rules/1","doc":"","ref":"Cldr.Config.html#normalize_plural_rules/1"},{"type":"function","title":"Cldr.Config.number_symbols_for/2","doc":"Get the number symbol definitions\nfor a locale","ref":"Cldr.Config.html#number_symbols_for/2"},{"type":"function","title":"Cldr.Config.number_symbols_for/3","doc":"","ref":"Cldr.Config.html#number_symbols_for/3"},{"type":"function","title":"Cldr.Config.number_symbols_for!/2","doc":"Get the number symbol definitions\nfor a locale or raises if an error","ref":"Cldr.Config.html#number_symbols_for!/2"},{"type":"function","title":"Cldr.Config.number_symbols_for!/3","doc":"","ref":"Cldr.Config.html#number_symbols_for!/3"},{"type":"type","title":"Cldr.Config.number_system/0","doc":"","ref":"Cldr.Config.html#t:number_system/0"},{"type":"function","title":"Cldr.Config.number_system_for/3","doc":"Returns the number system for a given\nlocale and number system name.","ref":"Cldr.Config.html#number_system_for/3"},{"type":"function","title":"Example - Cldr.Config.number_system_for/3","doc":"iex> Cldr.Config.number_system_for(:th, :thai, %Cldr.Config{locales: [\"th\", \"de\"]})\n    {:ok, %{digits: \"๐๑๒๓๔๕๖๗๘๙\", type: :numeric}}","ref":"Cldr.Config.html#number_system_for/3-example"},{"type":"function","title":"Cldr.Config.number_system_names_for/2","doc":"Returns the number system names for a locale","ref":"Cldr.Config.html#number_system_names_for/2"},{"type":"function","title":"Example - Cldr.Config.number_system_names_for/2","doc":"iex> Cldr.Config.number_system_names_for(:th, %Cldr.Config{locales: [\"en\", \"th\"]})\n    {:ok, [:latn, :thai]}","ref":"Cldr.Config.html#number_system_names_for/2-example"},{"type":"function","title":"Cldr.Config.number_system_types_for/2","doc":"Returns the number system types for a locale","ref":"Cldr.Config.html#number_system_types_for/2"},{"type":"function","title":"Cldr.Config.number_systems_for/2","doc":"Returns the number systems for a locale","ref":"Cldr.Config.html#number_systems_for/2"},{"type":"function","title":"Example - Cldr.Config.number_systems_for/2","doc":"iex> Cldr.Config.number_systems_for(:en, %Cldr.Config{locales: [\"en\", \"de\"]})\n    {:ok, %{default: :latn, native: :latn}}","ref":"Cldr.Config.html#number_systems_for/2-example"},{"type":"function","title":"Cldr.Config.number_systems_for!/2","doc":"Returns the number systems for a locale\nor raises if there is an error","ref":"Cldr.Config.html#number_systems_for!/2"},{"type":"function","title":"Example - Cldr.Config.number_systems_for!/2","doc":"iex> Cldr.Config.number_systems_for!(:de, %Cldr.Config{locales: [\"en\", \"de\"]})\n    %{default: :latn, native: :latn}","ref":"Cldr.Config.html#number_systems_for!/2-example"},{"type":"function","title":"Cldr.Config.parent_locales/0","doc":"Returns a map of locale names to\nits parent locale name.\n\nNote that these mappings only exist\nwhere the normal inheritance doesn't\napply.","ref":"Cldr.Config.html#parent_locales/0"},{"type":"function","title":"Cldr.Config.plural_ranges/0","doc":"Return a map of plural ranges","ref":"Cldr.Config.html#plural_ranges/0"},{"type":"function","title":"Cldr.Config.raise_if_otp_app_not_loaded!/1","doc":"","ref":"Cldr.Config.html#raise_if_otp_app_not_loaded!/1"},{"type":"function","title":"Cldr.Config.requested_locale_names/1","doc":"Returns a list of all configured locales.\n\nThe list contains locales configured both in `Gettext` and\nspecified in the mix.exs configuration file as well as the\ndefault locale.","ref":"Cldr.Config.html#requested_locale_names/1"},{"type":"function","title":"Cldr.Config.required_modules/0","doc":"Identifies the top level keys in the consolidated locale file.\n\nThese keys represent difference dimensions of content in the CLDR\nrepository and serve three purposes:\n\n1. To structure the content in the locale file\n\n2. To provide a rudimentary way to validate that some json represents a\nvalid locale file","ref":"Cldr.Config.html#required_modules/0"},{"type":"function","title":"Cldr.Config.root_locale_name/0","doc":"","ref":"Cldr.Config.html#root_locale_name/0"},{"type":"function","title":"Cldr.Config.source_data_dir/0","doc":"Return the directory where `Cldr` stores its source core data,\n\nThis directory should not be expected to be available\nother than when developing Cldr since it points to a source\ndirectory.\n\nThese are the json files that result from the normalization\nof the original CLDR data.","ref":"Cldr.Config.html#source_data_dir/0"},{"type":"function","title":"Cldr.Config.split_currency_metadata/1","doc":"","ref":"Cldr.Config.html#split_currency_metadata/1"},{"type":"function","title":"Cldr.Config.system_name_from/3","doc":"Returns a number system name for a given locale and number system reference.","ref":"Cldr.Config.html#system_name_from/3"},{"type":"function","title":"Arguments - Cldr.Config.system_name_from/3","doc":"* `system_name` is any number system name returned by\n  `Cldr.known_number_systems/0` or a number system type\n  returned by `Cldr.known_number_system_types/1`\n\n* `locale` is any valid locale name returned by `Cldr.known_locale_names/1`\n  or a `Cldr.LanguageTag` struct returned by `Cldr.Locale.new!/2`\n\n* `config` is a `Config.Cldr.t()` struct or a `Cldr.backend()` module\n\nNumber systems can be referenced in one of two ways:\n\n* As a number system type such as `:default`, `:native`, `:traditional` and\n  `:finance`. This allows references to a number system for a locale in a\n  consistent fashion for a given use\n\n* With the number system name directly, such as :latn, :arab or any name\n  returned by `Cldr.known_number_systems/0`\n\nThis function dereferences the supplied `system_name` and returns the\nactual system name.","ref":"Cldr.Config.html#system_name_from/3-arguments"},{"type":"function","title":"Examples - Cldr.Config.system_name_from/3","doc":"iex> Cldr.Config.system_name_from(:default, :en, TestBackend.Cldr)\n    {:ok, :latn}\n\n    iex> Cldr.Config.system_name_from(\"latn\", :en, TestBackend.Cldr)\n    {:ok, :latn}\n\n    iex> Cldr.Config.system_name_from(:native, :en, TestBackend.Cldr)\n    {:ok, :latn}\n\n    iex> Cldr.Config.system_name_from(:nope, :en, TestBackend.Cldr)\n    {\n      :error,\n      {Cldr.UnknownNumberSystemError, \"The number system :nope is unknown\"}\n    }","ref":"Cldr.Config.html#system_name_from/3-examples"},{"type":"type","title":"Cldr.Config.t/0","doc":"","ref":"Cldr.Config.html#t:t/0"},{"type":"function","title":"Cldr.Config.territories/0","doc":"Returns a map of territory info for all territories\nknown to CLDR.\n\nThe territory information is independent of the\n`ex_cldr` configuration.","ref":"Cldr.Config.html#territories/0"},{"type":"function","title":"Example - Cldr.Config.territories/0","doc":"iex> Cldr.Config.territories()[:GB]\n    %{\n      currency: [GBP: %{from: ~D[1694-07-27]}],\n      measurement_system: %{\n        default: :uksystem,\n        paper_size: :a4,\n        temperature: :uksystem\n      },\n      language_population: %{\n        \"ar\" => %{population_percent: 0.3},\n        \"bn\" => %{population_percent: 0.4},\n        \"cy\" => %{population_percent: 1.3, official_status: \"official_regional\"},\n        \"de\" => %{population_percent: 9},\n        \"en\" => %{population_percent: 98, official_status: \"official\"},\n        \"en-Shaw\" => %{population_percent: 0},\n        \"es\" => %{population_percent: 8},\n        \"fr\" => %{population_percent: 17},\n        \"ga\" => %{population_percent: 0.15, official_status: \"official_regional\"},\n        \"gd\" => %{\n          population_percent: 0.11,\n          official_status: \"official_regional\",\n          writing_percent: 5\n        },\n        \"gu\" => %{population_percent: 2.9},\n        \"it\" => %{population_percent: 0.2},\n        \"kw\" => %{population_percent: 0.0029},\n        \"lt\" => %{population_percent: 0.2},\n        \"pa\" => %{population_percent: 3.6},\n        \"pl\" => %{population_percent: 4},\n        \"pt\" => %{population_percent: 0.2},\n        \"ro\" => %{population_percent: 0.8},\n        \"sco\" => %{population_percent: 2.5, writing_percent: 5},\n        \"so\" => %{population_percent: 0.2},\n        \"ta\" => %{population_percent: 3.2},\n        \"tr\" => %{population_percent: 0.2},\n        \"ur\" => %{population_percent: 3.5},\n        \"zh-Hant\" => %{population_percent: 0.3}\n      },\n      gdp: 3700000000000,\n      literacy_percent: 99,\n      population: 68459100\n    }","ref":"Cldr.Config.html#territories/0-example"},{"type":"function","title":"Cldr.Config.territory/1","doc":"Get territory info for a specific territory.\n\n* `territory` is a string, atom or language_tag representation\n  of a territory code in the list returned by `Cldr.known_territories`\n\nReturns:\n\n* A map of the territory information or\n* `{:error, reason}`","ref":"Cldr.Config.html#territory/1"},{"type":"function","title":"Example - Cldr.Config.territory/1","doc":"iex> Cldr.Config.territory \"au\"\n    %{\n      currency: [AUD: %{from: ~D[1966-02-14]}],\n      measurement_system: %{default: :metric, paper_size: :a4, temperature: :metric},\n      language_population: %{\n        \"en\" => %{population_percent: 96, official_status: \"de_facto_official\"},\n        \"hnj\" => %{population_percent: 0.0082},\n        \"it\" => %{population_percent: 1.9},\n        \"wbp\" => %{population_percent: 0.0093},\n        \"zh-Hant\" => %{population_percent: 2.1}\n      },\n      gdp: 1584000000000,\n      literacy_percent: 99,\n      population: 26768600\n    }\n\n    iex> Cldr.Config.territory \"abc\"\n    {:error, {Cldr.UnknownTerritoryError, \"The territory \\\"abc\\\" is unknown\"}}","ref":"Cldr.Config.html#territory/1-example"},{"type":"function","title":"Cldr.Config.territory_containers/0","doc":"Returns a map of territory containers","ref":"Cldr.Config.html#territory_containers/0"},{"type":"function","title":"Cldr.Config.territory_containment/0","doc":"Returns a map of territory containment","ref":"Cldr.Config.html#territory_containment/0"},{"type":"function","title":"Cldr.Config.territory_currency_data/0","doc":"Returns the currency mapping data for\nterritories.","ref":"Cldr.Config.html#territory_currency_data/0"},{"type":"function","title":"Cldr.Config.territory_info/0","doc":"","ref":"Cldr.Config.html#territory_info/0"},{"type":"function","title":"Cldr.Config.territory_info/1","doc":"","ref":"Cldr.Config.html#territory_info/1"},{"type":"function","title":"Cldr.Config.territory_subdivision_containment/0","doc":"Return a mapping between a subdivision and its\ncontaining parents","ref":"Cldr.Config.html#territory_subdivision_containment/0"},{"type":"function","title":"Cldr.Config.territory_subdivisions/0","doc":"Return the territory subdivisions","ref":"Cldr.Config.html#territory_subdivisions/0"},{"type":"function","title":"Cldr.Config.unicode_script_to_subtag_mapping/0","doc":"Returns a mapping from Unicode script names to the\nrespective subtag used in BCP 47 language tags.","ref":"Cldr.Config.html#unicode_script_to_subtag_mapping/0"},{"type":"function","title":"Cldr.Config.units/0","doc":"Returns unit conversion data,","ref":"Cldr.Config.html#units/0"},{"type":"function","title":"Example - Cldr.Config.units/0","doc":"iex> Cldr.Config.units() |> get_in([:conversions, :quart])\n    %{\n      base_unit: :cubic_meter,\n      factor: \"0.000946352946\",\n      offset: 0,\n      systems: [:ussystem]\n    }","ref":"Cldr.Config.html#units/0-example"},{"type":"function","title":"Cldr.Config.unknown_locale_names/1","doc":"Returns a list of all locales that are configured but not available\nin the CLDR repository.","ref":"Cldr.Config.html#unknown_locale_names/1"},{"type":"function","title":"Cldr.Config.validity/1","doc":"Return a map of validity data for a given\ntype.\n\nThe types are `:languages`, `:scripts`,\n`:territories`, `:subdivisions`, `:variants`\n`:units`, `:u`, and `:t`","ref":"Cldr.Config.html#validity/1"},{"type":"function","title":"Cldr.Config.version/0","doc":"Returns the version string of the CLDR data repository","ref":"Cldr.Config.html#version/0"},{"type":"function","title":"Cldr.Config.week_info/0","doc":"","ref":"Cldr.Config.html#week_info/0"},{"type":"function","title":"Cldr.Config.weeks/0","doc":"Returns the data that defines start and end of\ncalendar weeks, weekends and years","ref":"Cldr.Config.html#weeks/0"},{"type":"module","title":"Cldr.Install","doc":"Provides functions for installing locales.\n\nWhen installed as a package on from [hex](http://hex.pm), `Cldr` has only\nthe default locales `[\"en\", \"und\"]` installed and configured.\n\nWhen other locales are added to the configuration `Cldr` will attempt to\ndownload the locale from [github](https://github.com/elixir-cldr/cldr)\nduring compilation.\n\nIf `Cldr` is installed from github directly then all locales are already\ninstalled.","ref":"Cldr.Install.html"},{"type":"function","title":"Cldr.Install.client_data_dir/1","doc":"","ref":"Cldr.Install.html#client_data_dir/1"},{"type":"function","title":"Cldr.Install.client_locale_file/2","doc":"Returns the full pathname of the locale's json file.\n\n* `locale` is any locale returned by `Cldr.known_locale_names/1`\n\nNo checking of locale validity is performed.","ref":"Cldr.Install.html#client_locale_file/2"},{"type":"function","title":"Cldr.Install.client_locales_dir/1","doc":"","ref":"Cldr.Install.html#client_locales_dir/1"},{"type":"function","title":"Cldr.Install.install_all_locale_names/1","doc":"Install all available locales.","ref":"Cldr.Install.html#install_all_locale_names/1"},{"type":"function","title":"Cldr.Install.install_known_locale_names/1","doc":"Install all the configured locales.","ref":"Cldr.Install.html#install_known_locale_names/1"},{"type":"function","title":"Cldr.Install.install_locale_name/3","doc":"Download the requested locale from github into the\nclient application's cldr data directory.\n\n* `locale` is any locale returned by `Cldr.known_locale_names/1`\n\n* `options` is a keyword list.  Currently the only supported\n  option is `:force` which defaults to `false`.  If `truthy` the\n  locale will be installed or re-installed.\n\nThe data directory is typically `priv/cldr/locales`.\n\nThis function is intended to be invoked during application\ncompilation when a valid locale is configured but is not yet\ninstalled in the application.\n\nAn https request to the master github repository for `Cldr` is made\nto download the correct version of the locale file which is then\nwritten to the configured data directory.","ref":"Cldr.Install.html#install_locale_name/3"},{"type":"function","title":"Cldr.Install.locale_filename/1","doc":"","ref":"Cldr.Install.html#locale_filename/1"},{"type":"function","title":"Cldr.Install.locale_installed?/2","doc":"Returns a `boolean` indicating if the requested locale is installed.\n\nNo checking of the validity of the `locale` itself is performed.  The\ncheck is based upon whether there is a locale file installed in the\nclient application or in `Cldr` itself.","ref":"Cldr.Install.html#locale_installed?/2"},{"type":"function","title":"Cldr.Install.locale_stale?/2","doc":"Returns a `boolean` indicating if the requested locale has available\ndata but the data is stale (is a older version not supported by this\nversion of `ex_cldr`.)","ref":"Cldr.Install.html#locale_stale?/2"},{"type":"module","title":"Cldr.Locale.Loader","doc":"Provides a public interface to read the\nraw JSON locale files and return the\nCLDR data in a consistent format.\n\nThe functions in this module are intended for the\nuse of authors writing additional CLDR-based\nlibraries.\n\nIn addition, the functions in this module are\nintended for use at compile-time - not runtime -\nsince reading, decoding and processing a\nlocale file is an expensive operation.","ref":"Cldr.Locale.Loader.html"},{"type":"function","title":"Cldr.Locale.Loader.get_locale/2","doc":"Read the locale json, decode it and make any necessary transformations.\n\nThis is the only place that we read the locale and we only\nread it once.  All other uses of locale data are references\nto this data.\n\nAdditionally the intention is that this is read only at compile time\nand used to construct accessor functions in other modules so that\nduring production run there is no file access or decoding.","ref":"Cldr.Locale.Loader.html#get_locale/2"},{"type":"function","title":"Cldr.Locale.Loader.known_locale_names/1","doc":"Returns a list of all locales that are configured and available\nin the CLDR repository.","ref":"Cldr.Locale.Loader.html#known_locale_names/1"},{"type":"function","title":"Examples - Cldr.Locale.Loader.known_locale_names/1","doc":"iex> Cldr.Locale.Loader.known_locale_names %Cldr.Config{locales: [\"en\", \"de\"]}\n    [:de, :en, :und]","ref":"Cldr.Locale.Loader.html#known_locale_names/1-examples"},{"type":"function","title":"Cldr.Locale.Loader.known_rbnf_locale_names/1","doc":"Returns a list of all locales that have RBNF data and that are\nconfigured and available in the CLDR repository.","ref":"Cldr.Locale.Loader.html#known_rbnf_locale_names/1"},{"type":"module","title":"Cldr.Substitution","doc":"Compiles substitution formats that are of the form\n\"{0} something {1}\" into a token list that allows for\nmore efficient parameter substitution at runtime.","ref":"Cldr.Substitution.html"},{"type":"function","title":"Cldr.Substitution.parse/1","doc":"Parses a substitution template into a list of tokens to\nallow efficient parameter substitution at runtime.\n\n* `template` is a binary that may include parameter markers that\nare substituted for values at runtime.\n\nReturns:\n\n* A list of tokens where any substitution is marked as an integer\nany any binary tokens are passed through as is.","ref":"Cldr.Substitution.html#parse/1"},{"type":"function","title":"Examples - Cldr.Substitution.parse/1","doc":"iex> Cldr.Substitution.parse \"{0}, {1}\"\n    [0, \", \", 1]\n\n    iex> Cldr.Substitution.parse \"{0} This is something {1} or another {2}\"\n    [0, \" This is something \", 1, \" or another \", 2]\n\nThis function is primarily intended to support compile-time generation\nof templates that simplify and speed up parameter substitution at runtime.","ref":"Cldr.Substitution.html#parse/1-examples"},{"type":"function","title":"Cldr.Substitution.substitute/2","doc":"Substitutes a list of values into a template token list that is\ncreated by `Cldr.Substitution.parse/1`.\n\n* `list1` is a list of values that will be substituted into a\na template list previously created by `Cldr.Substitution.parse/1`\n\n* `list2` is a template list previously created by\n`Cldr.Substitution.parse/1`\n\nReturns:\n\n* A list with values substituted for parameters in the `list1` template","ref":"Cldr.Substitution.html#substitute/2"},{"type":"function","title":"Examples: - Cldr.Substitution.substitute/2","doc":"iex> template = Cldr.Substitution.parse \"{0} This is something {1}\"\n    [0, \" This is something \", 1]\n    iex> Cldr.Substitution.substitute [\"a\", \"b\"], template\n    [\"a\", \" This is something \", \"b\"]","ref":"Cldr.Substitution.html#substitute/2-examples"},{"type":"module","title":"Cldr.Timezone","doc":"Functions to map between the CLDR short time zone code and the\nIANA timezone names.\n\nThe Unicode [locale](https://unicode.org/reports/tr35/#Locale)\n[extension U](https://unicode.org/reports/tr35/#u_Extension)\nallows the specification of the time zone requested for the provided locale.\n\nThis short timezone codes never change even if the IANA names change\nover time. Therefore these short codes are always stable between CLDR\nreleases.","ref":"Cldr.Timezone.html"},{"type":"function","title":"Cldr.Timezone.fetch/1","doc":"Returns a `:{:ok, list}` where list is a\nlist of IANA timezone names for\na given CLDR short zone code. If no such\nshort code exists then `:error` is returned.","ref":"Cldr.Timezone.html#fetch/1"},{"type":"function","title":"Example - Cldr.Timezone.fetch/1","doc":"iex> Cldr.Timezone.fetch(\"ausyd\")\n    {:ok,\n     [\"Australia/Sydney\", \"Australia/ACT\", \"Australia/Canberra\", \"Australia/NSW\"]}\n\n    iex> Cldr.Timezone.fetch(\"nope\")\n    :error","ref":"Cldr.Timezone.html#fetch/1-example"},{"type":"function","title":"Cldr.Timezone.get/2","doc":"Returns a list of IANA time zone names for\na given CLDR short zone code, or `nil`","ref":"Cldr.Timezone.html#get/2"},{"type":"function","title":"Examples - Cldr.Timezone.get/2","doc":"iex> Cldr.Timezone.fetch(\"ausyd\")\n    [\"Australia/Sydney\", \"Australia/ACT\", \"Australia/Canberra\", \"Australia/NSW\"]}\n\n    iex> Cldr.Timezone.fetch(\"nope\")\n    nil","ref":"Cldr.Timezone.html#get/2-examples"},{"type":"function","title":"Cldr.Timezone.timezones/0","doc":"Returns a mapping of CLDR short zone codes to\nIANA timezone names.","ref":"Cldr.Timezone.html#timezones/0"},{"type":"function","title":"Cldr.Timezone.timezones_for_territory/0","doc":"Returns a mapping of territories to\ntheir known IANA timezone names.","ref":"Cldr.Timezone.html#timezones_for_territory/0"},{"type":"exception","title":"Cldr.AcceptLanguageError","doc":"Exception raised when there no valid language tag\nin an `Accept-Language` header.","ref":"Cldr.AcceptLanguageError.html"},{"type":"exception","title":"Cldr.AmbiguousTimezoneError","doc":"Exception raised when the there are more\nthan one timezones for a locale","ref":"Cldr.AmbiguousTimezoneError.html"},{"type":"exception","title":"Cldr.FormatCompileError","doc":"Exception raised when there is an error in the compiling of a number format.","ref":"Cldr.FormatCompileError.html"},{"type":"exception","title":"Cldr.FormatError","doc":"Exception raised when there is an error in the formatting of a number/list/...","ref":"Cldr.FormatError.html"},{"type":"exception","title":"Cldr.InvalidDateFormatType","doc":"Exception raised when there is an invalid date format type.","ref":"Cldr.InvalidDateFormatType.html"},{"type":"exception","title":"Cldr.InvalidDateTimeFormatType","doc":"Exception raised when there is an invalid datetime format type.","ref":"Cldr.InvalidDateTimeFormatType.html"},{"type":"exception","title":"Cldr.InvalidLanguageError","doc":"Exception raised when a language\nis invalid","ref":"Cldr.InvalidLanguageError.html"},{"type":"exception","title":"Cldr.InvalidLanguageTag","doc":"Exception raised when there is an a parse error in a language tag","ref":"Cldr.InvalidLanguageTag.html"},{"type":"exception","title":"Cldr.InvalidScriptError","doc":"Exception raised when a script\nis invalid","ref":"Cldr.InvalidScriptError.html"},{"type":"exception","title":"Cldr.InvalidTerritoryError","doc":"Exception raised when a territory\nis invalid","ref":"Cldr.InvalidTerritoryError.html"},{"type":"exception","title":"Cldr.InvalidTimeFormatType","doc":"Exception raised when there is an invalid time format type.","ref":"Cldr.InvalidTimeFormatType.html"},{"type":"exception","title":"Cldr.InvalidVariantError","doc":"Exception raised when a language\nvariant is invalid","ref":"Cldr.InvalidVariantError.html"},{"type":"exception","title":"Cldr.NoDefaultBackendError","doc":"Exception raised when there is no\ndefault backend configured","ref":"Cldr.NoDefaultBackendError.html"},{"type":"exception","title":"Cldr.NoMatchingLocale","doc":"Exception raised when no configured locale matches the provided \"Accept-Language\" header","ref":"Cldr.NoMatchingLocale.html"},{"type":"exception","title":"Cldr.NoParentError","doc":"Exception raised when the there are more\nno parent locale","ref":"Cldr.NoParentError.html"},{"type":"exception","title":"Cldr.Rbnf.NotAvailable","doc":"Exception raised when there is no RBNF for a locale.","ref":"Cldr.Rbnf.NotAvailable.html"},{"type":"exception","title":"Cldr.UnknownBackendError","doc":"Exception raised when the backend\nmodule is unknown or not a backend module","ref":"Cldr.UnknownBackendError.html"},{"type":"exception","title":"Cldr.UnknownCalendarError","doc":"Exception raised when an attempt is made to use a calendar that is not known.\nin `Cldr`.","ref":"Cldr.UnknownCalendarError.html"},{"type":"exception","title":"Cldr.UnknownCurrencyError","doc":"Exception raised when there is an invalid currency code.","ref":"Cldr.UnknownCurrencyError.html"},{"type":"exception","title":"Cldr.UnknownFormatError","doc":"Exception raised when an attempt is made to use a locale that is not configured\nin `Cldr`.  `Cldr.known_locale_names/1` returns the locale names known to `Cldr`.","ref":"Cldr.UnknownFormatError.html"},{"type":"exception","title":"Cldr.UnknownLocaleError","doc":"Exception raised when an attempt is made to use a locale not configured\nin `Cldr`.  `Cldr.known_locale_names/1` returns the locale names known to `Cldr`.","ref":"Cldr.UnknownLocaleError.html"},{"type":"exception","title":"Cldr.UnknownMeasurementSystemError","doc":"Exception raised when the measurement\nsystem is invalid.","ref":"Cldr.UnknownMeasurementSystemError.html"},{"type":"exception","title":"Cldr.UnknownNumberSystemError","doc":"Exception raised when an attempt is made to use a number system that is not known\nin `Cldr`.  `Cldr.Number.number_system_names/0` returns the number system names known to `Cldr`.","ref":"Cldr.UnknownNumberSystemError.html"},{"type":"exception","title":"Cldr.UnknownNumberSystemTypeError","doc":"Exception raised when an attempt is made to use a number system type that is not known\nin `Cldr`.  `Cldr.Number.number_system_types/0` returns the number system types known to `Cldr`.","ref":"Cldr.UnknownNumberSystemTypeError.html"},{"type":"exception","title":"Cldr.UnknownOTPAppError","doc":"Exception raised when the configured OTP app\nis not known","ref":"Cldr.UnknownOTPAppError.html"},{"type":"exception","title":"Cldr.UnknownPluralRules","doc":"Exception raised when there are no plural rules for a locale or language.","ref":"Cldr.UnknownPluralRules.html"},{"type":"exception","title":"Cldr.UnknownTerritoryError","doc":"Exception raised when there is an invalid territory code.","ref":"Cldr.UnknownTerritoryError.html"},{"type":"exception","title":"Cldr.UnknownUnitError","doc":"Exception raised when an attempt is made to use a unit that is not known.\nin `Cldr`.","ref":"Cldr.UnknownUnitError.html"},{"type":"extras","title":"Getting Started with Cldr","doc":"# Getting Started with Cldr\n\n![Build status](https://github.com/elixir-cldr/cldr/actions/workflows/ci.yml/badge.svg)\n[![Hex.pm](https://img.shields.io/hexpm/v/ex_cldr.svg)](https://hex.pm/packages/ex_cldr)\n[![Hex.pm](https://img.shields.io/hexpm/dw/ex_cldr.svg?)](https://hex.pm/packages/ex_cldr)\n[![Hex.pm](https://img.shields.io/hexpm/dt/ex_cldr.svg?)](https://hex.pm/packages/ex_cldr)\n[![Hex.pm](https://img.shields.io/hexpm/l/ex_cldr.svg)](https://hex.pm/packages/ex_cldr)\n\n> #### Change to :json_library configuration {: .warning}\n> As of `ex_cldr` version 2.37.2 the configuration parameter `:json_library`\n> does not attempt to read the configuration of either Phoenix or Ecto.\n\n> #### Automatic configuration of :json_library  {: .info}\n> OTP 27 and Elixir 1.18 both include native JSON libraries. Therefore if running on either (or both) of these platforms, no `:json_library` configuration is required or recommended.","ref":"readme.html"},{"type":"extras","title":"Introduction - Getting Started with Cldr","doc":"`ex_cldr` is an Elixir library for the [Unicode Consortium's](http://unicode.org) [Common Locale Data Repository (CLDR)](http://cldr.unicode.org).  The intentions of CLDR, and this library, is to simplify the locale specific formatting and parsing of numbers, lists, currencies, calendars, units of measure and dates/times.  As of August 16th 2024 and `ex_cldr` Version 2.40.1, `ex_cldr` is based upon [CLDR version 45.0](http://cldr.unicode.org/index/downloads/cldr-45).\n\nThe first step is to define a module that will host the desired `ex_cldr` configuration and the functions that serve as the public API.  This module is referred to in this documentation as a `backend` module. For example:\n\n```elixir\ndefmodule MyApp.Cldr do\n  @moduledoc \"\"\"\n  Define a backend module that will host our\n  Cldr configuration and public API.\n\n  Most function calls in Cldr will be calls\n  to functions on this module.\n  \"\"\"\n  use Cldr,\n    locales: [\"en\", \"fr\", \"zh\", \"th\"],\n    default_locale: \"en\"\n\nend\n```\n\nThis strategy means that different configurations can be defined and it also\nmeans that one `ex_cldr` implementation won't interfere with implementations in another,\npotentially dependent, applications.\n\nThe functions you are mostly likely to use are:\n\n* `MyApp.Cldr.default_locale/0`\n* `MyApp.Cldr.put_locale/1`\n* `MyApp.Cldr.get_locale/0`\n* `MyApp.Cldr.known_locale_names/0`\n* `MyApp.Cldr.Locale.new/1`\n* `MyApp.Cldr.validate_locale/1`","ref":"readme.html#introduction"},{"type":"extras","title":"Use Case - Getting Started with Cldr","doc":"Use this library if you need to:\n\n* Support multiple languages and locales in your application\n\n* Support formatting numbers, dates, times, date-times, units and lists in one language or many\n\n* Need to access the data maintained in the CLDR repository in a functional manner\n\n* Parse an [Accept-Language](https://www.w3.org/Protocols/rfc2616/rfc2616-sec14.html#sec14.4) HTTP header or a [language tag](https://tools.ietf.org/html/bcp47)\n\n**It is highly likely that you will also want to install one or more of the dependent packages that provide localization and formatting for a particular data domain.  See [Additional Cldr Packages](#additional-cldr-packages) below**.","ref":"readme.html#use-case"},{"type":"extras","title":"Elixir Version Requirements - Getting Started with Cldr","doc":"* [ex_cldr](https://hex.pm/packages/ex_cldr) requires Elixir 1.12 or later.","ref":"readme.html#elixir-version-requirements"},{"type":"extras","title":"Installation - Getting Started with Cldr","doc":"Add `ex_cldr` and the JSON library of your choice as a dependency to your `mix` project. If running on OTP 27 or later, this step is not required since `ex_cldr` will detect and use the built-in `:json` module.\n\n```elixir\ndefp deps do\n  [\n    {:ex_cldr, \"~> 2.37\"},\n    # Poison or any other compatible json library\n    # that implements `encode!/1` and `decode!/1`\n    # :jason is recommended\n    {:jason, \"~> 1.0\"}\n    # {:poison, \"~> 2.1 or ~> 3.0\"}\n  ]\nend\n```\n\nthen retrieve `ex_cldr` and the JSON library from [hex](https://hex.pm/packages/ex_cldr):\n```elixir\nmix deps.get\nmix deps.compile\n```","ref":"readme.html#installation"},{"type":"extras","title":"Additional Cldr Packages - Getting Started with Cldr","doc":"`ex_cldr` includes only basic functions to maintain the CLDR data repository in an accessible manner and to manage locale definitions.  Additional functionality is available by adding additional packages:\n\n* Plugs for setting the locale from an HTTP request: [ex_cldr_plugs](https://hex.pm/packages/ex_cldr_plugs)\n* Number formatting: [ex_cldr_numbers](https://hex.pm/packages/ex_cldr_numbers)\n* List formatting: [ex_cldr_lists](https://hex.pm/packages/ex_cldr_lists)\n* Unit or measure formatting: [ex_cldr_units](https://hex.pm/packages/ex_cldr_units)\n* Date/Time/DateTime formatting: [ex_cldr_dates_times](https://hex.pm/packages/ex_cldr_dates_times)\n* Route localization for Phoenix: [ex_cldr_routes](https://hex.pm/packages/ex_cldr_routes)\n* Locale name localisation: [ex_cldr_locale_display](https://hex.pm/packages/ex_cldr_locale_display)\n* HTML select helpers: [ex_cldr_html](https://hex.pm/packages/cldr_html)\n* Calendars: [ex_cldr_calendars](https://hex.pm/packages/ex_cldr_calendars)\n* Calendar formatting: [ex_cldr_calendars_format](https://hex.pm/packages/ex_cldr_calendars_format)\n* Printf-like formatting: [ex_cldr_print](https://hex.pm/packages/ex_cldr_print)\n* Collation: [ex_cldr_collation](https://hex.pm/packages/ex_cldr_collation)\n* ICU Message formatting: [ex_cldr_messages](https://hex.pm/packages/ex_cldr_messages)\n* Person name formatting: [ex_cldr_person_names](https://hex.pm/packages/ex_cldr_person_names)\n* Territories localization and information: [ex_cldr_territories](https://hex.pm/packages/ex_cldr_territories) by @Schultzer\n* Languages localization: [ex_cldr_languages](https://hex.pm/packages/ex_cldr_languages) by @lostkobrakai\n\nEach of these packages includes `ex_cldr` as a dependency so configuring any of these additional packages will automatically install `ex_cldr`.","ref":"readme.html#additional-cldr-packages"},{"type":"extras","title":"Configuration - Getting Started with Cldr","doc":"`ex_cldr` attempts to maximise runtime performance at the expense of additional compile time.  Where possible `ex_cldr` will create functions to encapsulate data at compile time.  To perform these optimizations for all 541 locales known to Cldr wouldn't be an effective use of your time or your computer's.  Therefore `ex_cldr` requires that you configure the locales you want to use.\n\n`ex_cldr` is configured in your backend module. This removes any dependency on your `mix.exs` and therefore simplifies deployment as a release.","ref":"readme.html#configuration"},{"type":"extras","title":"Backend Module Configuration - Getting Started with Cldr","doc":"> #### `use Cldr` {: .info}\n>\n> When you `use Cldr`, a number of functions are generated\n> that encapsulate CLDR data. A module that invokes `use Cldr`\n> is referred to as a Cldr backend module.\n>\n> The functions in a Cldr backend module form the primary\n> recommended API for `ex_cldr`.\n>\n> In addition, a number of additional modules\n> may be generated with names that are prefixed by the name of\n> the module in which `use Cldr` is invoked. The number and names\n> of these additional modules is determined by the modules\n> configured under the `:providers` option to `use Cldr`.\n>\n> It is not recommended that a module that invokes `use Cldr`\n> define any other functions.\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    default_locale: \"en\",\n    locales: [\"fr\", \"en\", \"bs\", \"si\", \"ak\", \"th\"],\n    add_fallback_locales: false,\n    gettext: MyApp.Gettext,\n    data_dir: \"./priv/cldr\",\n    otp_app: :my_app,\n    precompile_number_formats: [\"¤¤#,##0.##\"],\n    precompile_transliterations: [{:latn, :arab}, {:thai, :latn}],\n    providers: [Cldr.Number],\n    generate_docs: true,\n    force_locale_download: false\nend\n```","ref":"readme.html#backend-module-configuration"},{"type":"extras","title":"Otp App Configuration - Getting Started with Cldr","doc":"In the backend configuration example above the `:otp_app` key has been defined.  This means that `ex_cldr` will look for additional configuration, defined under the key `:my_app` with the sub-key `MyApp.Cldr`.  For example:\n\n```elixir\n# cldr.ex\ndefmodule MyApp.Cldr do\n  use Cldr,\n    otp_app: :my_app,\n    default_locale: \"en\",\n    gettext: MyApp.Gettext,\n    json_library: Jason,\n    data_dir: \"./priv/cldr\",\n    precompile_number_formats: [\"¤¤#,##0.##\"],\n    providers: [Cldr.Number]\nend\n```\n\n```elixir\n# config/config.exs\nconfig :my_app, MyApp.Cldr,\n  # a single locale, for fast compilation in dev / test\n  locales: [\"en\"]\n```\n\n```elixir\n# config/production.exs\nconfig :my_app, MyApp.Cldr,\n  # these will take a while to compile\n  locales: [\"fr\", \"en\", \"bs\", \"si\", \"ak\", \"th\"],\n  precompile_transliterations: [{:latn, :arab}, {:thai, :latn}]\n```\n\nMultiple backends can be configured under a single `:otp_app` if required.","ref":"readme.html#otp-app-configuration"},{"type":"extras","title":"Global configuration. - Getting Started with Cldr","doc":"In `config.exs` a global configuration can be defined under the `:ex_cldr` key.  Although any valid configuration keys can be used here, only the keys `:json_library`, `:default_locale`, `:default_backend`, `:cacertfile`, `:data_dir`, `:force_locale_download` are considered valid.  Other configuration keys may be used to aid migration from `ex_cldr` version 1.x but a deprecation message will be printed during compilation.  Here's an example of global configuration:\n\n```elixir\nconfig :ex_cldr,\n  default_locale: \"en\",\n  default_backend: MyApp.Cldr,\n  json_library: Jason,\n  cacertfile: \"path/to/cacertfile\"\n```\n\nNote that the `:json_library` key can only be defined at the global level since it is required during compilation before any backend module is compiled.\n\n> #### Automatic configuration of :json_library  {: .info}\n> OTP 27 and Elixir 1.18 both include native JSON libraries. Therefore if running on either (or both) of these platforms, no `:json_library` configuration is required or recommended.\n\nOn most platforms other than Windows the `:cacertfile` will be automatically detected. Any configured `:cacertfile` will take precedence on all platforms.\n\n**If configuration beyond the keys `:default_locale`, `:cacertfile` or `:json_library` are defined a deprecation warning is printed at compile time noting that configuration should be moved to a backend module.**","ref":"readme.html#global-configuration"},{"type":"extras","title":"Configuration Priority - Getting Started with Cldr","doc":"When building the consolidated configuration the following priority applies:\n\n* Consider the global configuration\n* Merge the otp_app configuration over the top of the global configuration\n* Merge the backend module configuration over the top","ref":"readme.html#configuration-priority"},{"type":"extras","title":"Backend Configuration Keys - Getting Started with Cldr","doc":"The configuration keys available for `ex_cldr` are:\n\n * `default_locale` specifies the default locale to be used for this backend.  The default locale in case no other locale has been set is `\"en-001\"`.  The default locale is calculated as follows:\n\n     * If set by the `:default_locale` key, then this is the priority\n     * If no `:default_locale` key, then a configured `Gettext` default locale for this backend is chosen.\n     * If no `:default_locale` key is specified and no `Gettext` module is configured, or is configured but has no default set, use `Cldr.default_locale/0` which returns either the default locale configurated in `mix.exs` under the `ex_cldr` key or then the system default locale will is currently `en-001`.\n\n * `locales`: Defines what locales will be configured in `ex_cldr`.  Only these locales will be available and an exception `Cldr.UnknownLocaleError` will be raised if there is an attempt to use an unknown locale.  This is the same behaviour as `Gettext`.  Locales are configured as a list of binaries (strings).  For convenience it is possible to use wildcard matching of locales which is particularly helpful when there are many regional variances of a single language locale.  For example, there are over 100 regional variants of the \"en\" locale in CLDR.  A wildcard locale is detected by the presence of `.`, `[`, `*` and `+` in the locale string.  This locale is then matched using the pattern as a `regex` to match against all available locales.  The example below will configure all locales that start with `en-` and the locale `fr`.\n\n```elixir\nuse Cldr,\n  default_locale: \"en\",\n  locales: [\"en-*\", \"fr\"]\n```\n\n * There is one additional setting which is `:all` which will configure all 541 locales.  **This is highly discouraged** since it will take many minutes to compile your project and will consume more memory than you really want.  This setting is there to aid in running the test suite.  Really, don't use this setting.\n\n * `:add_fallback_locales` is a boolean key which when `true` results in the fallback locales being added for each of the configured locales.  The default is `false`. The reason to set this option to `true` is that some data such as rules based number formats and subdivision data are inherited from their language roots. For example, the locale `en-001` is inherited from the locale `en`. Locale `en-001` does not have any rules-based number formats or subdivision data defined for it. However locale `en` does. Including the fallback locales maximises the opportunity to resolve localised data.\n\n * `:gettext`: specifies the name of a Gettext module that informs `ex_cldr` to use that module as an additional source of locales you want to configure.  Since `Gettext` uses the POSIX locale name format (locales with an '\\_' in them) and `ex_cldr` uses the Unicode format (a '-' as the subtag separator), `ex_cldr` will transliterate locale names from `Gettext` into the `ex_cldr` canonical form. For example:\n\n ```elixir\n use Cldr,\n   default_locale: \"en\",\n   gettext: MyApp.Gettext,\n   locales: [\"en-*\", \"fr\"]\n ```\n\n * `:data_dir`: indicates where downloaded locale files will be stored.  The default is `:code.priv_dir(otp_app)` where `otp_app` is the app defined under the `:otp_app` configuration key.  If that key is not specified then the `:ex_cldr` app is used. It is recommended that an `:otp_app` key is specified in your backend module configuration.\n\n * `:precompile_number_formats`: provides a means to have user-defined format strings precompiled at application compile time.  This has a performance benefit since precompiled formats execute approximately twice as fast as formats that are not precompiled.\n\n * `:precompile_transliterations`: defines those transliterations between the digits of two different number systems that will be precompiled.  The is a list of 2-tuples where each tuple is of the form `{from_number_system, to_number_system}` where each number system is expressed as an atom.  The available  number systems are returned by `Cldr.Number.System.systems_with_digits/0`.  The default is the empty list `[]`.\n\n * `:precompile_date_time_formats`: provides a means to have user-defined date, time and date time format strings precompiled at application compile time.  This has a performance benefit since precompiled formats execute approximately twice as fast as formats that are not precompiled. These formats are used by [ex_cldr_date_times](https://hex.pm/packages/ex_cldr_dates_times).\n\n * `:precompile_interval_formats`: provides a means to have user-defined interval format strings precompiled at application compile time.  This has a performance benefit since precompiled formats execute approximately twice as fast as formats that are not precompiled. These formats are used by [ex_cldr_date_times](https://hex.pm/packages/ex_cldr_dates_times).\n\n * `:default_currency_format` determines whether `Cldr.Number.to_string/2` will use `:currency` or `:accounting` if no format is specified but a currency is. The default is `nil` which means that the format will be derived from the locale.\n\n * `:providers`: a list of modules that provide `ex_cldr` functionality to be compiled into the backend module. See the [providers](#providers) section below.\n\n * `:generate_docs` defines whether or not to generate documentation for the modules built as part of the backend.  Since these modules represent the public API for `ex_cldr`, the default is `true`.  Setting this key to `false` (the atom `false`, not a *falsy* value) will prevent the generation of docs for this backend.\n\n * `:suppress_warnings` defines whether warnings are logged when a provider module is configured but not available. It also controls whether warnings are logged when a number format is compiled at runtime. Its purpose is to help identify those formats that might best be added to the `:precompile_number_formats` configuration. The default is `false`. Warnings are not logged when set to `true`.\n\n * `:force_locale_download` determines whether to always download locale files during compilation. Locale data is `ex_cldr` version dependent. When a new version of `ex_cldr` is installed, no locales are installed and therefore locales are downloaded at compilation time as required. This ensures that the right version of the locale data is always associated with the right version of `ex_cldr`. However, if locale data is being cached in CI/CD there is some possibility that there can be a version mismatch.  Since reproducible builds are important, setting the `force_locale_download: true` in a backend or in global configuration adds additional certainty. The default setting is `false` thereby retaining compatibility with existing behaviour. The configuration can also be made dependent on `mix` environment as shown in this example:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"fr\"],\n    default_locale: \"en\",\n    force_locale_download: Mix.env() == :prod\nend\n```\n\n * `:https_proxy` is the URL of a proxy host that will be used when downloading locales to be installed. When downloading, this configuration key has priority, followed by the environment variables `HTTPS_PROXY` and `https_proxy`.  The default is `nil`.","ref":"readme.html#backend-configuration-keys"},{"type":"extras","title":"Providers - Getting Started with Cldr","doc":"The data maintained by [CLDR](https://cldr.unicode.org) is quite large and not all capabilities are required by all applications.  Hence `ex_cldr` has additional optional functionality that can be provided through additional `hex` packages. In order to support compile-time additions to a configured `backend`, any package can define a provider that will be called at compile time.\n\nThe currently known providers and their `hex` package names are:\n\n  | Hex Package            | Provider Module    | Comment                                        |\n  | :--------------------- | :----------------- | :--------------------------------------------- |\n  | ex_cldr_numbers        | Cldr.Number        | Formatting of numbers, currencies              |\n  | ex_cldr_lists          | Cldr.List          | Formatting of lists                            |\n  | ex_cldr_units          | Cldr.Unit          | Formatting of SI and Imperial units            |\n  | ex_cldr_person_names   | Cldr.PersonName    | Formatting person names                        |\n  | ex_cldr_currencies     | Cldr.Currency      | Currency definitions and localizations         |\n  | ex_cldr_territories    | Cldr.Territory     | Formatting of territory (country) data         |\n  | ex_cldr_languages      | Cldr.Language      | Formatting of language information             |\n  | ex_cldr_dates_times    | Cldr.DateTime      | Formatting of dates, times & datetimes         |\n  | ex_cldr_locale_display | Cldr.LocaleDisplay | Localising locale names                        |\n  | ex_cldr_routes         | Cldr.Route         | Localized routes and route helpers             |\n  | ex_cldr_messages       | Cldr.Message       | Formatting of ICU-formatted messages           |\n  | ex_money               | Money              | Operations on and formatting of a money type   |\n\nAny library author can create a provider module by exposing a function called `cldr_backend_provider/1` that takes a `Cldr.Config` struct as a single parameter.  The function should return an AST that is inserted into the `backend` module being compiled.\n\nProviders are configured on each backend module under the `:providers` key. It must be a list of provider modules.  For example:\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"zh\"],\n    default_locale: \"en\",\n    providers: [Cldr.Number, Cldr.List]\nend\n```\n**If :providers is `nil` (the default), `ex_cldr` will attempt to configure all of the providers described above if they have been installed as `deps`.  If you don't wish to invoke any providers, use the empty list `[]`.**","ref":"readme.html#providers"},{"type":"extras","title":"Migrating from Cldr 1.x - Getting Started with Cldr","doc":"1. Create a `backend` module by following the [configuration](#configuration) instructions\n2. Delete any duplicated [global configuration](#global-configuration) in any `config.exs` files. Only the keys `:default_locale` and `:json_library` are supported in the global configuration\n3. Update any [plugs](#plugs) to configure the desired backend\n4. Adjust any API calls from `Cldr.some_function` to `MyApp.Cldr.some_function`.  Or better still, alias your backend module where required.  ie. `alias MyApp.Cldr, as: Cldr`","ref":"readme.html#migrating-from-cldr-1-x"},{"type":"extras","title":"Downloading Locales - Getting Started with Cldr","doc":"`ex_cldr` can be installed from either [github](https://github.com/elixir-cldr/cldr)\nor from [hex](https://hex.pm/packages/ex_cldr).\n\n* If installed from GitHub then all 571 locales are installed when the repo is cloned into your application deps.\n\n* If installed from hex then only the locales \"en\", \"en-001\" and \"und\" are installed.  When you configure additional locales these will be downloaded during application compilation.","ref":"readme.html#downloading-locales"},{"type":"extras","title":"Localizing Numbers - Getting Started with Cldr","doc":"The `Cldr.Number` module implemented in the [ex_cldr_numbers](https://hex.pm/packages/ex_cldr_numbers) package provides number formatting.  The public API for number formatting is `MyApp.Cldr.Number.to_string/2`.  Some examples:\n```elixir\niex> MyApp.Cldr.Number.to_string 12345\n\"12,345\"\n\niex> MyApp.Cldr.Number.to_string 12345, locale: \"fr\"\n\"12 345\"\n\niex> MyApp.Cldr.Number.to_string 12345, locale: \"fr\", currency: \"USD\"\n\"12 345,00 $US\"\n\niex> MyApp.Cldr.Number.to_string 12345, format: \"#E0\"\n\"1.2345E4\"\n\niex(> MyApp.Cldr.Number.to_string 1234, format: :roman\n\"MCCXXXIV\"\n\niex> MyApp.Cldr.Number.to_string 1234, format: :ordinal\n\"1,234th\"\n\niex> MyApp.Cldr.Number.to_string 1234, format: :spellout\n\"one thousand two hundred thirty-four\"\n```\nSee `h MyApp.Cldr.Number` and `h MyApp.Cldr.Number.to_string` in `iex` for further information.","ref":"readme.html#localizing-numbers"},{"type":"extras","title":"Localizing Lists - Getting Started with Cldr","doc":"The `Cldr.List` module provides list formatting and is implemented in the [ex_cldr_lists](https://hex.pm/packages/ex_cldr_lists) package.  The public API for list formatting is `Cldr.List.to_string/2`.  Some examples:\n```elixir\niex> MyApp.Cldr.List.to_string([\"a\", \"b\", \"c\"], locale: \"en\")\n\"a, b, and c\"\n\niex> MyApp.Cldr.List.to_string([\"a\", \"b\", \"c\"], locale: \"en\", format: :unit_narrow)\n\"a b c\"\n\niex> MyApp.Cldr.List.to_string([\"a\", \"b\", \"c\"], locale: \"fr\")\n\"a, b et c\"\n```\nSee `h MyApp.Cldr.List` and `h MyApp.Cldr.List.to_string` in `iex` for further information.","ref":"readme.html#localizing-lists"},{"type":"extras","title":"Localizing Units - Getting Started with Cldr","doc":"The `Cldr.Unit` module provides unit localization and is implemented in the [ex_cldr_units](https://hex.pm/packages/ex_cldr_units) package.  The public API for unit localization is `Cldr.Unit.to_string/3`. Some examples:\n```elixir\niex> MyApp.Cldr.Unit.to_string 123, :gallon\n\"123 gallons\"\n\niex> MyApp.Cldr.Unit.to_string 1234, :gallon, format: :long\n\"1 thousand gallons\"\n\niex> MyApp.Cldr.Unit.to_string 1234, :gallon, format: :short\n\"1K gallons\"\n\niex> MyApp.Cldr.Unit.to_string 1234, :megahertz\n\"1,234 megahertz\"\n\niex> MyApp.Cldr.Unit.available_units\n[:acre, :acre_foot, :ampere, :arc_minute, :arc_second, :astronomical_unit, :bit,\n :bushel, :byte, :calorie, :carat, :celsius, :centiliter, :centimeter, :century,\n :cubic_centimeter, :cubic_foot, :cubic_inch, :cubic_kilometer, :cubic_meter,\n :cubic_mile, :cubic_yard, :cup, :cup_metric, :day, :deciliter, :decimeter,\n :degree, :fahrenheit, :fathom, :fluid_ounce, :foodcalorie, :foot, :furlong,\n :g_force, :gallon, :gallon_imperial, :generic, :gigabit, :gigabyte, :gigahertz,\n :gigawatt, :gram, :hectare, :hectoliter, :hectopascal, :hertz, :horsepower,\n :hour, :inch, ...]\n```\nSee `h MyApp.Cldr.Unit` and `h MyApp.Cldr.Unit.to_string` in `iex` for further information.","ref":"readme.html#localizing-units"},{"type":"extras","title":"Localizing Dates - Getting Started with Cldr","doc":"Formatting of relative dates and date times is supported in the `Cldr.DateTime.Relative` module implemented in the [ex_cldr_dates_times](https://hex.pm/packages/ex_cldr_dates_times) package.  The public API is `MyApp.Cldr.DateTime.to_string/2` and `MyApp.Cldr.DateTime.Relative.to_string/2`.  Some examples:\n```elixir\niex> MyApp.Cldr.Date.to_string Date.utc_today()\n{:ok, \"Aug 18, 2017\"}\n\niex> MyApp.Cldr.Time.to_string Time.utc_now\n{:ok, \"11:38:55 AM\"}\n\niex> MyApp.Cldr.DateTime.to_string DateTime.utc_now\n{:ok, \"Aug 18, 2017, 11:39:08 AM\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string 1, unit: :day, format: :narrow\n{:ok, \"tomorrow\"}\n\niex> MyApp.Cldr.DateTime.Relative.to_string(1, unit: :day, locale: \"fr\")\n\"demain\"\n\niex> MyApp.Cldr.DateTime.Relative.to_string(1, unit: :day, format: :narrow)\n\"tomorrow\"\n\niex> MyApp.Cldr.DateTime.Relative.to_string(1234, unit: :year)\n\"in 1,234 years\"\n\niex> MyApp.Cldr.DateTime.Relative.to_string(1234, unit: :year, locale: \"fr\")\n\"dans 1 234 ans\"\n```","ref":"readme.html#localizing-dates"},{"type":"extras","title":"Gettext Pluralization - Getting Started with Cldr","doc":"[gettext](https://hexdocs.pm/gettext) allows for user-defined [plural forms](https://hexdocs.pm/gettext/Gettext.Plural.html#content) modules to be configured for a [gettext backend](https://hexdocs.pm/gettext/Gettext.Backend.html#content).\n\nTo define a plural forms module that uses [CLDR plural rules](https://cldr.unicode.org/index/cldr-spec/plural-rules)\ncreate a new module and then `use Cldr.Gettext.Plural`. For example:\n\n    defmodule MyApp.Gettext.Plural do\n      use Cldr.Gettext.Plural, cldr_backend: MyApp.Cldr\n    end\n\nThis module can then be used in the configuration of a `gettext` backend.\nFor example:\n\n    defmodule MyApp.Gettext do\n      use Gettext, plural_forms: MyApp.Gettext.Plural\n    end\n\nNote that `MyApp.Gettext.Plural` does not guarantee to return the same `plural index` as `Gettext`'s own pluralization engine which can introduce some compatibility issues if you plan to mix plural engines.  See `Cldr.Gettext.Plural` for more information.","ref":"readme.html#gettext-pluralization"},{"type":"extras","title":"About Language Tags - Getting Started with Cldr","doc":"Note that `ex_cldr` defines locale strings according to the [IETF standard](https://en.wikipedia.org/wiki/IETF_language_tag) as defined in [RFC5646](https://tools.ietf.org/html/rfc5646).  `ex_cldr` also implements the `u` extension as defined in [RFC6067](https://tools.ietf.org/html/rfc6067) and the `t` extension defined in [RFC6497](https://tools.ietf.org/html/rfc6497). This is also the standard used by [W3C](https://www.w3.org/TR/ltli/).\n\nThe IETF standard is slightly different from the [ISO/IEC 15897](http://www.open-std.org/jtc1/sc22/wg20/docs/n610.pdf) standard used by Posix-based systems; primarily in that ISO 15897 uses a \"_\" separator whereas IETF and W3C use \"-\".\n\nLocale strings are case insensitive but there are common conventions:\n\n* Language codes are lower-cased\n* Territory codes are upper-cased\n* Script names are capital-cased\n* All other subtags are lower-cased\n\n### `Sigil_l`\n\nAs of `ex_cldr` version 2.23.0, a sigil is available to simplify creating `t:Cldr.LanguageTag` structs. Usage is:\n```elixir\niex> import Cldr.LanguageTag.Sigil\nCldr.LanguageTag.Sigil\n\n# Returns a locale that is valid and known to\n# the default backend module\niex> ~l(en-US)\n#Cldr.LanguageTag \n\n# Same, but specifying the backend module\n# MyApp.Cldr specifically\niex> ~l(en-US|MyApp.Cldr)\n#Cldr.LanguageTag \n\n# The `u` flag will parse and validate\n# the language tag but it may not be known\n# as a configured locale\niex> ~l(zh)u\n#Cldr.LanguageTag \n\n# Language tags can convey a lot more information\n# than might be initially expected!\niex> ~l(en-u-ca-ethiopic-cu-aud-sd-gbsct-t-d0-lower-k0-extended-m0-ungegn-x-ux)\n#Cldr.LanguageTag \n\n```","ref":"readme.html#about-language-tags"},{"type":"extras","title":"Locale extensions - Getting Started with Cldr","doc":"Unicode defines the [U extension](https://unicode.org/reports/tr35/#Locale_Extension_Key_and_Type_Data) which support defining the requested treatment of CLDR data formats. For example, a locale name\ncan configure the requested:\n\n* calendar to be used for dates\n* collation\n* currency\n* currency format\n* number system\n* first day of the week\n* 12-hour or 24-hour time\n* time zone\n* and many other items\n\nFor example, the following locale name will request the use of the timezone `Australia/Sydney`,\nand request the use of `accounting` format when formatting currencies:\n```elixir\niex> MyApp.Cldr.validate_locale \"en-AU-u-tz-ausyd-cf-account\"\n{:ok,\n %Cldr.LanguageTag{\n   canonical_locale_name: \"en-Latn-AU\",\n   cldr_locale_name: \"en-AU\",\n   extensions: %{},\n   gettext_locale_name: \"en\",\n   language: \"en\",\n   language_subtags: [],\n   language_variants: nil,\n   locale: %Cldr.LanguageTag.U{cf: :account, timezone: \"Australia/Sydney\"},\n   private_use: [],\n   rbnf_locale_name: \"en\",\n   requested_locale_name: \"en-AU\",\n   script: :Latn,\n   territory: :AU,\n   transform: %{}\n }}\n```\nThe implementation of these extensions is governed by each library in the `ex_cldr` family. As of January 2020, [ex_cldr_numbers version 2.10](https://hex.pm/packages/ex_cldr_numbers/2.10.0) implements the following `U` extension keys:\n\n* `cf` (currency format)\n* `cu` (currency)\n* `nu` (number system)\n\nOther libraries in the family will progressively implement other extension keys.","ref":"readme.html#locale-extensions"},{"type":"extras","title":"Notes - Getting Started with Cldr","doc":"* A language code is an ISO-3166 language code.\n* Potentially one or more modifiers separated by `-` (dash), not a `_`. (underscore).  If you configure a `Gettext` module then `ex_cldr` will transliterate `Gettext`'s `_` into `-` for compatibility.\n* Typically the modifier is a territory code.  This is commonly a two-letter uppercase combination.  For example `pt-PT` is the locale referring to Portuguese as used in Portugal.\n* In `ex_cldr` a locale name is always a `binary` and never an `atom`.  Internally a locale is parsed and stored as a `t:Cldr.LanguageTag` struct.\n* The locales known to `ex_cldr` can be retrieved by `Cldr.known_locale_names/1` to get the locales known to this configuration of `ex_cldr` and `Cldr.all_locale_names/0` to get the locales available in the CLDR data repository.","ref":"readme.html#notes"},{"type":"extras","title":"Developing ex_cldr - Getting Started with Cldr","doc":"See the file `DEVELOPMENT.md` in the GitHub repository.","ref":"readme.html#developing-ex_cldr"},{"type":"extras","title":"Testing - Getting Started with Cldr","doc":"Tests cover the full ~700 locales defined in CLDR. Since `ex_cldr` attempts to maximize the work done at compile time in order to minimize runtime execution, the compilation phase for tests is several minutes.\n\nTests are run on Elixir 1.11 and later.  `ex_cldr` is not supported on Elixir versions before 1.11.","ref":"readme.html#testing"},{"type":"extras","title":"License","doc":"# License\n\nCopyright 2018-2020 Kip Cole\n\nLicensed under the Apache License, Version 2.0 (the \"License\"); you may not use this file except in\ncompliance with the License. You may obtain a copy of the License at\n\n    http://www.apache.org/licenses/LICENSE-2.0\n\nUnless required by applicable law or agreed to in writing, software distributed under the License\nis distributed on an \"AS IS\" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or\nimplied. See the License for the specific language governing permissions and limitations under the\nLicense.","ref":"license.html"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n**Note that `ex_cldr` version 2.39.0 and later are supported on Elixir 1.12 and later only.**","ref":"changelog.html"},{"type":"extras","title":"Cldr v2.41.0 - Changelog","doc":"This is the changelog for Cldr v2.41.0 released on March 18th, 2025.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-41-0"},{"type":"extras","title":"Breaking Data format changes - Changelog","doc":"There are some changes to the underlying locale data format that will be a breaking change for results returned from:\n\n* `Cldr.DateTime.Format.time_formats/{1,2,3}`\n* `Cldr.Number.Symbol.number_symbols_for/3`\n* `MyApp.Cldr.Calendar.day_periods/{0, 1, 2}`\n\nThe data changes are summarised as:\n\n* Delimiters are now organized with `:default` and `:variant` quotation marks where the data is available.\n* Time formats now group the `:default` and `:ascii` alternatives.\n* Day periods used for date/time formatting now group the alternatives for `am` and `pm` where the data is available.\n* Day period display names now group the alternatives for `am` and `pm` where the data is available.","ref":"changelog.html#breaking-data-format-changes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to [CLDR 47](https://cldr.unicode.org/downloads/cldr-47) data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.40.4 - Changelog","doc":"This is the changelog for Cldr v2.40.4 released on March 18th, 2025.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-40-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove `:eex` and `:ex_unit` from `:extra_applications`. Thanks to @tanguilp for the report. Closes #253.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.40.3 - Changelog","doc":"This is the changelog for Cldr v2.40.3 released on March 9th, 2025.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-40-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes compilation error when the path of the containing project contains non-ASCII characters. Thanks to @zachdaniel and @albinkc for the report. Closes #251.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.40.2 - Changelog","doc":"This is the changelog for Cldr v2.40.2 released on December 23rd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-40-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Support (and automatically configure) Elixir 1.18's JSON module as a `:json_library` in the global configuration. Thanks to @Neophen for the report. Closes #247.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.40.1 - Changelog","doc":"This is the changelog for Cldr v2.40.1 released on August 16th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-40-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix specs to suport dialyzer flags `:error_handling, :unknown, :underspecs, :extra_return, :missing_return`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.40.0 - Changelog","doc":"This is the changelog for Cldr v2.40.0 released on July 26th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-40-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix parsing of date time available formats and interval formats when building the locale json files. Turns out some locales have formats that have variants and these need to be specifically parsed and grouped.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support OTP's `:json` module.  `ex_cldr` uses json formatted locale data and supports configuring a `json` library to decode it. Where no library is configured `ex_cldr` will attempt to identify one. This release adds auto-configuring OTP 27's `:json` module through a proxy implemented in `Cldr.Json` (which is part of `cldr_utils`).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.39.2 - Changelog","doc":"This is the changelog for Cldr v2.39.2 released on June 22nd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-39-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.LanguageTag.Sigil.sigil_l/2` which was incorrectly encoding the sigil flags.\n\n* Bump `stream_data` dependency version.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.39.1 - Changelog","doc":"This is the changelog for Cldr v2.39.1 released on June 11th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-39-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Kino.DataTable.format/2` to reflect the changes requested by the Kino team. See the [PR](https://github.com/livebook-dev/kino/pull/441) for further information.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.39.0 - Changelog","doc":"This is the changelog for Cldr v2.39.0 released on June 11th, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-39-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix dialyzer warnings on Elixir 1.17","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Kino.DataTable.value_to_string/2` which can be used to format Kino DataTable cells in a future Kino release. A [fork of Kino](https://github.com/kipcole9/kino) is available for testing.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.38.1 - Changelog","doc":"This is the changelog for Cldr v2.38.2 released on May 2nd, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-38-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix warnings on Elixir 1.17. This primarily relates to charlists constants now required to use `sigil_c` to avoid warnings. As a result, tests will only work on Elixir 1.16 and later even though support for the library is for Elixir 1.11 and later.\n\n* Make `Cldr.Config.cldr_data_dir/0` a runtime result, not a compile time result.\n\n* Sort currency data in `Cldr.Config.territories/0` so ensure deterministic order. Closes #227.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.38.0 - Changelog","doc":"This is the changelog for Cldr v2.38.0 released on April 21st, 2024.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-38-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to [CLDR 45.0](https://cldr.unicode.org/index/downloads/cldr-45) data.\n\n* Adds `Cldr.validate_locale!/2`. Thanks to @jarrodmoldrich for the suggestion.\n\n* Add decimal separator and grouping separator to the currency data for each locale. In some rare cases, like the currency [CVE](https://en.wikipedia.org/wiki/Cape_Verdean_escudo#:~:text=The%20escudo%20(sign%3A%20%3B%20ISO,subdivided%20into%20one%20hundred%20centavos.)) in the locale [pt-CV](https://www.localeplanet.com/icu/pt-CV/index.html) the currency symbol is placed where decimal separator is normally placed. The same can apply for the grouping separator although it appears no locale uses this field.\n\n* Adjust the `Inspect` protocol implementation for `t:Cldr.LanguageTag.t/0` types. When the language tag is resolved to a CLDR locale then the output is executable code. For example:\n\n```elixir\niex> MyApp.Cldr.Locale.new!(\"en-US\")\nMyApp.Cldr.Locale.new!(\"en-US\")\n```\n\n* Fix dialyzer warnings. Thanks to @Munksgaard for the PR. Closes #220. Also fixes `:underspecs` warning and the `:underspecs` dialyzer flag is now configured.\n\n* Add configuration for the new [ex_cldr_person_names](https://hex.pm/packages/ex_cldr_person_names) backend module generator.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.37.5 - Changelog","doc":"This is the changelog for Cldr v2.37.5 released on November 2nd, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-37-5"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix warnings on Elixir 1.16.\n\n* Fix dialyzer warnings. Thanks to @Munksgaard for the PR. Closes #220.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.37.4 - Changelog","doc":"This is the changelog for Cldr v2.37.4 released on October 12th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-37-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Reverts a change to the format of the alias data for subdivisions which was causing an exception in `ex_cldr_territories`. The change, which normalizes subdivision codes to be upcase atoms when the subdivision has its own ISO 3166 territory code, will be be added back for `ex_cldr` version 2.38.0 which will align with CLDR 44. Closes #216.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.37.3 [Deprecated] - Changelog","doc":"This is the changelog for Cldr v2.37.3 released on Octoebr 12th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-37-3-deprecated"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix spec for `Cldr.with_locale/3` and `MyApp.Cldr.with_locale/2`. Thanks to @nTraum for the PR. Closes #215.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds ` .put_gettext_locale/1`.\n\n* Adds `Cldr.validate_locale!/2`. Thanks to @jarrodmoldrich for the suggestion.\n\n* Add decimal separator and grouping separator to the currency data for each locale. In some rare cases, like the currency [CVE](https://en.wikipedia.org/wiki/Cape_Verdean_escudo#:~:text=The%20escudo%20(sign%3A%20%3B%20ISO,subdivided%20into%20one%20hundred%20centavos.) in the locale [pt-CV](https://www.localeplanet.com/icu/pt-CV/index.html) the currency symbol is placed where decimal separator is normally placed. The same can apply for the grouping separator although it appears not locale uses this field.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.37.2 - Changelog","doc":"This is the changelog for Cldr v2.37.2 released on July 4th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-37-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove checking Phoenix and Ecto json_library configurations.  Ecto no longer configures its `:json_library` in `config.exs` and checking for Phoenix configuration can cause config failures when [building in Docker](https://github.com/elixir-cldr/cldr/issues/208). Thanks to @maciej-szlosarczyk for the report. Closes #208.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Improves parsing of language tag extensions. Primarily intended to improve support for [tempo](https://github.com/kipcole9/tempo).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.37.1 - Changelog","doc":"This is the changelog for Cldr v2.37.1 released on May 7th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-37-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Don't include `:und` in the list returned by `Cldr.known_locale_names/1` since that function is commonly used to enumerate the configured locales and ultimately used to generate UI elements. `:und` is not a useful locale to select so its inclusion, which was added in `ex_cldr version 2.37.0` is inappropriate and now reverted.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.37.0 - Changelog","doc":"This is the changelog for Cldr v2.37.0 released on April 28th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-37-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes `Cldr.Locale.parent/1` to use `:und` as the ultimate parent rather than the default locale. This brings closer conformance to the [CLDR specification](https://unicode.org/reports/tr35/).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Upgrade to [CLDR 43](https://cldr.unicode.org/index/downloads/cldr-43) data.\n\n* Locale data is now versioned. If a locale file is found but if has no version (data prior to this release) or a version that does not match, the appropriate locale file is downloaded. This ensures locale files and `ex_cldr` are kept in sync. Closes #188.\n\n* Changes `Cldr.version/0` to return the version of CLDR data as a `t:Version.t/0`. This is then used to check the version of the locale data and forcing a download if the locale data is out of date for this release of `ex_cldr`.\n\n* Adds `Cldr.Locale.script_direction_from_locale/1` and `MyApp.Cldr.Locale.script_direction_from_locale/1` to return `:ltr` (for left-to-right scripts) or `:rtl` (for right-to-left scripts). Closes #196. Thanks to @Doerge for the suggestion.\n\n* Adds `Cldr.Validity.Script.unicode_script_to_subtag/1` as public, undocumented function. This function is required by `ex_cldr_person_names` and may be documented in a future release. It maps between a unicode script name (like that returned by `Unicode.script/1` in the `unicode` library) to the appropriate subtag used by CLDR.\n\n* Unit data is now kept as Decimal not Ratio so `:ratio` is no longer a dependency here, or in `ex_cldr_units`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.36.0 - Changelog","doc":"This is the changelog for Cldr v2.36.0 released on March 13th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\n**Note that `ex_cldr` version 2.33.0 and later are supported on Elixir 1.11 and later only.**\n\n**Note that `ex_cldr` version 2.36.0 data for interval formats is keyed differently than that of previous releases. The bug fix noted below means that this version of `ex_cldr` is only compatible with `ex_cldr_dates_times` version `2.13.3` and later. Only `ex_cldr_dates_times` is affected, other `ex_cldr` libraries are insensitive to this change.**","ref":"changelog.html#cldr-v2-36-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes the date time interval format keys. In previous releases, the locale ingestion process would treat keys like `:Hm` as being the same as `:hm` and as a result only the lower case version would be saved. This means that locales that rely upon `0..23` or `1..24` hour formats could not be formatted correctly.\n\n* Fixes the `mix cldr.download.iso_currency` to use the `Cldr.Http.get/2` function to download the data. Doing so ensures that peer verification happens and no error log message is emitted.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.35.1 - Changelog","doc":"This is the changelog for Cldr v2.35.1 released on March 7th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\n** Note that `ex_cldr` version 2.33.0 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-v2-35-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix bug that prevented setting `:default_currency_format` that slipped into the release (tests added).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.35.0 - Changelog","doc":"This is the changelog for Cldr v2.35.0 released on March 7th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\n** Note that `ex_cldr` version 2.33.0 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-v2-35-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Deprecates `:supress_warnings` backend configuration option in favour of the correctly spelt `:suppress_warnings`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `:default_currency_format` option to a backend configuration. The value must be either `:currency`, `:accounting` or `nil` (the default). This option is used by `ex_cldr_numbers` from version 2.30.0 onwards. If `nil` the format will be derived from the locale.\n\n* No longer `IO.warn/2` when `Cldr.Number` and `Cldr.Currency` are both configured as providers. A console note is still issued but it will not raise a compiler warning.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.34.2 - Changelog","doc":"This is the changelog for Cldr v2.34.2 released on February 25th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\n** Note that `ex_cldr` version 2.33.0 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-v2-34-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compatibility for CLDR-based Gettext plural backends for Gettext versions >= 0.22.\n\n* Notify if `Cldr.Currency` backend provider is configured when `Cldr.Number` is already configured. `Cldr.Number` provider already configures `Cldr.Currency` so a compiler warning is generated if it is explicitly configured. Thanks for @lawik for the report. Closes #194.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.34.1 - Changelog","doc":"This is the changelog for Cldr v2.34.1 released on January 25th, 2023.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\n** Note that `ex_cldr` version 2.33.0 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-v2-34-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Removes the dependencies [castore](https://hex.pm/packages/castore) and [certifi](https://hex.pm/packages/certifi) since they are not required by `ex_cldr` (they are optional dependencies of the dependent [ex_cldr_utils](https://hex.pm/package/ex_cldr_utils)). Thanks to @maennchen for the PR but deleting the dependency definitions here seems more appropriate. Closes #191.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.34.0 - Changelog","doc":"This is the changelog for Cldr v2.34.0 released on October 19th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\n** Note that `ex_cldr` version 2.33.0 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-v2-34-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Encapsulates [CLDR 42](https://cldr.unicode.org/index/downloads/cldr-42) data. Unless otherwise noted, all the changes are reflected in `ex_cldr` libraries and functions.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.33.2 - Changelog","doc":"This is the changelog for Cldr v2.33.2 released on August 28th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\n** Note that `ex_cldr` version 2.33.0 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-v2-33-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes a bug in `Cldr.LanguageTag.Sigil.sigil_l/2`. With the changes in metadata structure for Elixir 14 a pattern match was failing. The pattern is now fixed and is backwards compatible with earlier Elixir versions.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.33.1 - Changelog","doc":"This is the changelog for Cldr v2.33.1 released on August 20th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\n** Note that `ex_cldr` version 2.33.0 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-v2-33-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Now delegates locale installation to `Cldr.Http.get/2` in the [cldr_utils](https://hex.pm/packages/cldr_utils) library so that we can centralise request handling and provide an \"unsafe TLS\" option for downloading to support resolution of [#184](https://github.com/elixir-cldr/cldr/issues/184).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.33.0 - Changelog","doc":"This is the changelog for Cldr v2.33.0 released on July 31st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\n** Note that `ex_cldr` version 2.33.0 and later are supported on Elixir 1.11 and later only.**","ref":"changelog.html#cldr-v2-33-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Removes warnings for Elixir 1.14.  As a result `ex_cldr` now supported Elixir 1.11 and later only (support for Elixir 1.10 has been discontinued).\n\n* Allow either `ratio 2.x` or `ratio 3.x` depdendencies to be configured. This library is only used during the development of `ex_cldr` and is not normally used by library consumers. However [ex_cldr_units](https://hex.pm/packages/ex_cldr_units) does use `ratio` so this flexibility helps downstream maintenance, especially when `ratio` is updated to avoid Elixir 1.14 deprecation warnings.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.32.1 - Changelog","doc":"This is the changelog for Cldr v2.32.1 released on July 26th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-32-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Don't use `IO.warn/2` when compiling a backend and a known Gettext locale can't be matched to a Cldr locale.  `IO.warn/2` will cause errors if the compilation setting `warnings_as_errors: true` is set.  Instead, these messages will be output as a \"note\" that does not trigger warnings. In addition the error message has been improved to make clear that although the Gettext locale has no Cldr equivalent, it will still be matched at runtime.  See the conversation at https://elixirforum.com/t/bridging-locale-name-differences-between-ex-cldr-gettext. Thanks to @lenards for the report.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.32.0 - Changelog","doc":"This is the changelog for Cldr v2.32.0 released on July 23rd, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-32-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.with_locale/{2, 3}` to source the current locale from the backend of the supplied new locale.  This reduces the chances of an exception resulting from a non-existent default backend and a default locale that is not set.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `with_locale/2` to Cldr backend modules. This ultimately delegates to `Cldr.with_locale/{2, 3}`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.31.0 - Changelog","doc":"This is the changelog for Cldr v2.31.0 released on July 6th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-31-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Locale.script_from_locale/{1, 2}` and `Cldr.default_script/0`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.30.0 - Changelog","doc":"This is the changelog for Cldr v2.30.0 released on June 5th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-30-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds a backend module for `AcceptLanguage` which defines `MyApp.Cldr.AcceptLanguage.parse/1` and `MyApp.Cldr.AcceptLanguage.best_match/1`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.29.0 - Changelog","doc":"This is the changelog for Cldr v2.29.0 released on May 10th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-29-0"},{"type":"extras","title":"Migration - Changelog","doc":"* The plugs `Cldr.Plug.SetLocale`, `Cldr.Plug.AcceptLanguage` and `Cldr.Plug.PutSession` have been extracted to their own library, [ex_cldr_plugs](https://hex.pm/packages/ex_cldr_plugs). Therefore adding `{:ex_cldr_plugs, \"~> 1.0\"}` to the `deps` of any application using these plugs is required.","ref":"changelog.html#migration"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes resolving the RBNF locale name for locales that inherit the RBNF locale from a parent. This is true for at least the \"nb\" locale which in previous releases had its own RBNF locale data but now inherits from \"no\". Thanks to @juanperi for the report. Closes [#175](https://github.com/elixir-cldr/cldr/issues/175).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.28.0 - Changelog","doc":"This is the changelog for Cldr v2.28.0 released on April 6th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-28-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update [CLDR](https://cldr.unicode.org) to [release 41](https://cldr.unicode.org/index/downloads/cldr-41). This is minor CLDR release adding `en-MV`, `hi-Latn` and `ks-Deva` locales and continuing data improvements on unit grammar. Changes to locales in this release can be found on the [locale change](https://unicode-org.github.io/cldr-staging/charts/41/delta/index.html) page.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.27.1 - Changelog","doc":"This is the changelog for Cldr v2.27.1 released on March 8th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-27-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Don't depend on CLDR production data being available at compile time in the hex package (since it won't be available at all!). Eggregious error inserted in release 2.27.0. Thanks to @dkln for the report. Closes #170.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.27.0 - Changelog","doc":"This is the changelog for Cldr v2.27.0 released on March 8th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-27-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove spurious `Cldr.Trans` module. The new [ex_cldr_trans](https://hex.pm/packages/ex_cldr_trans) provides this capability.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `:host` to the list of places that `Cldr.Plug.SetLocale` can look for to derive a locale for a request.\n\n* Add `Cldr.Locale.fallback_locale_names!/1` to return the locale fallback chain or raise an execption.\n\n* Add `Cldr.with_locale/2` to execute a function with the process locale set to a given locale. The current locale is put back in place after the function executes.\n\n* Add `Cldr.Locale.is_locale_name/1` guard.  This is an area that needs some cleanup since we have\n  * `Cldr.is_locale_name/1` that permits atoms and strings since it is used to guard functions that might use `Cldr.validate_locale/2`. Therefore this is most useful for functions that take user input.\n  * `Cldr.Locale.is_locale_name/1` that permits only atom locale names since this the canonical form.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.26.3 - Changelog","doc":"This is the changelog for Cldr v2.26.3 released on February 24th, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-26-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix spec of `Cldr.put_locale/2`. Thanks to @alappe for the report. Closes #167.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.26.2 - Changelog","doc":"This is the changelog for Cldr v2.26.2 released on February 22nd, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-26-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Locale.canonical_language_tag/3` for cases when the `:add_likely_subtags` is `false` and the locale name is `known`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.26.1 - Changelog","doc":"This is the changelog for Cldr v2.26.1 released on February 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-26-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.locale_and_backend_from/2` for atom locales. Since this is a private API there should be no upstream issues with dependent libraries.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.26.0 - Changelog","doc":"This is the changelog for Cldr v2.26.0 released on February 21st, 2022.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-26-0"},{"type":"extras","title":"LanguageTag structure changes - Changelog","doc":"* `Cldr.LanguageTag.t` has been revised with the `:cldr_locale_name` and `:rbnf_locale_name` now being atoms rather than binaries.  This is unlikely to affect client code. The primary benefit, apart from a slightly improved memory space, is the easier integration planned with the [trans](https://hex.pm/packages/trans) library.","ref":"changelog.html#languagetag-structure-changes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix setting the default backend with `Cldr.put_default_backend/1` which wasn't actually being set.\n\n* Fix `Config.message_formats` to default to an empty map, not an empty list.\n\n* Fix `Cldr.Locale.parents/1` to return an `{:ok, list}` tuple on success rather than a bare list.\n\n* Fix ` .Cldr.Number.{Cardinal, Ordinal, Spellout}.pluralize/3` for non-integer `Decimal` numbers.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add ` .Trans` module to support closer integration with the [trans](https://hex.pm/packages/trans) for database translations.\n\n* Add `Cldr.Locale.fallback_locales/1` to return the list of recursively created parent locales, including the provided locale. This can be used to support resolving translations from a system that might be sparsely populated.\n\n* Add `Cldr.Locale.fallback_locale_names/1` that returns the `:cldr_locale_name` component of the locales returned by `Cldr.Locale.fallback_locales/1`.\n\n* Adds `Cldr.Locale.locale_from_territory/{1,2}` to derive a \"best fit\" locale for a given territory. Also adds ` .Locale.locale_from_territory/1`.\n\n* Adds `Cldr.Locale.locale_from_host/{2, 3}` to derive a \"best fit\" locale for a given host name. Also adds ` .Locale.locale_from_host/2`.\n\n* Adds `Cldr.Locale.territory_from_host/1` to return the territory for a given host name. Also adds ` .Locale.territory_from_host/1`.\n\n* Adds `Cldr.Locale.consider_as_tlds/0` to return a list of valid territory suffixes that are considered as generic TLDs instead.  See https://developers.google.com/search/docs/advanced/crawling/managing-multi-regional-sites.\n\n* Adds `Cldr.Locale.languages_for_territories/0` to return a mapping of territories to that territory's most spoken language.\n\n* Adds `Cldr.put_gettext_locale/1` that sets the `gettext` locale for a given `t:Cldr.LanguageTag`.\n\n* Adds `Cldr.TestHelper` module in `test/suport` to provide testing helpers.  Initially provides `with_no_default_backend/1` function.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.25.0 - Changelog","doc":"This is the changelog for Cldr v2.25.0 released on December 16th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-25-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes configuring locales when the default locale is in posix form (ie like `en_GB`) as apposed to BCP47 form (ie `en-GB`). In fixing this bug, forming the normalised list of configured locales is now also standarised. Thanks to @gazzer82 for the report. Closes #165.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Implement `Cldr.Gettext.Plural` allowing the creation of [gettext](https://hexdocs.pm/gettext) [plural forms](https://hexdocs.pm/gettext/Gettext.Plural.html#content) modules.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.24.2 - Changelog","doc":"This is the changelog for Cldr v2.24.2 released on December 5th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-24-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Obviate compiler warning for `Code.can_await_module_compilation?/0` on Elixir versions where the function does not exist. Thanks to @DaTrader for the report.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Apply `@external_resource` for each configured locale in backend modules.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.24.1 - Changelog","doc":"This is the changelog for Cldr v2.24.1 released on November 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-24-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compilation performance regression when compiling `ex_cldr` on Elixir 1.13.  `ex_cldr` has relied upon a private API in Elixir to detect when compilation is in progress and to then cache locale files. This improves compilation performance when many locales are configured by up to 6x. However the private API has changed in Elixir 1.13 and there is now a public API as well (hooray!).  Thanks very much to @josevalim for the support as always, and for the PR that fixed the issue.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.24.0 - Changelog","doc":"This is the changelog for Cldr v2.24.0 released on October 27th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-24-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updated to [CLDR 40](https://cldr.unicode.org/index/downloads/cldr-40) data. In addition, the canonical format of some data has changed; for example subdivisions are now atoms, not strings. This change is primarily of interest to authors writing libraries that use the raw underlying locale data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes an issue with the locale loader which was incorrectly atomizing date part keys in date/time formats and conversely incorrectly stringifying the number system in the same formats.\n\n* `Cldr.validate_territory_subdivision/1` was case sensitive and didn't correctly handle atoms and binaries. Required to support `ex_cldr_territories` properly.\n\n* Correctly atomize the keys for the locale display names \"language\" types.\n\n* `Cldr.Plug.PutSession` now uses the locale key `:canonical_locale_name` to serialize to the session. Previously it was using `:cldr_locale_name` which does not include any of the extension information. Extension information encodes user preferences and is required to properly support localisation.\n\n* `Cldr.known_territories/1` no longer includes reserved, deprecated, special use or private use territory codes.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Deprecated `Cldr.Config.known_locale_names/1` in favour of `Cldr.Locale.Loader.known_locale_names/1`.\n\n* Deprecated `Cldr.Config.known_rbnf_locale_names/1` in favour of `Cldr.Locale.Loader.known_rbnf_locale_names/1`.\n\n* Deprecated `Cldr.Config.get_locale/2` in favour of `Cldr.Locale.Loader.get_locale/2`.\n\n* Deprecated the `:put_session?` option in `Cldr.Plug.SetLocale`.  Use the plug `Cldr.Plug.PutSession` instead.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr v2.24.0-rc.6 - Changelog","doc":"This is the changelog for Cldr v2.24.0-rc.6 released on October 25th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\nThis is expected to be the last RC before final release on October 27th.","ref":"changelog.html#cldr-v2-24-0-rc-6"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Deprecated `Cldr.Config.known_locale_names/1` in favour of `Cldr.Locale.Loader.known_locale_names/1`\n\n* Deprecated `Cldr.Config.known_rbnf_locale_names/1` in favour of `Cldr.Locale.Loader.known_rbnf_locale_names/1`","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr v2.24.0-rc.5 - Changelog","doc":"This is the changelog for Cldr v2.24.0-rc.5 released on October 23rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-24-0-rc-5"},{"type":"extras","title":"Deprecations - Changelog","doc":"* Deprecated `Cldr.Config.get_locale/2` in favour of `Cldr.Locale.Loader.get_locale/2`.","ref":"changelog.html#deprecations"},{"type":"extras","title":"Cldr v2.24.0-rc.4 - Changelog","doc":"This is the changelog for Cldr v2.24.0-rc.4 released on October 21st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-24-0-rc-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes an issue with the locale loader which was incorrectly atomizing date part keys in date/time formats and conversely incorrectly stringifying the number system in the same formats.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.24.0-rc.3 - Changelog","doc":"This is the changelog for Cldr v2.24.0-rc.3 released on October 18th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-24-0-rc-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* `Cldr.validate_territory_subdivision/1` was case sensitive and didn't correctly handle atoms and binaries. Now fixed. Required to support `ex_cldr_territories` properly.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.24.0-rc.2 - Changelog","doc":"This is the changelog for Cldr v2.24.0-rc.2 released on October 18th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-24-0-rc-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correctly atomize the keys for the locale display names \"language\" types.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.24.0-rc.1 - Changelog","doc":"This is the changelog for Cldr v2.24.0-rc.1 released on October 18th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-24-0-rc-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* This release updates the CLDR 40 data to the latest pre-release (it's likely the final release data).  In addition, the canonical format of some data has changed; for example subdivisions are now atoms, not strings.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.24.0-rc.0 - Changelog","doc":"This is the changelog for Cldr v2.24.0-rc.0 released on October 3rd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\nThere has been a significant amount of refactoring of the code that packages the locale files and the code that loads a locale. This has a very minor performance improvement at compile time but the major benefit is for maintainability.","ref":"changelog.html#cldr-v2-24-0-rc-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* `Cldr.Plug.PutSession` now uses the locale key `:canonical_locale_name` to serialize to the session. Previously it was using `:cldr_locale_name` which does not include any of the extension information. Extension information encodes user preferences and is required to properly support localisation.\n\n* `Cldr.known_territories/1` no longer includes reserved, deprecated, special use or private use territory codes.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to CLDR release 40","ref":"changelog.html#enhancements"},{"type":"extras","title":"Soft Deprecations - Changelog","doc":"* Deprecated the `:put_session?` option in `Cldr.Plug.SetLocale`.  Use the plug `Cldr.Plug.PutSession` instead.","ref":"changelog.html#soft-deprecations"},{"type":"extras","title":"Cldr v2.23.2 - Changelog","doc":"This is the changelog for Cldr v2.23.2 released on September 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-23-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove `telemetry` as a dependency. It is not required by `ex_cldr`. Thanks for the report from @benregn. Closes #154.\n\n* Integerize all the numeric keys in calendars, including the 60 days of the Chinese calendar cycle and the 239 Japanese eras.\n\n* Change from `use Mix.Config` to `import Config` for configuration. This has been the standard since Elixir 1.9 and since only Elixir 1.10 is supported, the update can be made.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.23.1 - Changelog","doc":"This is the changelog for Cldr v2.23.1 released on August 20th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-23-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix doc errors. Thanks to @maennchen for the report. Doc errors in other `ex_cldr` packages are also updated.  Closes #149.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.23.0 - Changelog","doc":"This is the changelog for Cldr v2.23.0 released on July 1st, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-23-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Corrects the formation of a canonical language tag. In previous releases, the script tag was always included as part of the canonical locale name. For example, `en-US` would become `en-Latn-US` because `Latn` is defined as a likely subtag of `en`. However [TR35](https://unicode-org.github.io/cldr/ldml/tr35.html#Contents) specifies that if the script is the only script specified for this language then it should be omitted from the canonical name. Fixing this conformance is also a prerequisite for generating local display names.\n\n* Fixes `Cldr.Locale.normalize_locale_name/1` to correctly case all keys in lower case except script (capital case) and region (upper case). It will now also process arbitrary locale names.\n\n* A language tag can have more than one variant and this was not correctly implemented. As a result, the `t:Cldr.LanguageTag` struct field `variant` is renamed `variants` and is now a list with a default of `[]` rather than `nil`.\n\n* Fix a race condition which could return incorrect results for a backend `known_gettext_locale_names/0`\n\n* `Cldr.validate_locale/2` will now return an error if the territory for a locale is unknown to CLDR. Note that `Cldr.Locale.new/1,2` checks only if the territory is valid - not if it is known to CLDR.\n\n* Locale inheritance no longer includes the \"root\" locale.  In alignment with [BCP 47](https://unicode-org.github.io/cldr/ldml/tr35.html#Unicode_Locale_Identifier_BCP_47_to_CLDR), the \"root\" locale is now longer a valid locale. Parsing a locale name \"root\" is still valid but it will return the \"und\" language instead.  While parsing is still correct, it remains a locale that is not valid for use in `ex_cldr`. The \"root\" locale is used only for a limited set of rules-based number formats.\n\n* Correct territory containment chain for the territory `US`.\n\n* Correctly parses and validates the [-t- extension](https://unicode-org.github.io/cldr/ldml/tr35.html#t_Extension) of a language tag.\n\n* Fixes inspecting a language tag that has a `-t-` extension and/or a private use (`-x-`) extension.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.DisplayName` protocol definition to return a localised string representation of CLDR-based structs such as `t:Cldr.LanguageTag`, `t:Cldr.Unit` and `t:Cldr.Currency`\n\n* `Cldr.Locale.new/1,2` now passes all ~1600 validation tests for parsing and forming the canonical locale name. This is a prerequisite to implementing the [Locale Display Algorithm](https://unicode-org.github.io/cldr/ldml/tr35-general.html#Display_Name_Elements) in [ex_cldr_locale_display](https://github.com/elixir-cldr/cldr_locale_display).\n\n* `Cldr.locale_and_backend_from/1` now supports a `map` of options as the argument.\n\n* `Cldr.validate_territory/1` now correctly substitutes for known aliases. For example `MyApp.Cldr.validate_locale(\"en-UK\")` will correctly return `en-GB`.\n\n* Implement the `String.Chars` protocol to support `Kernel.to_string/1` for `t:Cldr.LanguageTag` structs.\n\n* Implement the `Inspect` protocol to support `inspect/2` for `t:Cldr.LanguageTag` structs.\n\n* Add `Cldr.LanguageTag.sigil_l/2` to simplify creating `t:Cldr.LanguageTag` structs.\n\n* Add `Cldr.validate_script/1` to normalize and validate a script code (which is now in atom format as its canonical form)\n\n* Pre-compiled language tags (which are stored in `priv/cldr/language_tags.ebin`) are now cached during compilation resulting in a minor performance improvement in compile times.\n\n* Pre-generate the rfc5646 parser which improves overall compile times.  As a result the `nimble_parsec` dependency is marked as `optional` since it is no long required by library consumers.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.22.1 - Changelog","doc":"This is the changelog for Cldr v2.22.1 released on May 20th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-22-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* `Cldr.Number.PluralRule.plural_type/2` correctly returns a plural type when no backend is provided, no default backend is configured and the locale is a `t:Cldr.LanguageTag`\n\n* `Cldr.validate_locale/1` doesn't raise if there is no default backend configured and the locale is a `t:Cldr.LanguageTag`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.22.0 - Changelog","doc":"This is the changelog for Cldr v2.22.0 released on May 20th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-22-0"},{"type":"extras","title":"Soft deprecation - Changelog","doc":"* The plug `Cldr.Plug.SetSession` was introduced in `ex_cldr` version 2.21.0. However the convention in Phoenix and Plug is `put`, not `set`. The plug is renamed to `Cldr.Plug.PutSession`. `Cldr.Plug.SetSession` is still available but will emit a deprecation notice and will delegatge to `Cldr.Plug.PutSession.` Apologies to all for the sloppy release review process.","ref":"changelog.html#soft-deprecation"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix typespec of Cldr.AcceptLanguage.best_match/2. Thanks to @adriankumpf.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Make log level for \"no match\" errors in `Cldr.Plug.AcceptLanguage` configurable.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.21.0 - Changelog","doc":"This is the changelog for Cldr v2.21.0 released on May 17th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-21-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correctly pluralize numbers where the plural rule has an explicit case for the given number. When pluralizing numbers, plural rules will return a value such as `:one`, `:two`, `:few`, `:many` which is used as a key into a map of substitutions. However it is also possible to have substitutions based upon the explicit value of a number, rather than its plural type. Previously this last rule was not being applied but now is.  For the purposes of pluralization, `1.0` and `1` are considered the same - plural rules use the integer representation so a float is cast to an integer when they are both equal according to `==`.\n\n* Correctly pluralize Decimal numbers (in addition to integer and float)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `--force-locale-download` option to `mix cldr.install.locales`.\n\n* `Plug.SetLocale` default keys for locale discovery from an HTTP request are now expanded to be `[:session, :accept_language, :query, :path]`.\n\n* The `:session_key` option to `Cldr.Plug.SetLocale` is deprecated. A well-known session key is required in order to support setting the locale from the session passed to `mount/3` for liveview applications. The session key is available as `Cldr.Plug.SetLocale.session_key/0`\n\n* Adds `Cldr.Plug.SetSession` that will copy the cldr locale name from the `conn` and put it in the session. This simplifies the lifecycle of a typical HTTP request and ensures that the locale is readily available in liveviews as well.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.20.0 - Changelog","doc":"This is the changelog for Cldr v2.20.0 released on April 8th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-20-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR version 39](http://cldr.unicode.org/index/downloads/cldr-39) data.\n\n* Add `Cldr.Locale.parent/1` to return the parent locale according. This is not exactly the same as the CLDR [locale inheritance rules](https://unicode.org/reports/tr35/#Locale_Inheritance)\n\n* Add `Cldr.Locale.parents/2` to return a list of parents up to and including the `root` locale. It is a recursive use of `Cldr.Locale.parent/1`.\n\n* Add locale display name data to the locale files. This data can be used to format a locale for UI usage.\n\n* Add subdivision translations to the locale files. This data can be used to format subdivision names for UI usage. Thanks to @mskv. Closes #144.\n\n* Add grammatical features to the repository. This data is used in [ex_cldr_units](https://github.com/elixir-cldr/cldr_units). See also `Cldr.Config.grammatical_features/0`.\n\n* Add grammatical gender to the repository. This data is used in [ex_cldr_units](https://github.com/elixir-cldr/cldr_units). See also `Cldr.Config.grammatical_gender/0`.\n\n* Make `Cldr.Locale.first_match/2` a public function. This function is useful for other CLDR-based libraries to help resolve the files of localised content in CLDR.\n\n* Add `:add_fallback_locales` to the backend configuration. When `true`, the fallback locales of the configured backend locales is also added to the configuration. The default is `false` and therefore by default there is no change to behaviour from previous releases. Setting this option to `true` enables means that data that is stored in parent locales rather than child locales can be processed. This applies particularly to rules-based number formats and subdivision data. These data aren't stored in all locales - generally they are stored in the base language locale.\n\n* Add `Cldr.Config.fallback_chain/1` which takes a locale name and returns a list of locales from which this locale inherits up to but not including the `root` locale.\n\n* Add `Cldr.Config.fallback/1` which takes a locale name and returns the direct parent of the locale name.\n\n* Rename alias key `subdivisionAlias` to `subdivision`\n\n* Fix `Cldr.Substitution.substitute/2` when the template has no substitutions. Thanks to @jarrodmoldrich. Closes [ex_cldr_units #20](https://github.com/elixir-cldr/cldr_units/issues/20).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.20.0-rc.3 - Changelog","doc":"This is the changelog for Cldr v2.20.0-rc.3 released on April 7th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-20-0-rc-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.Substitution.substitute/2` when the template has no substitutions. Thanks to @jarrodmoldrich. Closes [ex_cldr_units #20](https://github.com/elixir-cldr/cldr_units/issues/20).","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.20.0-rc.2 - Changelog","doc":"This is the changelog for Cldr v2.20.0-rc.2 released on March 22nd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-20-0-rc-2"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `:add_fallback_locales` to the backend configuration. When `true`, the fallback locales of the configured backend locales is also added to the configuration. The default is `false` and therefore by default there is no change to behaviour from previous releases. Setting this option to `true` enables means that data that is stored in parent locales rather than child locales can be processed. This applies particularly to rules-based number formats and subdivision data. These data aren't stored in all locales - generally they are stored in the base language locale.\n\n* Add `Cldr.Config.fallback_chain/1` which takes a locale name and returns a list of locales from which this locale inherits up to but not including the `root` locale.\n\n* Add `Cldr.Config.fallback/1` which takes a locale name and returns the direct parent of the locale name.\n\n* Rename alias key `subdivisionAlias` to `subdivision`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.20.0-rc.1 - Changelog","doc":"This is the changelog for Cldr v2.20.0-rc.1 released on March 22nd, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-20-0-rc-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Make `Cldr.Locale.first_match/2` a public function. This function is useful for other CLDR-based libraries to help resolve the files of localised content in CLDR.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.20.0-rc.0 - Changelog","doc":"This is the changelog for Cldr v2.20.0-rc.0 released on March 19th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-20-0-rc-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR version 39](http://cldr.unicode.org/index/downloads/cldr-39) data.\n\n* Add `Cldr.Locale.parent/1` to return the parent locale according. This is not exactly the same as the CLDR [locale inheritance rules](https://unicode.org/reports/tr35/#Locale_Inheritance)\n\n* Add `Cldr.Locale.parents/2` to return a list of parents up to and including the `root` locale. It is a recursive use of `Cldr.Locale.parent/1`.\n\n* Add locale display name data to the locale files. This data can be used to format a locale for UI usage.\n\n* Add subdivision translations to the locale files. This data can be used to format subdivision names for UI usage. Thanks to @mskv. Closes #144.\n\n* Add grammatical features to the repository. This data is used in [ex_cldr_units](https://github.com/elixir-cldr/cldr_units). See also `Cldr.Config.grammatical_features/0`.\n\n* Add grammatical gender to the repository. This data is used in [ex_cldr_units](https://github.com/elixir-cldr/cldr_units). See also `Cldr.Config.grammatical_gender/0`.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.19.1 - Changelog","doc":"This is the changelog for Cldr v2.19.1 released on April 7th.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-19-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Fix `Cldr.Substitution.substitute/2` when the template has no substitutions. Thanks to @jarrodmoldrich. Closes [ex_cldr_units #20](https://github.com/elixir-cldr/cldr_units/issues/20).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.19.0 - Changelog","doc":"This is the changelog for Cldr v2.19.0 released on February 6th, 2021.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-19-0"},{"type":"extras","title":"Breaking change - Changelog","doc":"* A parsed language tag would previously turn the `tz` parameter of the `u` extension into a timezone ID. For example, the language tag `en-AU-u-tz-ausyd` would decode `ausyd` into `Australia/Sydney`. From this release, parsing no longer decodes the `tz` parameter since doing so means that `to_string/1` does not work correctly.  Use `Cldr.Locale.timezone_from_locale/1` instead.","ref":"changelog.html#breaking-change"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR 38.1](https://unicode-org.github.io/cldr-staging/charts/38.1/delta/index.html)\n\n* Includes the display name and where available the gender for units in the locale data to support generating UI elements in the upcoming version 3.4.0 of [ex_cldr_units](https://github.com/elixir-cldr/cldr_units)\n\n* Add `Cldr.Locale.timezone_from_locale/{1,2}` to extract a timezone ID from a language tag\n\n* Add option `:format` to `Cldr.ellipsis/2`. This option is either `:word` or `:sentence`.  `:sentence` is the default. Using the locale `en` as an example, the differences in formatting are:\n\n```elixir\n# Default style: :sentence\niex> Cldr.ellipsis \"And furthermore\"\n\"And furthermore…\"\n\niex> Cldr.ellipsis [\"And furthermore\", \"there is much to be done\"], locale: \"ja\"\n\"And furthermore…there is much to be done\"\n\n# With style: :word\niex> Cldr.ellipsis \"And furthermore\", style: :word\n\"And furthermore …\"\n\niex> Cldr.ellipsis [\"And furthermore\", \"there is much to be done\"], locale: \"ja\", format: :word\n\"And furthermore … there is much to be done\"\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.18.2 - Changelog","doc":"This is the changelog for Cldr v2.18.2 released on November 9th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-18-2"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add `Cldr.Locale.territory_from_locale/1` for string language tags","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.18.1 - Changelog","doc":"This is the changelog for Cldr v2.18.1 released on November 7th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-18-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add ` .Locale.territory_from_locale/1`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes `Cldr.LanguageTag.to_string/1` when the `u` extenion is empty. Closes #140. Thanks to @Zurga.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.18.0 - Changelog","doc":"This is the changelog for Cldr v2.18.0 released on November 1st, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-18-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to [CLDR 38](http://cldr.unicode.org/index/downloads/cldr-38)\n\n* Removed the `mix cldr.compile` mix task (it was deprecated several releases ago)\n\n* Removed the `mix cldr.download.core_data` mix task since the current development process does not require it.\n\n* The script `ldml2json` now rebuilds to tools on each run and instead of hardcoded environment variables it uses existing ones if set and only applies defaults if required. This is applicable only to `ex_cldr` developers and maintainers.\n\n* Warn on duplicate providers being configured for a backend and then ignore the duplicates.\n\n* Omit stacktrace when warning about use of the global configuration\n\n* Deprecate `Cldr.default_backend/0` in favour of `Cldr.default_backend!/0` which more clearly expresses that the function will raise if no default backend is configured.\n\n* Changes the behaviour of `Cldr.put_locale/{1, 2}`. In previous releases the intent was that a process would store a locale for a given backend. Logically however, it is more appropriate to store a locale on a per-process basis, not per backend per process.  The backend is an important asset, but only insofaras it hosts locale-specific content.  Therefore in this release, `Cldr.put_locale/{1, 2}` always stores the locale on a per-process basis and there is only one locale, not one specialised per backend. This also simplifies `Cldr.get_locale/0` which now returns the process's locale or the default locale.\n\n* Support plural categories of \"compact decimals\". These are represented as `{number, formatting_exponent}`. See [TR35](https://unicode-org.github.io/cldr/ldml/tr35-numbers.html#Plural_rules_syntax) for more information. This notation is only supported for `Cldr.Number.PluralRule.plural_type/2`. In CLDR version 38 only the locale \"fr\" includes rules that differ for some compact formats. For example:\n```\n# For all locales except \"fr\" the plural type is the same\n# for all exponents\niex> Cldr.Number.PluralRule.plural_type {1234567, 3}, locale: \"en\"\n:other\niex> Cldr.Number.PluralRule.plural_type {1234567, 6}, locale: \"en\"\n:other\n\n# For \"fr\", compact formats pluralize differently in some cases\niex> Cldr.Number.PluralRule.plural_type {1234567, 3}, locale: \"fr\"\n:other\niex> Cldr.Number.PluralRule.plural_type {1234567, 6}, locale: \"fr\"\n:many\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.17.2 - Changelog","doc":"This is the changelog for Cldr v2.17.2 released on September 30th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-17-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* When configuring a Cldr backend, warn then omit any Gettext locales configured that aren't actually available in CLDR. Thanks to @mikl. Closes #138.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.17.1 - Changelog","doc":"This is the changelog for Cldr v2.17.1 released on September 26th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-17-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Significantly improve the performance of `Cldr.default_locale/0`. In previously releases, the default locale was being parsed on each access. In this release it is parsed once and cached in the application environment. This improves performance by about 40x.  Thanks to @Phillipp who brought this to attention in [Elixir Forum](https://elixirforum.com/t/cldr-number-parser-parse-quite-slow/34572)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.17.0 - Changelog","doc":"This is the changelog for Cldr v2.17.0 released on September 8th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-17-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Support `Decimal` version `~> 1.6` and `~> 2.0`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Corrects `Cldr.Plug.SetLocale` testing for body parameters. Previous version of `Plug` would parse body parameters for an HTTP `get` verb which is not standard behaviour. The test now uses the HTTP `put` verb where body parameters are expected to be parsed.\n\n* Corrects internal links to the readme.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.16.2 - Changelog","doc":"This is the changelog for Cldr v2.16.2 released on August 29th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-16-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compiler warning for Elixir 1.11 when calling a remote function that is based upon a module name that is a variable.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.16.1 - Changelog","doc":"This is the changelog for Cldr v2.16.1 released on June 7th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-16-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Do not send `Connection: close` header when downloading locales.\n\n* Do not convert `charlist` data from `:httpc` before saving it as a locale file. Fixes an issue whereby the saved locale file is shorter than expected due to an extraneous use of `:erlang.list_to_binary/1` which is not `UTF8` friendly. Thanks to @halostatue for the patience and persistence working this issue through on a weekend. Fixes #137.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.16.1-rc.0 - Changelog","doc":"This is the changelog for Cldr v2.16.1-rc.0 released on June 7th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-16-1-rc-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Do not send `Connection: close` header when downloading locales.\n\n* Do not convert `charlist` data from `:httpc` before saving it as a locale file. Probably fixes an issue whereby the saved locale file is shorter than expected.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.16.0 - Changelog","doc":"This is the changelog for Cldr v2.16.0 released on June 6th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-16-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Add configuration key `:force_locale_download` for backend and the global configuration. Locale data is `ex_cldr` version dependent. When a new version of `ex_cldr` is installed, no locales are installed and therefore locales are downloaded at compilation time as required. This ensures that the right version of the locale data is always associated with the right version of `ex_cldr`.\n\nHowever:\n\n* If locale data is being cached in CI/CD there is some possibility that there can be a version mismatch.  Since reproducible builds are important, using the `force_locale_download: true` in a backend or in global configuration adds additional certainty.  The default setting is `false` thereby retaining compatibility with existing behaviour. The configuration can also be made dependent on `mix` environment as shown in this example:\n\n```elixir\ndefmodule MyApp.Cldr do\n  use Cldr,\n\t  locales: [\"en\", \"fr\"],\n\t\tdefault_locale: \"en\",\n\t\tforce_locale_download: Mix.env() == :prod\n\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Validate configured locales in a backend case insensitively and with either BCP 47 or Poxix (\"-\" or \"_\") separators.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.15.0 - Changelog","doc":"This is the changelog for Cldr v2.15.0 released on May 27th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\nStarting with `ex_cldr` the development process now requires the CLDR repository be cloned to the development machine; that the CLDR json data is generated on that machine and the shell variable `CLDR_PRODUCTION_DATA` must be set to the directory where the generated json data is stored.  For more information on the development process for `ex_cldr` consult `DEVELOPMENT.md`\n\nThis change is relevant only to the developers of `ex_cldr`. It is not applicable to users of the library.","ref":"changelog.html#cldr-v2-15-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds data to support lenient parsing of dates and numbers","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.14.1 - Changelog","doc":"This is the changelog for Cldr v2.14.1 released on May 15th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-14-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix compilation order for backends configured in `Cldr.Plug.SetLocale`. Thanks to @syfgkjasdkn. Closes #135.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.14.0 - Changelog","doc":"This is the changelog for Cldr v2.14.0 released on May 2nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)\n\nThe primary purpose of this release is to support the new data for units that standardize\na means for conversion.  In addition, some data file names are changed to be more consistent in naming.","ref":"changelog.html#cldr-v2-14-0"},{"type":"extras","title":"Summary - Changelog","doc":"* Updates the data source to [CLDR release 37](http://cldr.unicode.org/index/downloads/cldr-37).\n\n* Require that a certificate trust store be configured in order to download locales. A system trust store will be automatically detected in many situations. In other cases configuring [castore](https://hex.pm/packages/castore) or [certifi](https://hex.pm/packages/certifi) will be automatically detected. A specific trust store can be configured under the `:cacertfile` key of the `:ex_cldr` configuration in `config.exs`. Note that on Windows either `castore`, `certifi` or a configured trust store will be required.\n\n* Add `Cldr.put_default_locale/{1, 2}` to set the system-wide default locale. The removes the need to configure a default locale in `config.exs` in keeping with modern Elixir app configuration strategies.\n\n* Adds the `Cldr.Chars` protocol and the `Cldr.to_string/1` function intended to be a drop-in replacement for `Kernel.to_string/1` to make it easier to develop localised applications.\n\n* Add the new data Units introduced in [CLDR version 37](http://cldr.unicode.org/index/downloads/cldr-37). This data is used in an updated `ex_cldr_units` package.\n\n* The plugs `Cldr.Plug.AcceptLanguage` and `Cldr.Plug.SetLocale` no longer require a backend be configured. The `Cldr.default_backend/0` will be used if no specific backend is configured.\n\n* Add territory subdivisions. The are a geographic level below territory and typically represent states/provinces of a country. In some cases large cities or counties are also known.\n\n* Add calendar preferences.  `Cldr.Config.calendar_preferences/0` returns the map of territory to the desired calendar list in descending order or preference.\n\n* Add \"yue\" locale now that the data is complete in CLDR 37. There are now 566 locales up from 541 in CLDR 36.  See the [release notes](http://cldr.unicode.org/index/downloads/cldr-37) for further information.","ref":"changelog.html#summary"},{"type":"extras","title":"Breaking changes (that you should not notice) - Changelog","doc":"Although these are breaking changes, they are changes that affect functions in `Cldr.Config` which is considered a private module and therefore client applications are not expected to be impacted.\n\n* Minimal supported version of Elixir is 1.6 (it was 1.5)\n\n* Adds `Cldr.LanguageTag.U` to formalise the structure of the BCP47 `U` extension. This changes the data format of a `LanguageTag` that has a `U` extension. Additionally, most fields of this struct are now atoms, not binaries.\n\n* Adds `Cldr.LanguageTag.T` to formalise the structure of the BCP47 `T` extension. This changes the data format of a `LanguageTag` that has a `T` extension.\n\n* Rename `Cldr.Config.calendar_data/0` to `Cldr.Config.calendars/0`\n\n* Rename `Cldr.Config.territory_info/0` to `Cldr.Config.territories/0`\n\n* Rename `Cldr.Config.territory_info/1` to `Cldr.Config.territory/1`\n\n* Rename `Cldr.Config.week_data/0` to `Cldr.Config.weeks/0`\n\n* Rename `Cldr.Config.territory_containment/0` to `Cldr.Config.territory_containers/0`\n\n* Remove `priv/cldr/measurement_system_preferences.json`. This data is returned in `Cldr.Config.territories/0`\n\n* Use canonical measurement system names throughout. This changes some data returned by `Cldr.Config.territory/0` and `Cldr.Config.measurement_system_preferences/0`\n\n* Rename `priv/cldr/week_data.json` to `priv/cldr/weeks.json`\n\n* Rename `priv/cldr/calendar_data.json` to `priv/cldr/calendars.json`\n\n* Rename `priv/cldr/territory_info.json` to `priv/cldr/territories.json`","ref":"changelog.html#breaking-changes-that-you-should-not-notice"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correct the preferred measurement system for temperature in some territories (including the US)","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Require that a certificate trust store be configured in order to download locales\n\n* Add the `Cldr.Chars` protocol which defines `to_string/1` and it invoked from `Cldr.to_string/1`. It is intended as a drop-in replacement for `Kernel.to_string/1` excepting that it produces localised output. Then intent is to continue making it easier for developers to build localised applications.\n\n* The plug `Cldr.Plug.AcceptLanguage` no longer requires that a backend be configured. The backend returned by `Cldr.default_backend/0` will be used by default.\n\n* The plug `Cldr.Plug.SetLocale` no longer requires that a backend be configured. The backend returned by `Cldr.default_backend/0` will be used by default.\n\n* `t:Cldr.LanguageTag.t` now includes a `:backend` field which is populated during parsing. This allows the implementation of the `Cldr.Chars` protocol.\n\n* CLDR has introduced unit conversion data. This data is now packaged as `Cldr.Config.units/0` which is used for [ex_cldr_units version 3.0](https://hex.pm/packages/ex_cldr_units/3.0.0)\n\n* Unit Preferences now consistently use underscore in names and values instead of dashes.\n\n* Add `Cldr.validate_backend/1` to validate if a module is a CLDR backend module\n\n* Add `Cldr.validate_measurement_system/1` to validate a measurement system name\n\n* Add `Cldr.Config.measurement_systems/0` to return a map of known measurement systems\n\n* Add `Cldr.Config.time_preferences/0` to return a map of time preferences for a given locale or territory. This data is used in [ex_cldr_dates_times](https://github/com/elixir-cldr/cldr_dates_times) from version `2.4`\n\n* Add `Cldr.Config.territory_containment/0` that returns a map of territories to a list of lists of the territories in which it is contained. A territory may be contained by more than one list of containers. For example, `:GB` is contained like this: `[[:\"154\", :\"150\", :\"001\"], [:UN], [:EU]]`.\n\n* Add `Cldr.known_territory_subdivisons/0` to return a map of regions and subdivisions and their children\n\n* Add `Cldr.known_territory_subdivision_containment/0` to return a map of subdivisions and their parents\n\n* Add `priv/cldr/units.json` which contains the new unit data and conversion information from CLDR 37\n\n* Add `priv/cldr/measurement_systems.json`\n\n* Add `Cldr.validate_backend/1` to confirm a backend modules existence and that it includes `use Cldr`\n\n* Add `Cldr.Locale.territory_from_locale/1` to determine the territory to be used for localization.\n\n* Add `Cldr.Config.calendar_preferences/0`\n\n* Add `Cldr.the_world/0` that returns the territory code for the world which is `:001`","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.13.0 - Changelog","doc":"This is the changelog for Cldr v2.13.0 released on January 19th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-13-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Removes the runtime dependency on `Jason` since the RFC5646 parser is now inlined. Closes #99\n\n* Adds `Cldr.Timezone` to support timezone mapping for language tags using the `tz` key of the `u` extension to the [Unicode locale identifier](https://unicode.org/reports/tr35/#u_Extension)\n\n* When parsing a locale with a `u` extension containing a `cf` (currency format) key, the key is transformed to the standard `:currency` or `:accounting` atoms rather than being left as strings.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.12.1 - Changelog","doc":"This is the changelog for Cldr v2.12.1 released on January 14th, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-12-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove two lingering dialyzer errors-that-aren't-really-errors so its passes cleanly.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.12.0 - Changelog","doc":"This is the changelog for Cldr v2.12.0 released on January 2nd, 2020.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-12-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Remove use of `Code.ensure_compiled?/1` since its deprecated in Elixir 1.10. A new function `Cldr.Config.ensure_compiled?/1` is introduced but marked as `@doc false`.\n\n* Adds `mix cldr.download.plural_ranges` to automate the downloading, extracting and saving of `pluralRanges.xml` from CLDR.\n\n* Update copyright dates in LICENSE.md","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.11.1 - Changelog","doc":"This is the changelog for Cldr v2.11.1 released on October 20th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-11-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Validate session-based locale in `Cldr.Plug.SetLocale`. Closes #131. Thanks for @Ray-Wang.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.11.0 - Changelog","doc":"This is the changelog for Cldr v2.11.0 released on October 10th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-11-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Update to CLDR data version 36.0.0.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.10.2 - Changelog","doc":"This is the changelog for Cldr v2.10.2 released on September 7th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-10-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Use `Keyword.get_lazy/3` when retrieving `Cldr.default_backend/0` to avoid exceptions when no default backend is configured.\n\n* `Cldr.Number.PluralRule.plural_type/2` has become `Cldr.Number.PluralRule.plural_type/3` to better align with other functions that typically use `argument, backend, options` as their parameters. No user code change is expected as the function heads remain compatible.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.10.1 - Changelog","doc":"This is the changelog for Cldr v2.10.1 released on August 25th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-10-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix error in the generation of unit preference data","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.10.0 - Changelog","doc":"This is the changelog for Cldr v2.10.0 released on August August 25th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-10-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds unit preference data. This data is used by [ex_cldr_units](https://hex.pm/packages/ex_cldr_units) version 2.6 and later to allow localization of units into the preferred units for a given locale or territory.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.9.0 - Changelog","doc":"This is the changelog for Cldr v2.9.0 released on August August 24th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-9-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Includes the compound unit fields from units in the generated locale data.  This enables formatting of compound units, like the \"per\" form which is used when there is no predefined unit style. This functionality is enabled in [ex_cldr_units](https://hex.pm/packages/ex_cldr_units) version 2.6.\n\n* Add `Cldr.quote/3` and `MyApp.Cldr.quote/2` that add locale-specific quotation marks around a string.  The locale data files are updated to include this information.\n\n* Add `Cldr.ellipsis/3` and `MyApp.Cldr.ellipsis/2` that add locale-specific ellipsis' to a string. The locale data files are updated to include this information.\n\n* Add `Cldr.Config.measurement_system/0` that returns a mapping between a territory and a measurement system (ie does a territory/country use the metric, US or UK system)","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.8.1 - Changelog","doc":"This is the changelog for Cldr v2.8.1 released on August 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-8-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix the `@spec` for `Cldr.Substitution.substitute/2`","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.8.0 - Changelog","doc":"This is the changelog for Cldr v2.8.0 released on August 21st, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-8-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.validate_plural_type/1` which will validate if a plural type is one those returned by `Cldr.Number.PluralRule.known_plural_types/0` which is also added.  These functions are added to support message formatting in the forthcoming `ex_cldr_messages` package.\n\n* Adds `Cldr.Number.PluralRule.plural_type/2` which returns the plural type for a number.\n\n* Adds `message_formats` backend configuration key.  This is used by [ex_cldr_messages](https://github.com/elixir-cldr/cldr_messages) to define custom formats for messages.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Add `@spec` to parser combinators to remove dialyzer warnings.  Ensure that you are using `nimble_parsec` version 0.5.1 or later if running dialyzer checks.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.7.2 - Changelog","doc":"This is the changelog for Cldr v2.7.2 released on June 14th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-7-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fixes a bug whereby a `Gettext` backend module may not be compiled at the time that the `Cldr` backend is being compiled. This can cause compilation errors and may cause the wrong assembly of configured locales. Closes #124.  Thanks very much to @erikreedstrom and @epilgrim.\n\n* Fixes a bug whereby a `Cldr` backend may not be recognised during compilation of `Cldr.Plug.SetLocale`. Similar issue to #124. Thanks for @AdrianRibao for the report.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.7.1 - Changelog","doc":"This is the changelog for Cldr v2.7.1 released on June 2nd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-7-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.known_number_systems/0` by removing the call to `Config.known_number_systems/0` which decodes json on each call and use `Cldr.known_number_systems/0` which does not.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.7.0 - Changelog","doc":"This is the changelog for Cldr v2.7.0 released on April 22nd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-7-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to CLDR version 35.1.0 which is primarily related to the change of Japanese era with the ascension of a new emperor on April 1st.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.6.2 - Changelog","doc":"This is the changelog for Cldr v2.6.2 released on April 16th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-6-2"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.flag/1` that returns a binary unicode grapheme representing a flag for a given territory\n\n* The parameters provided to `Cldr.Plug.SetLocale.init/1` are now conformed more precisely based upon the provided options. This ensures that the keys `:cldr` and `:gettext` are set from other options if they are not provided directly.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* `Cldr.Plug.SetLocale.init/1` would raise an exception if no `:gettext` key was specified.  This is now corrected.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.6.1 - Changelog","doc":"This is the changelog for Cldr v2.6.1 released on April 13th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-6-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correctly resolves the `:data_dir` param for a backend module.  Thanks to @erikreedstrom for the report.  Closes #123.\n\n* Raises if a backend module configures an `:otp_app` that is not known","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.6.0 - Changelog","doc":"This is the changelog for Cldr v2.6.0 released on March 28th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-6-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Updates to [CLDR version 35.0.0](http://cldr.unicode.org/index/downloads/cldr-35) released on March 27th 2019.\n\nThere is one unresolved issue in this implementation related to plural rules for the locale \"kw\" (Cornish).\n\nThe plural rule definition for `:other` in the repository is:\n```\n\"pluralRule-count-other\": \" @integer 4~19, 100, 1000000, … @decimal 0.1~0.9, 1.1~1.7, 10.0, 100.0, 1000.0 100000.0 1000000.0, …\",\n```\n\nHowever in rules testing, the values `1000.0`, `10000.0` and `100000.0` are resolving to category `:two` rather than `:other`. Until this is resolved, these data points are removed from the test data.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.5.0 - Changelog","doc":"This is the changelog for Cldr v2.5.0 released on March 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-5-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds the global `:ex_cldr` configuration key `:default_backend`.\n\n* Adds `Cldr.default_backend/0` which will return the configured default backend or will raise an exception if not is configured.\n\n* Where appropriate, `Cldr.*` will now use `Cldr.default_backend()` as a default parameter.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.4.3 - Changelog","doc":"This is the changelog for Cldr v2.4.3 released on March 20th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-4-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix `Cldr.validate_locale/1` @spec error and remove spurious `@dialyzer` directives","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.4.2 - Changelog","doc":"This is the changelog for Cldr v2.4.2 released on March 15th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-4-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Exclude `Cldr.Currency` from the list of known providers so that it won't be compiled twice when working with `ex_cldr_numbers`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.4.1 - Changelog","doc":"This is the changelog for Cldr v2.4.1 released on March 14th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-4-1"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Makes generation of documentation for backend modules optional.  This is implemented by the `:generate_docs` option to the backend configuration.  The default is `true`. For example:\n\n```\ndefmodule MyApp.Cldr do\n  use Cldr,\n    default_locale: \"en-001\",\n    locales: [\"en\", \"ja\"],\n    gettext: MyApp.Gettext,\n    generate_docs: false\nend\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.4.0 - Changelog","doc":"This is the changelog for Cldr v2.4.0 released on March 10th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-4-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Minor restructuring of the locale files.  Calendar map keys are harmonised to have the same names and meanings. This would not normally be user visible but a change in data format suggests a minor version bump to easy version management.\n\n* Restructure the data returned by `Cldr.Config.week_info/0` to also encode week days as numbers in the range 1..7 where 1 is Monday.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.3.2 - Changelog","doc":"This is the changelog for Cldr v2.3.2 released on March 8th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-3-2"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Does a better job of detecting a required JSON library and raising at compile time if no such library can be found.  In order of priority the search for a JSON library is:\n\n    * the key `:json_library` under the application key `:ex_cldr`\n    * a configured Phoenix `json_library`\n    * a configured Ecto `json_library`\n    * `Jason` if configured\n    * `Poison` if configured","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.3.1 - Changelog","doc":"This is the changelog for Cldr v2.3.1 released on March 6th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-3-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix dialyzer errors.  In some cases, notably related to `nimble_parsec`, errors are generated that need to be fixed in a dependency.  These errors are added to the `.dialyzer_ignore_warnings` file for now.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.3.0 - Changelog","doc":"This is the changelog for Cldr v2.3.0 released on March 4th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-3-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.LanguageTag.to_string/1` which converts a `Cldr.LanguageTag{}` into a language tag string. This is useful when creating a collator that is based upon `libicu` since that collator will apply the configuration specified by the `u` extension in the language tag.  For example:\n\n```\niex> {:ok, locale} = Cldr.validate_locale \"en-US-u-co-phonebk-nu-arab\", MyApp.Cldr\niex> Cldr.LanguageTag.to_string(locale)\n\"en-Latn-US-u-ca-phonebk-nu-arab\"\n```","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix a bug when parsing some locale strings which have extensions. An extension may have a list of \"keyword-type\" pairs or simply \"keyword\". Parsing was failing when only the \"keyword\" form was used.  For example the following used to fail, but is now parsed correctly:\n```\niex> {:ok, locale} = Cldr.validate_locale \"en-US-u-co-ca\", MyApp.Cldr\n{:ok,\n %Cldr.LanguageTag{\n   canonical_locale_name: \"en-Latn-US\",\n   cldr_locale_name: \"en\",\n   extensions: %{},\n   gettext_locale_name: nil,\n   language: \"en\",\n   language_subtags: [],\n   language_variant: nil,\n   locale: %{calendar: \"gregory\", collation: \"standard\"},\n   private_use: [],\n   rbnf_locale_name: \"en\",\n   requested_locale_name: \"en-US\",\n   script: \"Latn\",\n   territory: \"US\",\n   transform: %{}\n }}\n```\n\n* Fix a race condition when starting up the compile-time locale cache","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.2.7 - Changelog","doc":"This is the changelog for Cldr v2.2.7 released on February 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-2-7"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"Correctly validates locales that are not pre-compiled into a backend. At compile time, all configured locales are generated from the CLDR data.  However not all valid locales can be predefined - especially those that have variants, subtags or extensions or use a different casing to the canonical form.\n\nFor example, the following would fail in prior releases even though it is perfectly valid since language tags are defined to be case insensitive:\n```\niex> MyApp.Cldr.validate_locale \"en-au\"\n{:error, {Cldr.UnknownLocaleError, \"The locale \\\"en-au\\\" is not known.\"}}\n\n```\nSimilarly, it is expected that both the POSIX and IEEE formats of a language tag are acceptable, meaning that a `-` or `_` should be acceptable. Again, in prior releases this would result in an error:\n```\niex> MyApp.Cldr.validate_locale \"en_AU\"\n{:error, {Cldr.UnknownLocaleError, \"The locale \\\"en_AU\\\" is not known.\"}}\n\n```\nLastly, when using locale extensions, subtags or variants the validation would fail:\n```\nMyApp.Cldr.validate_locale \"en-u-ca-buddhist\"\n{:error, {Cldr.UnknownLocaleError, \"The locale \\\"en_AU\\\" is not known.\"}}\n```\nEach of these examples now correctly validates:\n```\niex> TestBackend.Cldr.validate_locale \"en-au\"\n{:ok,\n %Cldr.LanguageTag{\n   canonical_locale_name: \"en-Latn-AU\",\n   cldr_locale_name: \"en-AU\",\n   extensions: %{},\n   gettext_locale_name: \"en\",\n   language: \"en\",\n   language_subtags: [],\n   language_variant: nil,\n   locale: %{},\n   private_use: [],\n   rbnf_locale_name: \"en\",\n   requested_locale_name: \"en-AU\",\n   script: \"Latn\",\n   territory: \"AU\",\n   transform: %{}\n }}\niex> TestBackend.Cldr.validate_locale \"en_au\"\n{:ok,\n %Cldr.LanguageTag{\n   canonical_locale_name: \"en-Latn-AU\",\n   cldr_locale_name: \"en-AU\",\n   extensions: %{},\n   gettext_locale_name: \"en\",\n   language: \"en\",\n   language_subtags: [],\n   language_variant: nil,\n   locale: %{},\n   private_use: [],\n   rbnf_locale_name: \"en\",\n   requested_locale_name: \"en-AU\",\n   script: \"Latn\",\n   territory: \"AU\",\n   transform: %{}\n }}\niex> TestBackend.Cldr.validate_locale \"en-u-ca-buddhist\"\n{:ok,\n  %Cldr.LanguageTag{\n    canonical_locale_name: \"en-Latn-US\",\n    cldr_locale_name: \"en\",\n    extensions: %{},\n    gettext_locale_name: \"en\",\n    language: \"en\",\n    language_subtags: [],\n    language_variant: nil,\n    locale: %{calendar: :buddhist},\n    private_use: [],\n    rbnf_locale_name: \"en\",\n    requested_locale_name: \"en\",\n    script: \"Latn\",\n    territory: \"US\",\n    transform: %{}\n}}\n```","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.2.6 - Changelog","doc":"This is the changelog for Cldr v2.2.6 released on February 23rd, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-2-6"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Adds `Cldr.Config.territory_currency_data/0` that maps a territory code (like \"US\") to a list of currencies reflecting the historic and current usage of currencies in that territory.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.2.5 - Changelog","doc":"This is the changelog for Cldr v2.2.5 released on February 18th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-2-5"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Remove most dialyzer errors\n\n* Fix documentation syntax errors\n\n* Fix regex for parsing currency names into currency strings","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.2.4 - Changelog","doc":"This is the changelog for Cldr v2.2.4 released on February 10th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-2-4"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Ensure the global default locale (currently \"en-001\") is always configured","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Log a warning if a CLDR provider module could not be found","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.2.3 - Changelog","doc":"This is the changelog for Cldr v2.2.3 released on February 9th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-2-3"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Fix parsing of currency names that have date ranges or annotations within them like \"US dollar (next day)\" and \"Afghan afghani (1927–2002)\"","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.2.2 - Changelog","doc":"This is the changelog for Cldr v2.2.2 released on February 9th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-2-2"},{"type":"extras","title":"Enhancements - Changelog","doc":"* add `Cldr.Config.currencies_for/2` to return a map of the currency definition for a locale","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.2.1 - Changelog","doc":"This is the changelog for Cldr v2.2.1 released on January 30th, 2019.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-2-1"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Correctly add the `gettext` locale to the language tag returned by ` .default_locale` and `Cldr.default_locale/2`.  Thanks to @erikreedstrom.  Closes #106.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Added a section on migrating from `Cldr` 1.x to 2.x.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.2.0 - Changelog","doc":"This is the changelog for Cldr v2.2.0 released on December 23nd, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-2-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Bump `nimble_parsec` to version 0.5 which has some breaking changes from 0.4 that affects the language tag parser.\n\n* Use `IO.warn/1` for compiler warnings related to global configuration and Cldr providers configuration for a backend.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.1.0 - Changelog","doc":"This is the changelog for Cldr v2.1.0 released on December 1st, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-1-0"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Don't issue a bogus global config deprecation warning.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Revises the Cldr provider strategy - again. Rather than try to auto-discover available provider modules and configuring them automatically they are now configured under the `:provider` key.  The [readme](/readme.html#providers) contains further information on configuring providers. For example:\n\n```\ndefmodule MyApp.Cldr do\n  use Cldr,\n    locales: [\"en\", \"zh\"],\n    default_locale: \"en\",\n    providers: [Cldr.Number, Cldr.List]\nend\n```\n\nThe default behaviour is the same as `Cldr 2.0` in that all known cldr providers are configured.","ref":"changelog.html#enhancements"},{"type":"extras","title":"Cldr v2.0.4 - Changelog","doc":"This is the changelog for Cldr v2.0.4 released on November 26th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-0-4"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Dependency plugin check was using `Mix.Project.in_project/3` which actually changes directory which during compilation is a bad thing (since compilation is in parallel and within a single Unix process).  The plugin dependency list is now static.  Thanks to @robotvert. Closes #93.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.0.3 - Changelog","doc":"This is the changelog for Cldr v2.0.3 released on November 25th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-0-3"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Check for a `json` library existence as early as possible in the compile cycle since it is required during compilation of `Cldr`.","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.0.2 - Changelog","doc":"This is the changelog for Cldr v2.0.2 released on November 24th, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-0-2"},{"type":"extras","title":"Enhancements - Changelog","doc":"* Move minimal Decimal version to 1.5","ref":"changelog.html#enhancements"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* `Cldr.Substitution.substitute/2` now conforms to its documentation and substitutes a list of terms into a list format","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.0.1 - Changelog","doc":"This is the changelog for Cldr v2.0.1 released on November 22, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-0-1"},{"type":"extras","title":"Bug fixes - Changelog","doc":"* Fixes a bug whereby a backend configured with locales, but no default locale (and no global configuration), would crash during compilation","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Cldr v2.0.0 - Changelog","doc":"This is the changelog for Cldr v2.0.0 released on November 22, 2018.  For older changelogs please consult the release tag on [GitHub](https://github.com/elixir-cldr/cldr/tags)","ref":"changelog.html#cldr-v2-0-0"},{"type":"extras","title":"Enhancements - Changelog","doc":"See also [Breaking Changes](#breaking-changes) below.\n\n* Transforms the regex's for currency spacing to be compatible with the elixir regex engine.  This supports improved conformance for currency formatting in [ex_cldr_numbers](https://hex.pm/packages/ex_cldr_numbers)\n* Removes the need for Phoenix as a dependency in tests.  Thanks to @lostkobrakai.  Closes #84.\n* Print deprecation message if the global config is used for more than :json_library and :default_locale\n* Align `Cldr/get_locale/1/0` and `Cldr.put_locale/2/1` with Gettext.  See `Cldr.get_locale/1`, `Cldr.get_locale/0`, `Cldr.put_locale/2` and `Cldr.put_locale/1`\n* Improve performance of `Cldr.Gettext.Plural` and align its return better with `Gettext`\n* Add the 'miscellaneous' number formats to the locale definition files.  This allows formatting of \"at least\", \"approximately\", \"at most\" and \"range\". These formats will be used in [ex_cldr_numbers](https://hex.pm/packages/ex_cldr_numbers).","ref":"changelog.html#enhancements"},{"type":"extras","title":"Purpose of the changes - Changelog","doc":"Version 2.0 of Cldr is focused on re-architecting the module structure to more closely follow the model set by Phoenix, Ecto, Gettext and others that also rely on generating a public API at compile time. In Cldr version 1.x, the compile functions were all hosted within the `ex_cldr` package itself which has created several challenges:\n\n* Only one configuration was possible per installation\n* Dependency compilation order couldn't be determined which meant that when Gettext was configured a second, forced, compilation phase was required whenever the configuration changed\n* Code in the ex_cldr _build directory would be modified when the configuration changed","ref":"changelog.html#purpose-of-the-changes"},{"type":"extras","title":"New structure and configuration - Changelog","doc":"In line with the recommended strategy for configurable library applications, `Cldr` now requires a backend module be defined that hosts the configuration and public API.  This is similar to the strategy used by `Gettext`, `Ecto`, `Phoenix` and others.  These backend modules are defined like this:\n\n    defmodule MyApp.Cldr do\n      use Cldr, locales: [\"en\", \"zh\"]\n    end\n\nFor further information on configuration, consult the [readme](/readme.html).","ref":"changelog.html#new-structure-and-configuration"},{"type":"extras","title":"Migrating from Cldr 1.x to Cldr version 2.x - Changelog","doc":"Although the api structure is the same in both releases, the move to a backend module hosting configuration and the public API requires changes in applications using Cldr version 1.x.  The steps to migrate are:\n\n1. Change the dependency in `mix.exs` to `{:ex_cldr, \"~> 2.0\"}`\n2. Define a backend module to host the configuration and public API.  It is recommended that the module be named `MyApp.Cldr` since this will ease migration through module aliasing.\n3. Change calls to `Cldr.function_name` to `MyApp.Cldr.function_name`.  The easiest way to do this is to alias the backend module.  For example:\n\n```\ndefmodule MyApp.SomeModule do\n# alias the backend module so that calls to Cldr functions still work\n  alias MyApp.Cldr\n\n  def some_function do\n    IO.puts Cldr.known_locale_names\n  end\nend\n```","ref":"changelog.html#migrating-from-cldr-1-x-to-cldr-version-2-x"},{"type":"extras","title":"Breaking Changes - Changelog","doc":"* Configuration has changed to focus on the backend module, then otp app, then global config.  All applications are required to define a backend module.\n* The Public API moves to a configured backend module. Functions previous called on `Cldr` should be called on `MyApp.Cldr`.\n* The `~L` sigil has been removed.  The public api functions support either a locale name (like \"en\") or a language tag.\n* `Cldr.Plug.AcceptLanguage` and `Cldr.Plug.SetLocale` need to have a config key :cldr to specify the `Cldr` backend to be used.\n* The `Mix` compiler `:cldr` is obsolete.  It still exists so configuration doesn't break but its no a `:noop`.  It should be removed from your configuration.\n* `Cldr.Config.get_locale/1` now takes a `config` or `backend` parameter and has become `Cldr.Config.get_locale/2`.\n* `Cldr.get_current_locale/0` is renamed to `Cldr.get_locale/0` to better align with `Gettext`\n* `Cldr.put_current_locale/1` is renamed to `Cldr.put_locale/1` to better align with `Gettext`","ref":"changelog.html#breaking-changes"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}